function bplnk(w,t)
! plank function with respect to wavelength
!--- history
! 89. 8. 1  created
! 08. 9.25 modified Fortran 90 free-style form
!--- input 
! w      r      wavelength (micron)
! t      r      absolute temperature (K)
!--- output
! bplnk  rf     plank function (W/m2/str/micron)
!--
  implicit none

! input 
  real(8),intent(in)::w,t

  real(8)::x,expfn,bplnk
!--exec
  if(w*t <= 0.d0) then
     bplnk=0.d0
  else
     x=1.438786d4/w/t
     bplnk=1.1911d8/w**5/(expfn(x)-1.d0)
  endif
  return
end function bplnk
subroutine frnlr(cr,ci,wi,wr,r1,r2)
! fresnel reflection coefficients
!--- history
! 88. 6.16  created
!--- input
! cr      r      real part of the complex refraction index
! ci      r      imaginary part m = cr + i*ci
! wi      r      incident angle in degrees
!--- output
! wr      r      refraction angle in degrees
!                if total reflection, then wr=999
! r1      r      reflectivity for polarization
! r2      r      reflectivity for polarization
!--- reference
! k.-n. liou
!--
  use VIRparameters, only: pi,rad
  implicit none

! input 
  real(8),intent(in):: cr
  real(8),intent(in):: ci
  real(8),intent(in):: wi

! output
  real(8),intent(out):: wr
  real(8),intent(out):: r1
  real(8),intent(out):: r2

! work
  real(8):: ci1,c,s
  real(8):: en1,en2,en3,u,v,u2
!--  
  ci1=-ci
  c=cos(wi*rad); s=sin(wi*rad)
  wr=s/cr
  if(wr.gt.1.d0) then
     wr=999.d0
  else
     wr=sin(wr)/rad
  endif

  en1=cr**2-ci1**2; en2=2.d0*cr*ci1; en3=en1-s**2
  u=sqrt(abs(en3+sqrt(en3**2+en2**2))/2.d0)
  v=sqrt(abs(u**2-en3))
  u2=u**2+v**2

  r1=1.d0/(u*c/(u2+c**2)+0.5d0)-1.d0
  r2=1.d0/((en1*u+en2*v)*c/((en1**2+en2**2)*c**2+u2)+0.5d0)-1.d0
  return
end subroutine frnlr
subroutine fsoli(wl1,wl2,fsol)
! wavelength integrated solar incidence.
!---history
! 94. 5.30 created by M.Tsukamoto
! 97. 4.19 tuned parameters by T. Nakajima
! 03. 9. 9 Changed for free source form (Fortran 90) by M. Sekiguchi 
!---input
! wl1: min. wavelength of the band (micron)
! wl2: max. wavelength of the band (micron)
!---output
! fsol: integrated solar irradiance (w/m2)
!---
  implicit none
  real(8),intent(in)::wl1,wl2
  real(8),intent(out)::fsol
  integer,parameter::knx=3000,knm=10
  real(8),parameter::dwwlc=1.d6
  integer::n,i
  real(8)::wll1,wll2,wl,dwll,wn,sunir
!--exec
  wll1=log(wl1); wll2=log(wl2)
  n=min(int((wll2-wll1)*dwwlc),knx); n=max(n,knm)
  dwll=(wll2-wll1)/dble(n)
  fsol=0.d0
  do i=1,n
     wl=exp(wll1+(dble(i)-0.5d0)*dwll); wn=1.d4/wl
     fsol=fsol+wl*sunir(wn)*dwll
  enddo
  return
end subroutine fsoli
subroutine gtpar1(ius,nl,nptc,cnp,ispcvp,rfracp,asphr,rop,dryap, &
     nawp,awcrp,nv,nwlv,wlv,rfi)
! get parameters of particle polydispersions
!--- history
! 95. 1.25  created from getph3
! 95. 1.24  dintpm -> aerd (now includs also aerosol water uptake data)
! 95  9.13  with modified aerd file format
! 96. 3.11  added non-spherical parameters
!     5. 5  awcrp(*,*,2)
! 08.10.31  modified fortran 90 version.
!--- input
! ius       i         read unit number of particle parameter file
! nl        i         number of layers (come from mlatm)
!--- output
! nptc      i         number of particle polydispersions
! cnp  r(knl,kpcl)  dry volume concentration profile (relative unit)
! ispcvp  i(3,kpcl)    fundamental materials for 3 comp. internal mixture (1-8)
! rfracp  r(3,kpcl)    dry volume fraction of the dry mixture
! asphr r(3,kpcl)    non-spherical parameters (x0, g, r)
! rop     r(kpcl)      paricle density relative to water
! dryap r(6,4,kpcl)  dv/dlnr parameters for the dry mixture
!                     see vlspc2
!                     c-values (coefficients of volume spectrum) are ralative
! nawp    i(kpcl)      number of aw
! awcrp r(kaw,kpcl,2)  1: aw      water activity (see shettle and fenn.)
!                     2: rmmd    rmmd
! nv        i         number of fundamental species (1-8)
! nwlv      i         number of wavelengths for refractive index tables
! wlv    r(kwl)       wavelengths (micron)
! rfi   r(kwl,knv,2)  refractive index of fundamental materials (mr, mi)
!                     =mr - i mi
!                     with log-regular wavelength interval
!---
  use VIRparameters,only: kptc,knl,kaw,kwlv,knv
  integer,intent(in):: ius
  integer,intent(in):: nl
  integer,intent(out):: nptc
  real(8),intent(out):: cnp(knl,kptc)
  real(8),intent(out):: rfracp(3,kptc)
  integer,intent(out):: ispcvp(3,kptc)
  real(8),intent(out):: asphr(3,kptc)
  real(8),intent(out):: rop(kptc)
  real(8),intent(out):: dryap(6,4,kptc)
  integer,intent(out):: nawp(kptc)
  real(8),intent(out):: awcrp(kaw,kptc,2)
  integer,intent(out):: nv
  integer,intent(out):: nwlv
  real(8),intent(out):: wlv(kwlv)
  real(8),intent(out):: rfi(kwlv,knv,2)

! work
  character(1)::ch
  integer::i,j,k,l,m,iv
  real(8)::rmin,rmax,nmode
!---
  rewind ius
!  number concentration profiles (relative unit)
!  number is conservative in growing aerosols
  read(ius,'(a1)') ch
  read(ius,*) rmin,rmax
  read(ius,*) nptc
  do m=1,nptc
     read(ius,'(a1)') ch
     read(ius,*) (cnp(l,m),l=1,nl)
  enddo
! loop for aerosol mptcs
  do m=1,nptc
     read(ius,'(a1)') ch
     read(ius,*) (ispcvp (i,m),i=1,3)
     read(ius,*) (rfracp (i,m),i=1,3)
     read(ius,*) (asphr(i,m),i=1,3)
     read(ius,*) rop(m)
     read(ius,*) nmode
     dryap(1,2,m)=nmode
     dryap(1,3,m)=rmin
     dryap(1,4,m)=rmax
     do j=1,nmode
        read(ius,*) dryap(2:6,j,m)
     enddo
     read(ius,*) nawp(m)
     if(nawp(m) > 0) then
        read(ius,'(a1)') ch
        do i=1,nawp(m)
           read(ius,*) awcrp(i,m,1:2)
        enddo
     endif
  enddo
! get refractive index table
  read(ius,'(a1)') ch
  read(ius,*) nv,nwlv
  read(ius,*) wlv(1:nwlv)
  do iv=1,nv
     read(ius,'(a1)') ch
     read(ius,*) rfi(1:nwlv,iv,1)
     read(ius,*) rfi(1:nwlv,iv,2)
  enddo
  return
end subroutine gtpar1
subroutine ints5b(iua,ius,matm,nl,alt,prs,tmp,nmol,cng,nptc,cnp, &
     ispcvp,rfracp,asphr,rop,dryap,nawp,awcrp,nv,nwlv,wlv,rfi)
! initilization of star5b
! assume non-spherical parameter input
!--- history
! 95. 9.20  created
! 96. 3.11  kpcl=20 for more aerosol models and non-spherical parameters
!           getpr1 included
!     5. 5  drop npoly and get all the polydispersion information
! 01.10.14  changed for fortran90 version
! 08.09.20  modified free-style form
!--- input
! iua        i        device number for atmospheric model file
! ius        i        device number for particle model file
! matm       i        model number of atmosphere (afgl)
!                      1: tropical
!                      2: mid-latitude summer    3: mid-latitude winter
!                      4: high-lat summer        5: high-lat winter
!                      6: us standard
!--- output
! nl         i        number of atmospheric layers
! alt     r(knl)      height at interfaces of layers (km), top to bottom
! prs     r(knl)      pressure    at interfaces of layers (mb)
! tmp     r(knl)      temperature at interfaces of layers (k)
! nmol       i        number of gases
! cng    r(knl,knm0)  gas concentration (ppmv)
! nptc      i         number of particle polydispersions
! cnp  r(knl,kpcl)  dry volume concentration profile (relative unit)
! ispcvp  i(3,kpcl)    fundamental materials for 3 comp. internal mixture (1-8)
! rfracp  r(3,kpcl)    dry volume fraction of the dry mixture
! asphr r(3,kpcl)    non-spherical parameters (x0, g, r)
! rop    r(kpcl)      paricle density relative to water
! dryap r(6,4,kpcl)  dv/dlnr parameters for the dry mixture
!                     see vlspc2
!                     c-values (coefficients of volume spectrum) are ralative
! nawp    i(kpcl)      number of aw
! awcrp  r(kaw,kpcl,2) 1: aw      water activity (see shettle and fenn.)
!                     2: rmmd    rmmd
! nv        i         number of fundamental species (1-8)
! nwlv      i         number of wavelengths for refractive index tables
! wlv    r(kwl)       wavelengths (micron)
! rfi   r(kwl,knv,2)  refractive index of fundamental materials (mr, mi)
!                     =mr - i mi
!                     with log-regular wavelength interval
!---Declarations
  use VIRparameters,only: kptc,knl,knm0,kaw,kwlv,knv
  implicit none

! input
  integer,intent(in):: iua,ius   !! device number
  integer,intent(in):: matm      !! atmospheric number

! output
  integer,intent(out):: nl       !! number of atmospheric layer
  real(8),intent(out):: alt(knl) !! altitude [km]
  real(8),intent(out):: prs(knl) !! pressure [mb]
  real(8),intent(out):: tmp(knl) !! temperature [K]
  integer,intent(out):: nmol          !! number of gases
  real(8),intent(out):: cng(knl,knm0) !! gas concentration [ppmv]
  integer,intent(out):: nptc          !! number of particle polydispersions
  real(8),intent(out):: cnp(knl,kptc) !! dry volume concentration
  integer,intent(out):: ispcvp(3,kptc) !! internal mixture of fundamental
  real(8),intent(out):: rfracp(3,kptc) !! dry component volume fractions
  real(8),intent(out):: asphr(3,kptc)  !! non-spherical parameters
  real(8),intent(out):: rop(kptc)     !! particle density of dry mixture [g/cm3]
  real(8),intent(out):: dryap(6,4,kptc) !! param to define volume size dist.
  integer,intent(out):: nawp(kptc)    !! number of RH to define particle growth
  real(8),intent(out):: awcrp(kaw,kptc,2) !! growth parameters

  integer,intent(out):: nv            !! number of fundamental species
  integer,intent(out):: nwlv          !! number of wavelenggths for rfi tables
  real(8),intent(out):: wlv(kwlv)     !! wavelengths [micron] for rfi tables
  real(8),intent(out):: rfi(kwlv,knv,2)  !! refractive index of fundamental

! for mlatm
  integer,parameter:: knm1=7     !! number of major gas
  integer,parameter:: knm2=21    !! number of minor gas
  integer,parameter:: katm=6     !! number of standard atmospheric condition
  integer,parameter:: knm=knm1+knm2
  character(8)::idm(knm)
  integer::idms(knm,10)
  real(8)::wmol(knm,10),rams(knm,10)
  real(8)::pmatm(knl,katm),tmatm(knl,katm),dnsty(knl,katm)
  real(8)::amol(knl,knm1,katm),trac(knl,knm2)

! for getpar
  integer,save::init=1
  integer::natm,nm1,nm2,l,m
  real(8)::airm
!---
  if(init > 0) then
     init=0
! model atmospheres
     call mlatm(iua,nl,natm,nm1,nm2,idm,idms,wmol,rams,airm, &
          alt,pmatm,tmatm,dnsty,amol,trac)

!  get aerosol parameters
! / removed for SDSU /
!     call gtpar1(ius,nl,nptc,cnp,ispcvp,rfracp,asphr,rop,dryap,nawp, &
!          awcrp,nv,nwlv,wlv,rfi)
! / added for SDSU /
     nptc=0; ispcvp=0; nawp=0; nv=0; nwlv=0
     cnp=0.d0; rfracp=0.d0; asphr=0.d0; rop=0.d0; dryap=0.d0; awcrp=0.d0
     wlv=0.d0; rfi=0.d0
  endif

  prs(1:knl)=pmatm(1:knl,matm)
  tmp(1:knl)=tmatm(1:knl,matm)
  cng(1:knl,1:knm1)=amol(1:knl,1:knm1,matm)
! cng(:,8:28)=trac(:,1:21)
  nmol=knm1
  return
end subroutine ints5b

subroutine mlatm(iu,nl,natm,nm1,nm2,idm,idms,wmol,rams,airm, &
     alt,pmatm,tmatm,dnsty,amol,trac)
! set model profiles
!--- history
! 90. 2.24 modified by t. nakajima
! 92. 3.30 idms*8 -> idms for sun-sparc read-statement trouble
! 94. 3.29 idms(i,j)=' ' -> 0
! 94. 6.20 add return
!    10.30 9 format(a8) for ibm
! 95. 9.15 rewind iu
! 01.10.14  changed for fortran90 version
! 08. 9.20  modified free-style form
!--- input
! iu        i         read unit number
!--- output
! nl        i         number of layers = 50
! natm      i         number of model atmospheres = 6
! nm1       i         number of molecules of first kind = 7
! nm2       i         number of molecules of second kind = 21
! idm     c(knm)*8    molecular id
! idms   i(knm,10)    isotope id (0 means end)
! wmol   r(knm,10)    molecular weights
! rams   r(knm,10)    relative abundance of isotopes (0 means end)
! airm      r         molecular weight of air
! alt     r(knl)      altitude (k)
! pmatm  r(knl,katm)  model pressure profiles (mb)
!                     1: tropical,
!                     2: mid-latitude summer,  3: mid-latitude winter
!                     4: high-lat summer    ,  5: high-lat winter
!                     6: us standard
! tmatm  r(knl,katm)  model temperature profiles
! dnsty  r(knl,katm)  density (air molecules / cm3) = p*na/r/t
! amol   r(knl,knm1   molecular profiles (ppmv)
!            ,katm)   1: h2o    2: co2     3: o3      4: n2o     5: co
!                     6: ch4    7: o2
! trac   r(knl,knm2)  trace gase frofiles (ppmv)
!                     8: no     9: so2    10: no2    11: nh3    12: hno3
!                    13: oh    14: hf     15: hcl    16: hbr    17: hi
!                    18: clo   19: ocs    20: h2co   21: hocl   22: n2
!                    23: hcn   24: ch3cl  25: h2o2   26: c2h2   27: c2h6
!                    28: ph3
!
! err      c*64       error indicater
!
!--- data file
! MLATMD
!--
  use VIRparameters , only : knl

! parameters in this routine
  integer,parameter:: knm1=7     !! number of major gas
  integer,parameter:: knm2=21    !! number of minor gas
  integer,parameter:: katm=6     !! number of standard atmospheric condition
  integer,parameter:: knm=knm1+knm2

! input
  integer,intent(in)::iu

! output
  character(8),intent(out)::idm(knm)
  integer,intent(out)::idms(knm,10)
  real(8),intent(out)::wmol(knm,10),rams(knm,10)
  real(8),intent(out)::pmatm(knl,katm),tmatm(knl,katm)
  real(8),intent(out)::amol(knl,knm1,katm),trac(knl,knm2)
  real(8),intent(out)::alt(knl),dnsty(knl,katm)
!--- work area
  character ch*1
  integer::nm1,nm2,natm,nm,i,j,k,ns,nl
  real(8)::airm
!--exec
! read numbers
  read(iu,'(a1)') ch
  read(iu,*) nm1,nm2,natm,nl
  nm=nm1+nm2

! read molecular information
  read(iu,'(a1)') ch
  read(iu,*) airm
  read(iu,'(a1)') ch
  idms(:,:)=0
  rams(:,:)=0.0d0
  do i=1,nm
     read(iu,'(a8)') idm(i)
     read(iu,*) ns
     read(iu,*) idms(i,1:ns)
     read(iu,*) wmol(i,1:ns)
     read(iu,*) rams(i,1:ns)
  enddo

! read altitude
  read(iu,'(a1)') ch
  read(iu,*) alt(1:nl)

! read pressure
  do j=1,natm
     read(iu,'(a1)') ch
     read(iu,*) pmatm(1:nl,j)
  enddo

! read temperature
  do j=1,natm
     read(iu,'(a1)') ch
     read(iu,*) tmatm(1:nl,j)
  enddo

! read molecular profiles
  do k=1,nm1
     do j=1,natm
        read(iu,'(a1)') ch
        read(iu,*) amol(1:nl,k,j)
     enddo
  enddo

  do j=1,natm
     read(iu,'(a1)') ch
     read(iu,*) dnsty(1:nl,j)
  enddo

! read trace gase profiles
  do  k=1,nm2
     read(iu,'(a1)') ch
     read(iu,*) trac(1:nl,k)
  enddo
  return
end subroutine mlatm
module sundat
  implicit none
  real(8),save::solara(1440),solarb(2910)
  
contains
  subroutine solar(solara,solarb)
    real(8)::solara(1440),solarb(2910)

!     solar spectrum from      0 to    800 cm-1,  in steps of 20 cm-
    solara(1:41)=(/ &
         0.0000d+00, 4.5756d-08, 7.0100d-07, 3.4580d-06, 1.0728d-05, &
         2.5700d-05, 5.2496d-05, 9.6003d-05, 1.6193d-04, 2.5766d-04, &
         3.9100d-04, 5.6923d-04, 8.0203d-04, 1.1006d-03, 1.4768d-03, &
         1.9460d-03, 2.5213d-03, 3.2155d-03, 4.0438d-03, 5.0229d-03, &
         6.1700d-03, 7.5145d-03, 9.0684d-03, 1.0853d-02, 1.2889d-02, &
         1.5213d-02, 1.7762d-02, 2.0636d-02, 2.3888d-02, 2.7524d-02, &
         3.1539d-02, 3.5963d-02, 4.0852d-02, 4.6236d-02, 5.2126d-02, &
         5.8537d-02, 6.5490d-02, 7.3017d-02, 8.1169d-02, 9.0001d-02, &
         9.9540d-02 /)
!     solar spectrum from    820 to   3680 cm-1,  in steps of 20 cm-
    solara(42:185)=(/ &
         .10980, .12080, .13260, .14520, .15860, .17310, .18850, .20490, &
         .22240, .24110, .26090, .28200, .30430, .32790, .35270, .37890, &
         .40650, .43550, .46600, .49800, .53160, .56690, .60390, .64260, &
         .68320, .72560, .76990, .81620, .86440, .91470, .96710, 1.0220, &
         1.0780, 1.1370, 1.1990, 1.2630, 1.3290, 1.3990, 1.4710, 1.5460, &
         1.6250, 1.7060, 1.7910, 1.8800, 1.9710, 2.0670, 2.1660, 2.2680, &
         2.3740, 2.4840, 2.5970, 2.7140, 2.8350, 2.9600, 3.0890, 3.2210, &
         3.3570, 3.4980, 3.6420, 3.7900, 3.9440, 4.1040, 4.2730, 4.4450, &
         4.6150, 4.7910, 4.9830, 5.1950, 5.4210, 5.6560, 5.8930, 6.1270, &
         6.3560, 6.5820, 6.8080, 7.0360, 7.2700, 7.5170, 7.7890, 8.0910, &
         8.4070, 8.7120, 8.9900, 9.2490, 9.5000, 9.7550, 10.010, 10.250, &
         10.480, 10.700, 10.950, 11.230, 11.550, 11.900, 12.250, 12.600, &
         12.930, 13.250, 13.530, 13.780, 14.040, 14.320, 14.660, 15.070, &
         15.530, 16.011, 16.433, 16.771, 17.077, 17.473, 17.964, 18.428, &
         18.726, 18.906, 19.141, 19.485, 19.837, 20.160, 20.509, 21.024, &
         21.766, 22.568, 23.190, 23.577, 23.904, 24.335, 24.826, 25.236, &
         25.650, 26.312, 27.208, 27.980, 28.418, 28.818, 29.565, 30.533, &
         31.247, 31.667, 32.221, 33.089, 33.975, 34.597, 35.004, 35.395/)
!     solar spectrum from   3700 to   6560 cm-1,  in steps of 20 cm-
    solara(186:329)=(/ &
         36.026, 36.985, 37.890, 38.401, 38.894, 39.857, 40.926, 41.570, &
         42.135, 43.083, 44.352, 45.520, 45.982, 46.281, 48.335, 51.987, &
         54.367, 54.076, 52.174, 50.708, 52.153, 55.707, 56.549, 54.406, &
         53.267, 56.084, 61.974, 64.406, 60.648, 55.146, 53.067, 57.476, &
         64.645, 68.348, 69.055, 69.869, 70.943, 71.662, 72.769, 74.326, &
         75.257, 74.883, 73.610, 73.210, 74.886, 78.042, 80.204, 80.876, &
         82.668, 84.978, 86.244, 88.361, 91.998, 95.383, 98.121, 100.29, &
         100.64, 99.997, 101.82, 105.06, 107.50, 109.99, 112.45, 113.90, &
         113.79, 119.23, 121.96, 124.58, 127.14, 125.19, 124.37, 125.00, &
         127.88, 130.67, 131.98, 133.74, 136.69, 136.18, 135.02, 137.44, &
         138.44, 137.25, 136.35, 142.60, 144.54, 148.37, 151.90, 151.55, &
         155.35, 157.59, 159.70, 162.28, 168.44, 171.43, 169.82, 170.33, &
         172.28, 176.68, 181.92, 186.06, 187.85, 186.00, 189.82, 189.35, &
         192.86, 202.00, 209.63, 205.76, 212.88, 215.63, 216.51, 219.20, &
         220.29, 221.12, 227.12, 229.97, 233.23, 233.95, 234.52, 234.45, &
         235.77, 239.80, 243.11, 241.19, 242.34, 243.69, 242.84, 246.19, &
         246.11, 246.76, 251.75, 255.38, 258.74, 260.26, 263.40, 268.68, &
         271.81, 272.95, 273.93, 274.74, 274.43, 279.69, 287.76, 287.72/)
!     solar spectrum from   6580 to   9440 cm-1,  in steps of 20 cm-
    solara(330:473)=(/ &
         287.96, 290.01, 291.92, 295.28, 296.78, 300.46, 302.19, 299.14, &
         301.43, 305.68, 309.29, 310.63, 313.24, 314.61, 309.58, 318.81, &
         320.54, 321.62, 328.58, 331.66, 337.20, 345.62, 345.54, 342.96, &
         344.38, 346.23, 349.17, 351.79, 354.71, 356.97, 358.29, 362.29, &
         364.15, 364.97, 367.81, 368.98, 369.07, 372.17, 377.79, 381.25, &
         384.22, 388.66, 393.58, 396.98, 398.72, 400.61, 404.06, 408.23, &
         412.47, 415.58, 416.17, 416.53, 419.55, 425.88, 433.30, 437.73, &
         438.13, 439.79, 441.51, 438.71, 434.25, 437.54, 448.95, 448.86, &
         439.46, 437.10, 439.34, 444.33, 455.00, 467.05, 473.04, 469.64, &
         467.53, 473.78, 477.50, 477.50, 480.96, 483.94, 482.19, 479.08, &
         482.09, 493.43, 498.40, 492.05, 489.53, 493.34, 495.51, 496.52, & 
         499.57, 504.65, 509.68, 512.00, 512.05, 512.31, 515.00, 520.70, &
         527.30, 531.88, 532.16, 530.48, 532.33, 539.26, 548.57, 553.00, &
         548.96, 546.05, 551.00, 556.41, 557.21, 557.85, 560.95, 564.02, &
         565.57, 566.38, 567.88, 571.48, 576.68, 581.54, 586.51, 593.62, &
         600.70, 602.79, 601.39, 603.00, 606.88, 605.95, 600.97, 600.79, &
         607.21, 612.87, 614.13, 614.39, 616.61, 620.53, 625.19, 629.78, &
         633.79, 637.31, 640.47, 642.53, 642.62, 641.93, 643.11, 646.68/)
!     solar spectrum from   9460 to  12320 cm-1,  in steps of 20 cm-
    solara(474:617)=(/ &
         650.57, 654.30, 660.95, 672.10, 682.31, 684.89, 682.20, 682.53, &
         687.79, 691.42, 689.62, 688.14, 693.71, 703.25, 708.07, 706.22, &
         704.64, 708.97, 717.35, 725.43, 731.08, 734.17, 735.41, 736.60, &
         739.34, 742.90, 745.04, 744.29, 742.44, 749.53, 755.70, 758.82, &
         766.31, 761.53, 762.09, 769.68, 764.18, 763.75, 768.88, 762.69, & 
         753.93, 762.38, 765.79, 772.19, 760.67, 762.10, 766.76, 766.98, &
         769.35, 773.50, 766.84, 763.60, 773.82, 777.18, 779.61, 792.48, &
         797.54, 787.81, 793.75, 805.96, 804.77, 806.62, 821.72, 830.28, &
         827.54, 831.06, 830.20, 826.22, 823.28, 822.18, 833.92, 854.58, &
         859.80, 862.56, 871.16, 875.16, 867.67, 863.87, 883.30, 893.40, &
         897.74, 905.24, 905.38, 911.07, 930.21, 939.24, 934.74, 935.15, &
         942.38, 948.13, 947.00, 951.88, 960.12, 951.88, 954.22, 959.07, &
         963.36, 980.16, 983.66, 978.76, 979.38, 985.24, 977.08, 919.94, &
         899.68, 962.91, 997.17, 999.93, 995.65, 999.93, 1014.9, 951.57, &
         893.52, 955.14, 1003.1, 990.13, 978.79, 1011.2, 1034.7, 1031.9, &
         1029.9, 1039.7, 1045.5, 1044.1, 1049.6, 1056.1, 1049.8, 1038.0, &
         1051.9, 1072.2, 1075.5, 1077.0, 1079.3, 1078.0, 1075.7, 1079.7, &
         1081.0, 1069.8, 1078.4, 1104.3, 1111.4, 1111.7, 1117.6, 1119.6/)

!     solar spectrum from  12340 to  15200 cm-1,  in steps of 20 cm-
    solara(618:761)=(/ &
         1109.3, 1100.6, 1112.9, 1122.7, 1119.5, 1123.9, 1136.1, 1143.7, &
         1140.5, 1141.2, 1151.5, 1148.7, 1138.3, 1141.0, 1150.6, 1160.1, &
         1170.6, 1177.7, 1179.8, 1181.7, 1182.4, 1179.8, 1181.8, 1188.3, &
         1190.0, 1191.4, 1197.0, 1196.0, 1192.2, 1200.6, 1210.4, 1209.1, &
         1207.5, 1205.3, 1193.3, 1192.9, 1220.0, 1243.3, 1245.4, 1241.5, &
         1240.2, 1241.1, 1244.0, 1248.5, 1253.2, 1257.1, 1259.9, 1261.9, &
         1263.6, 1265.7, 1269.6, 1277.0, 1284.2, 1284.4, 1282.7, 1287.2, &
         1286.8, 1272.3, 1262.2, 1270.7, 1288.8, 1304.8, 1311.8, 1312.2, &
         1314.4, 1320.2, 1326.2, 1328.4, 1325.3, 1322.5, 1325.4, 1334.6, & 
         1346.4, 1354.0, 1353.7, 1347.3, 1338.3, 1331.0, 1329.7, 1338.0, &
         1351.9, 1363.0, 1368.8, 1372.0, 1375.9, 1382.1, 1387.8, 1388.8, &
         1388.2, 1392.2, 1401.7, 1412.9, 1418.2, 1410.7, 1395.9, 1385.7, &
         1388.1, 1405.0, 1424.0, 1428.1, 1422.2, 1423.6, 1434.5, 1445.2, &
         1450.7, 1451.8, 1451.5, 1453.9, 1459.9, 1466.9, 1471.3, 1469.4, &
         1462.5, 1460.4, 1468.9, 1481.8, 1490.8, 1495.3, 1497.9, 1500.7, &
         1505.2, 1510.0, 1512.3, 1512.7, 1515.6, 1521.6, 1524.2, 1520.7, &
         1520.3, 1531.6, 1545.7, 1548.2, 1541.7, 1542.2, 1553.6, 1563.6, &
         1563.6, 1559.9, 1561.3, 1569.9, 1581.6, 1577.6, 1529.7, 1447.0/)

!    solar spectrum from  15220 to  18080 cm-1,  in steps of 20 cm-
    solara(762:905)=(/ &
         1396.9, 1428.7, 1506.4, 1567.1, 1594.0, 1606.1, 1613.5, 1609.0, &
         1588.6, 1567.8, 1567.3, 1587.2, 1610.2, 1624.4, 1630.2, 1630.9, &
         1628.1, 1622.3, 1616.9, 1618.9, 1631.6, 1648.1, 1658.2, 1659.7, &
         1658.1, 1658.0, 1659.4, 1660.4, 1659.2, 1653.7, 1645.3, 1642.1, &
         1652.7, 1674.2, 1694.1, 1700.6, 1703.4, 1697.6, 1654.5, 1644.4, &
         1661.6, 1676.3, 1707.7, 1703.1, 1710.8, 1732.3, 1716.5, 1719.6, &
         1729.6, 1683.1, 1628.5, 1683.5, 1727.0, 1707.8, 1689.4, 1698.4, &
         1733.1, 1737.8, 1714.1, 1734.6, 1750.1, 1750.1, 1760.3, 1764.3, &
         1765.3, 1769.4, 1779.9, 1793.0, 1765.1, 1729.4, 1745.9, 1753.4, &
         1758.1, 1775.0, 1768.4, 1767.9, 1789.5, 1806.6, 1799.3, 1782.6, &
         1779.3, 1792.1, 1809.7, 1808.0, 1794.4, 1818.6, 1774.2, 1648.5, &
         1674.3, 1789.3, 1847.2, 1848.3, 1812.9, 1796.4, 1840.3, 1868.3, &
         1864.6, 1873.2, 1872.2, 1856.0, 1845.0, 1842.4, 1823.9, 1795.1, &
         1819.6, 1861.5, 1857.7, 1838.6, 1840.5, 1863.5, 1876.8, 1884.4, &
         1894.9, 1875.2, 1821.2, 1779.4, 1810.2, 1855.3, 1831.8, 1837.3, &
         1882.3, 1866.4, 1819.6, 1804.8, 1831.4, 1861.6, 1867.1, 1862.9, &
         1851.9, 1834.7, 1835.2, 1845.1, 1831.9, 1803.6, 1792.5, 1821.8, &
         1845.8, 1832.3, 1847.6, 1894.2, 1909.2, 1901.0, 1891.2, 1869.9/)

!    solar spectrum from  18100 to  20960 cm-1,  in steps of 20 cm-
    solara(906:1049)=(/ &
         1854.4, 1865.8, 1873.7, 1868.8, 1881.7, 1897.1, 1884.2, 1856.2, &
         1840.6, 1855.1, 1885.3, 1903.6, 1900.1, 1887.4, 1887.7, 1879.0, &
         1844.5, 1844.1, 1877.1, 1847.3, 1785.1, 1792.6, 1848.7, 1894.4, & 
         1908.8, 1892.8, 1867.4, 1885.6, 1959.9, 1971.9, 1895.8, 1883.5, &
         1917.6, 1853.8, 1793.0, 1875.6, 1974.0, 1975.7, 1943.9, 1926.4, &
         1914.4, 1902.7, 1882.5, 1813.3, 1710.8, 1717.9, 1859.7, 1965.1, &
         1970.1, 1941.4, 1902.5, 1852.0, 1836.3, 1879.3, 1901.6, 1862.9, &
         1839.1, 1840.9, 1780.0, 1684.9, 1677.3, 1718.7, 1697.3, 1684.3, &
         1784.5, 1898.0, 1910.3, 1877.2, 1866.6, 1862.6, 1860.3, 1899.7, &
         1971.0, 1999.9, 1970.9, 1936.5, 1922.8, 1922.8, 1924.0, 1917.2, &
         1912.0, 1926.2, 1959.7, 1995.4, 1995.9, 1938.8, 1883.5, 1894.7, &
         1933.3, 1935.1, 1899.3, 1852.7, 1820.2, 1821.5, 1865.2, 1935.5, &
         1966.1, 1919.6, 1881.2, 1931.5, 2015.6, 2050.0, 2021.4, 1960.8, &
         1938.2, 1997.0, 2051.0, 2003.4, 1912.1, 1880.2, 1895.2, 1898.0, &
         1898.8, 1938.3, 1994.2, 2010.0, 1982.4, 1948.8, 1927.3, 1911.6, &
         1877.7, 1791.6, 1679.8, 1645.0, 1727.3, 1845.2, 1926.2, 1973.4, &
         2005.2, 2021.6, 2021.8, 2025.7, 2054.3, 2086.5, 2082.6, 2052.9, &
         2047.1, 2070.2, 2072.4, 2038.1, 2020.2, 2049.9, 2074.0, 2038.1/)

!    solar spectrum from  20980 to  23840 cm-1,  in steps of 20 cm-
    solara(1050:1193)=(/ &
         1978.6, 1963.5, 1996.8, 2037.5, 2057.5, 2048.2, 2018.4, 1999.2, &
         2011.4, 2039.5, 2056.0, 2040.2, 1981.8, 1911.4, 1891.8, 1938.3, & 
         1991.7, 2005.5, 2000.8, 2011.3, 2022.7, 1997.5, 1947.7, 1936.3, &
         1986.6, 2037.9, 2032.8, 1995.7, 1984.0, 2012.0, 2055.5, 2091.6, &
         2106.5, 2094.9, 2070.4, 2052.8, 2046.7, 2043.8, 2035.5, 2016.6, &
         1988.4, 1973.3, 1999.0, 2057.4, 2103.8, 2109.4, 2089.4, 2068.5, &
         2051.8, 2031.2, 2005.9, 1986.7, 1981.5, 1979.4, 1964.1, 1943.6, &
         1951.8, 2007.3, 2083.2, 2139.1, 2158.0, 2143.3, 2103.2, 2050.9, &
         2001.9, 1974.5, 1988.0, 2037.8, 2075.1, 2050.6, 1971.5, 1884.5, &
         1828.5, 1820.9, 1866.4, 1935.3, 1974.2, 1958.7, 1925.1, 1920.2, &
         1949.7, 1984.6, 1996.4, 1966.4, 1884.8, 1781.9, 1726.8, 1759.4, &
         1817.4, 1800.4, 1692.6, 1593.2, 1598.6, 1700.3, 1823.8, 1909.7, &
         1937.7, 1902.5, 1822.4, 1737.8, 1683.2, 1666.8, 1682.7, 1715.3, &
         1734.1, 1712.4, 1668.2, 1655.0, 1698.1, 1727.2, 1636.9, 1415.7, &
         1204.2, 1155.8, 1278.4, 1450.0, 1560.5, 1595.1, 1587.8, 1570.6, &
         1565.8, 1590.3, 1640.5, 1688.4, 1708.1, 1703.6, 1700.7, 1718.5, &
         1749.0, 1772.2, 1772.5, 1745.2, 1690.2, 1624.9, 1589.0, 1618.5, &
         1701.3, 1783.2, 1816.4, 1800.7, 1765.0, 1734.1, 1714.6, 1705.0/)

!    solar spectrum from  23860 to  26720 cm-1,  in steps of 20 cm-
    solara(1194:1337)=(/ &
         1701.6, 1696.6, 1682.0, 1661.4, 1657.2, 1693.0, 1763.2, 1826.5, &
         1841.6, 1806.1, 1755.6, 1725.8, 1724.2, 1736.8, 1749.0, 1756.1, &
         1759.5, 1762.1, 1770.2, 1791.7, 1826.8, 1848.9, 1819.6, 1720.7, &
         1595.5, 1513.9, 1522.5, 1602.0, 1706.2, 1793.4, 1837.9, 1820.3, &
         1738.3, 1631.1, 1553.1, 1539.2, 1574.3, 1623.9, 1660.6, 1676.8, &
         1673.1, 1652.9, 1626.4, 1606.7, 1604.2, 1620.9, 1654.5, 1701.2, &
         1752.2, 1796.2, 1822.8, 1827.4, 1808.5, 1767.0, 1713.9, 1667.3, &
         1643.7, 1643.5, 1652.5, 1655.3, 1638.7, 1592.2, 1506.4, 1377.3, &
         1209.5, 1010.5, 807.59, 666.84, 664.53, 835.23, 1099.6, 1330.7, &
         1423.2, 1363.7, 1194.1, 961.77, 725.04, 551.29, 504.01, 596.30, &
         775.15, 975.62, 1150.2, 1287.2, 1386.1, 1447.5, 1473.7, 1468.5, &
         1435.2, 1376.9, 1296.0, 1195.5, 1085.3, 985.40, 917.25, 894.59, &
         910.86, 951.53, 1001.7, 1046.4, 1070.7, 1061.2, 1021.2, 977.16, &
         959.15, 982.06, 1020.5, 1032.6, 983.44, 879.83, 762.66, 675.28, &
         643.33, 662.65, 721.49, 808.35, 913.24, 1027.0, 1139.9, 1236.2, &
         1293.2, 1287.1, 1210.4, 1102.1, 1021.6, 1022.8, 1109.3, 1232.6, &
         1337.0, 1383.1, 1372.8, 1324.7, 1257.7, 1188.8, 1133.5, 1106.5, &
         1113.7, 1136.8, 1147.9, 1121.4, 1054.1, 968.10, 889.19, 837.87/)

!    solar spectrum from  26740 to  28780 cm-1,  in steps of 20 cm-
    solara(1338:1440)=(/ &
         817.64, 823.72, 851.04, 896.53, 959.85, 1041.2, 1137.6, 1231.2, &
         1294.4, 1299.9, 1241.2, 1155.0, 1092.0, 1097.1, 1170.2, 1263.5, &
         1322.4, 1307.4, 1233.6, 1146.1, 1090.8, 1092.5, 1134.6, 1188.9, &
         1228.9, 1245.5, 1248.5, 1250.3, 1260.5, 1274.6, 1279.5, 1261.8, &
         1214.3, 1145.4, 1069.6, 1001.4, 952.52, 930.48, 941.68, 990.34, &
         1064.4, 1135.2, 1171.5, 1149.1, 1076.3, 984.35, 906.25, 868.17, &
         873.75, 915.33, 984.41, 1067.2, 1137.1, 1163.1, 1115.5, 990.55, &
         830.93, 692.29, 627.44, 654.10, 739.24, 838.88, 911.69, 941.90, &
         944.42, 939.58, 946.10, 970.23, 1005.2, 1042.4, 1073.8, 1097.0, &
         1114.3, 1128.8, 1142.9, 1153.4, 1152.4, 1131.5, 1084.2, 1016.7, &
         945.95, 890.37, 866.15, 876.54, 913.13, 966.10, 1025.4, 1080.2, &
         1119.0, 1102.7, 1243.5, 1209.9, 1079.2, 852.20, 956.80, 842.31, &
         897.44, 1081.8, 914.23, 993.09, 1049.8, 844.95, 839.16/)
     
!    solar spectrum from  28400 to  29830 cm-1,  in steps of 10 cm-
    solarb(1:144)=(/ &
         876.54, 892.17, 913.13, 938.18, 966.10, 995.62, 1025.4, 1054.1, &
         1080.2, 1102.1, 1119.0, 1132.2, 1102.7, 1159.3, 1243.5, 1238.3, &
         1209.9, 1196.2, 1079.2, 895.60, 852.20, 935.59, 956.80, 897.09, &
         842.31, 821.15, 897.44, 1042.7, 1081.8, 988.79, 914.23, 929.38, &
         993.09, 1041.9, 1049.8, 984.33, 844.95, 770.76, 839.16, 939.65, &
         1026.1, 1121.1, 1162.6, 1142.6, 1077.9, 1027.3, 1078.2, 1094.3, &
         969.83, 853.72, 849.91, 909.12, 995.68, 1095.0, 1146.9, 1086.3, &
         1010.4, 1065.4, 1128.9, 1080.6, 987.93, 898.18, 835.20, 771.63, &
         687.12, 614.52, 606.14, 737.09, 908.13, 997.64, 1080.6, 1126.3, &
         1056.7, 1028.4, 1141.7, 1252.6, 1225.3, 1103.2, 1038.6, 1043.4, &
         1002.9, 965.51, 1035.0, 1150.7, 1200.9, 1152.0, 1068.5, 995.84, &
         889.52, 818.48, 907.01, 1042.2, 1055.6, 1000.6, 972.00, 985.72, &
         1027.2, 1054.8, 1078.0, 1126.6, 1205.3, 1245.7, 1201.0, 1144.7, &
         1097.5, 1030.1, 926.85, 836.71, 864.11, 993.50, 1075.3, 1032.6, &
         1008.9, 1066.1, 1067.4, 1004.8, 971.54, 923.18, 815.71, 799.70, &
         946.19, 1100.1, 1126.4, 1032.2, 895.14, 784.30, 734.77, 726.53, &
         726.88, 765.54, 863.90, 992.24, 1070.9, 1028.1, 858.78, 647.15, &
         563.18, 679.98, 906.40, 1094.3, 1155.3, 1124.3, 1098.4, 1109.5/)

!    solar spectrum from  29840 to  31270 cm-1,  in steps of 10 cm-
    solarb(145:288)=(/ &
         1076.2, 944.17, 849.20, 928.54, 1062.0, 1118.9, 1119.2, 1074.6, &
         1005.8, 980.02, 999.11, 1002.4, 939.78, 838.12, 816.13, 908.73, &
         1014.9, 1058.3, 1043.7, 987.54, 946.35, 981.40, 1055.8, 1094.3, &
         1028.3, 916.41, 908.99, 991.83, 1049.6, 1076.2, 1093.5, 1076.3, &
         1014.5, 949.61, 947.26, 1001.2, 1051.5, 1072.8, 1068.0, 1012.5, &
         907.81, 866.30, 950.89, 1037.5, 1079.5, 1183.9, 1291.3, 1268.6, &
         1199.3, 1188.6, 1188.0, 1186.6, 1198.2, 1171.3, 1132.6, 1131.6, &
         1096.0, 971.10, 847.07, 836.62, 922.78, 990.99, 987.51, 969.24, &
         981.46, 981.36, 971.95, 985.34, 1003.0, 1037.2, 1071.2, 1065.7, &
         1026.7, 984.84, 1002.7, 1070.3, 1117.5, 1116.0, 1048.9, 965.34, &
         972.27, 1045.7, 1096.6, 1127.5, 1133.5, 1099.6, 1079.3, 1082.9, &
         1026.8, 927.50, 879.08, 858.83, 831.01, 807.82, 789.56, 813.75, &
         893.46, 937.62, 901.56, 864.46, 873.35, 891.03, 862.46, 810.30, &
         787.36, 752.93, 715.34, 708.07, 728.93, 786.79, 807.73, 736.28, &
         645.08, 616.90, 649.17, 691.77, 749.18, 820.21, 820.68, 791.26, &
         854.27, 940.56, 956.38, 909.42, 824.18, 767.17, 722.06, 653.42, &
         624.67, 633.73, 655.14, 707.93, 784.94, 880.79, 961.15, 985.60, &
         986.18, 966.53, 921.47, 888.89, 855.85, 851.66, 886.78, 850.97/)

!    solar spectrum from  31280 to  32710 cm-1,  in steps of 10 cm-
    solarb(289:432)=(/ &
         766.97, 738.95, 724.53, 657.61, 587.77, 616.86, 760.61, 903.23, &
         917.27, 838.49, 784.80, 759.41, 719.61, 671.48, 624.63, 588.57, &
         574.70, 596.68, 698.02, 866.39, 974.82, 960.37, 930.10, 962.65, &
         1007.1, 1001.9, 926.29, 816.64, 763.25, 772.93, 762.66, 729.39, &
         725.01, 727.16, 672.73, 581.42, 520.97, 488.80, 478.60, 542.08, &
         663.71, 749.48, 785.87, 811.05, 818.19, 813.80, 824.54, 836.62, &
         799.66, 728.00, 660.36, 559.28, 473.28, 550.16, 752.04, 885.84, &
         906.80, 912.21, 929.32, 899.72, 830.20, 774.56, 736.42, 724.09, &
         740.12, 754.11, 764.96, 780.76, 788.94, 784.87, 758.80, 725.91, &
         751.84, 804.24, 777.73, 703.36, 665.27, 663.99, 679.36, 706.09, &
         757.57, 836.09, 880.02, 881.18, 907.91, 929.26, 894.32, 874.01, &
         918.56, 953.50, 922.32, 866.61, 836.54, 825.28, 752.54, 586.02, &
         427.46, 374.05, 437.23, 534.32, 556.74, 563.11, 629.31, 631.26, &
         518.76, 438.31, 460.31, 530.45, 608.50, 657.99, 662.08, 686.17, &
         775.18, 843.11, 797.46, 685.33, 611.33, 628.74, 711.36, 754.94, &
         728.80, 722.79, 726.38, 679.68, 665.83, 710.48, 723.10, 724.09, &
         760.18, 784.01, 742.78, 634.33, 546.55, 563.54, 611.03, 623.16, &
         665.36, 743.55, 764.46, 671.14, 513.18, 401.86, 405.77, 515.72/)

!    solar spectrum from  32720 to  34150 cm-1,  in steps of 10 cm-
    solarb(433:576)=(/ &
         639.90, 677.85, 679.55, 759.33, 848.11, 819.89, 751.75, 710.50, & 
         615.33, 525.09, 583.35, 715.23, 767.53, 739.10, 664.05, 580.57, &
         572.85, 634.13, 648.77, 561.27, 497.72, 591.71, 737.83, 794.19, &
         802.51, 799.33, 735.79, 658.41, 659.47, 718.18, 761.67, 697.24, &
         545.14, 474.47, 526.96, 597.65, 584.74, 447.28, 291.35, 261.28, &
         330.26, 401.96, 466.32, 531.26, 572.34, 584.86, 585.17, 569.46, &
         558.27, 559.41, 512.02, 426.37, 378.14, 398.26, 473.49, 542.18, &
         531.76, 437.48, 341.85, 305.82, 299.88, 328.12, 440.04, 586.46, &
         660.32, 625.22, 510.26, 418.85, 447.36, 534.89, 605.86, 667.07, &
         687.31, 636.79, 549.63, 472.88, 419.53, 370.06, 327.98, 320.49, &
         354.00, 399.17, 450.98, 528.34, 608.25, 696.07, 774.28, 760.75, &
         690.58, 648.20, 580.63, 477.96, 453.91, 488.74, 464.02, 421.59, &
         444.32, 446.59, 375.95, 342.13, 397.49, 510.97, 646.38, 725.14, &
         703.06, 639.06, 619.10, 654.66, 665.99, 611.40, 580.22, 607.29, &
         591.05, 542.30, 583.82, 673.02, 673.21, 582.44, 465.73, 377.25, &
         377.04, 487.27, 607.93, 617.52, 583.46, 601.68, 615.94, 575.47, &
         541.63, 542.06, 522.28, 472.49, 423.29, 438.09, 556.72, 664.34, &
         669.88, 657.45, 684.71, 705.70, 683.11, 600.81, 509.90, 497.64/)

!    solar spectrum from  34160 to  35590 cm-1,  in steps of 10 cm-
    solarb(577:720)=(/ &
         511.07, 496.07, 500.32, 518.70, 529.91, 563.00, 609.20, 626.49, &
         622.11, 615.72, 600.44, 591.26, 598.12, 593.07, 590.94, 631.58, &
         696.48, 718.48, 676.11, 631.56, 619.64, 620.53, 624.10, 636.56, &
         658.02, 688.78, 724.81, 742.60, 722.31, 675.86, 665.96, 704.73, &
         703.70, 645.00, 598.26, 587.77, 590.94, 575.93, 528.03, 477.92, &
         457.52, 456.80, 454.91, 448.65, 445.47, 445.38, 444.43, 446.04, &
         455.91, 468.02, 454.34, 393.32, 301.22, 211.44, 167.11, 193.99, &
         254.01, 305.35, 353.03, 385.08, 387.03, 391.60, 406.20, 415.34, &
         435.34, 469.77, 492.15, 472.73, 409.86, 353.25, 340.68, 355.27, &
         379.77, 401.81, 409.67, 406.89, 393.16, 378.89, 375.20, 373.52, &
         360.19, 322.79, 273.55, 237.76, 212.33, 184.80, 156.20, 127.75, &
         96.269, 68.806, 62.047, 77.143, 100.47, 127.56, 159.88, 194.05, &
         225.20, 254.64, 285.75, 300.14, 294.40, 308.92, 340.83, 346.26, &
         336.29, 347.54, 373.81, 388.78, 372.68, 325.29, 294.40, 317.56, &
         360.30, 378.08, 374.22, 374.03, 383.34, 387.88, 377.55, 356.96, &
         340.67, 328.71, 314.00, 316.91, 344.51, 355.54, 335.66, 318.68, &
         318.65, 322.43, 318.61, 304.92, 284.84, 268.13, 265.80, 273.55, &
         274.18, 252.38, 215.04, 188.60, 181.31, 181.31, 180.78, 175.24 /)

!    solar spectrum from  35600 to  37030 cm-1,  in steps of 10 cm-
    solarb(721:864)=(/ &
         162.06, 145.08, 128.76, 113.76, 98.078, 83.072, 76.222, 78.359, &
         78.434, 74.235, 75.843, 80.321, 77.859, 70.298, 64.651, 67.049, &
         77.810, 83.167, 75.286, 71.202, 80.549, 92.008, 100.17, 108.63, &
         119.44, 130.78, 142.31, 158.94, 177.12, 186.40, 186.60, 181.47, &
         175.30, 175.54, 179.00, 177.04, 172.60, 172.67, 178.98, 193.77, &
         215.13, 233.62, 252.05, 277.68, 298.91, 298.40, 280.81, 274.21, &
         286.52, 285.46, 259.71, 241.39, 246.98, 259.87, 274.27, 298.47, &
         316.85, 303.19, 263.69, 229.31, 227.90, 256.12, 281.58, 300.19, &
         310.56, 279.54, 211.93, 152.18, 129.94, 147.47, 181.62, 215.37, &
         239.50, 233.12, 191.55, 139.41, 110.51, 118.93, 134.79, 129.05, &
         124.39, 143.53, 158.29, 141.84, 116.32, 111.59, 128.93, 149.17, &
         153.44, 145.63, 148.52, 159.25, 155.84, 154.17, 177.28, 203.40, &
         207.35, 205.27, 222.85, 253.18, 271.28, 279.27, 302.17, 321.47, &
         288.83, 230.14, 206.40, 213.22, 216.49, 207.46, 196.20, 195.21, &
         202.03, 194.33, 164.86, 136.65, 123.87, 128.14, 161.89, 216.99, &
         253.68, 249.26, 222.89, 213.11, 243.64, 293.10, 309.42, 286.40, &
         269.61, 272.23, 271.67, 265.84, 265.61, 264.77, 266.03, 289.51, &
         325.67, 337.34, 321.17, 300.30, 282.60, 287.14, 322.06, 335.79 /)

!    solar spectrum from  37040 to  38470 cm-1,  in steps of 10 cm-
    solarb(865:1008)=(/ &
         297.22, 254.10, 243.47, 239.49, 219.32, 211.94, 239.28, 271.43,  &
         279.37, 272.26, 264.77, 250.52, 229.93, 222.15, 235.30, 256.79,  &
         275.28, 286.92, 284.85, 269.52, 255.05, 253.46, 263.22, 274.78,  &
         279.19, 270.17, 249.41, 229.04, 221.64, 231.38, 252.70, 280.64,  &
         310.06, 328.33, 325.01, 290.26, 238.97, 223.38, 257.24, 282.60,  &
         264.32, 243.34, 253.18, 272.89, 271.32, 256.12, 260.24, 271.35,  &
         257.11, 236.61, 238.72, 248.92, 255.90, 272.04, 291.78, 297.40,  &
         288.09, 283.28, 292.92, 301.74, 309.07, 322.05, 320.42, 295.43,  &
         269.65, 254.41, 240.88, 228.18, 221.23, 213.72, 201.23, 197.17,  &
         212.29, 233.39, 247.65, 261.74, 286.17, 322.49, 349.47, 338.28,  &
         297.06, 261.55, 252.28, 264.65, 286.92, 298.94, 280.45, 244.37,  &
         213.47, 193.03, 182.07, 168.54, 143.12, 114.10, 89.615, 73.589,  &
         73.990, 87.912, 96.265, 94.813, 96.604, 102.30, 102.15, 103.07,  &
         117.81, 137.41, 146.09, 144.28, 137.89, 128.11, 122.82, 128.19,  &
         130.66, 117.31, 98.912, 93.397, 105.63, 122.73, 126.39, 113.05,  &
         92.317, 76.340, 69.032, 66.324, 71.280, 87.431, 105.94, 114.02,  &
         107.91, 91.872, 75.208, 69.123, 75.930, 90.928, 109.71, 125.70,  &
         135.79, 141.14, 138.14, 121.33, 91.806, 63.497, 52.106, 59.555  /)

!    solar spectrum from  38480 to  39910 cm-1,  in steps of 10 cm-
    solarb(1009:1152)=(/ &
         81.015, 106.67, 118.97, 116.36, 110.82, 100.88, 89.056, 90.431, &
         104.41, 114.95, 124.85, 148.87, 171.72, 167.22, 142.25, 118.42, &
         98.653, 78.908, 68.133, 77.286, 100.93, 120.08, 125.49, 131.79, &
         155.69, 180.75, 181.81, 166.77, 150.06, 133.24, 116.14, 97.728, &
         81.629, 76.695, 87.607, 110.23, 134.88, 149.13, 147.64, 139.88, &
         135.19, 135.07, 138.00, 136.73, 128.84, 122.22, 120.48, 121.98, &
         123.08, 116.30, 101.43, 86.303, 74.719, 68.800, 71.327, 80.626, &
         90.485, 96.739, 100.69, 100.81, 93.677, 84.740, 81.532, 82.893, &
         84.564, 87.584, 91.780, 91.272, 87.014, 87.386, 90.149, 84.917, &
         71.266, 57.873, 51.863, 53.876, 57.909, 58.508, 57.020, 57.432, &
         60.671, 64.667, 67.362, 67.511, 64.233, 59.035, 55.697, 56.636, &
         59.400, 59.070, 56.522, 55.834, 55.860, 54.039, 51.976, 52.344, &
         54.667, 56.450, 56.751, 56.769, 58.002, 60.029, 59.602, 53.134, &
         42.926, 35.588, 33.447, 35.171, 39.379, 44.371, 47.745, 46.933, &
         42.441, 37.879, 35.595, 36.458, 41.048, 47.300, 51.098, 50.024, &
         45.331, 41.282, 40.082, 40.000, 39.104, 37.329, 36.632, 37.792, &
         39.189, 41.058, 45.214, 50.737, 54.281, 55.015, 56.138, 60.931, &
         67.383, 69.534, 65.159, 56.372, 47.326, 44.322, 49.944, 59.696 /)

!    solar spectrum from  39920 to  41350 cm-1,  in steps of 10 cm-
    solarb(1153:1296)=(/ &
         67.929, 71.334, 69.905, 65.620, 59.303, 54.016, 55.880, 65.155, &
         74.065, 76.217, 73.506, 71.406, 70.849, 69.749, 69.268, 71.380, &
         72.721, 68.929, 61.665, 54.896, 47.420, 38.325, 32.219, 31.243, &
         33.310, 35.358, 35.623, 36.840, 41.551, 47.499, 51.176, 50.344, &
         45.362, 38.341, 33.130, 33.801, 40.140, 49.121, 55.385, 55.174, &
         50.450, 46.511, 47.495, 51.883, 56.354, 59.603, 61.584, 63.215, &
         64.603, 64.101, 59.027, 50.956, 47.633, 52.543, 58.883, 59.829, &
         57.617, 56.727, 57.371, 57.898, 57.177, 55.129, 52.952, 52.018, &
         52.186, 52.044, 50.269, 46.592, 42.515, 40.755, 41.887, 44.119, &
         46.536, 48.858, 50.490, 51.919, 54.085, 54.707, 51.927, 49.449, &
         49.865, 50.933, 50.496, 48.616, 46.717, 46.070, 46.263, 46.733, &
         48.009, 50.187, 52.420, 53.536, 52.507, 51.380, 53.214, 56.985, &
         60.614, 63.139, 63.999, 63.869, 65.100, 69.385, 74.743, 78.184, &
         78.103, 74.113, 67.371, 60.849, 58.924, 62.682, 68.032, 69.117, &
         64.604, 59.110, 55.998, 56.838, 61.778, 65.874, 65.079, 63.038, &
         64.809, 69.911, 74.841, 76.439, 73.587, 68.853, 67.497, 72.675, &
         80.602, 83.422, 78.957, 72.228, 66.737, 62.842, 61.535, 63.574, &
         69.248, 76.577, 79.922, 77.755, 73.938, 70.518, 68.003, 66.339 /)

!    solar spectrum from  41360 to  42790 cm-1,  in steps of 10 cm-
    solarb(1297:1440)=(/ &
         63.979, 61.098, 59.421, 58.103, 55.741, 52.549, 48.079, 42.578, &
         38.373, 37.297, 37.455, 34.861, 30.483, 29.634, 34.734, 42.460, &
         47.066, 45.848, 40.157, 34.290, 31.584, 30.650, 29.054, 27.788, &
         30.427, 37.570, 44.196, 46.880, 47.848, 49.166, 49.180, 45.002, &
         38.135, 35.055, 38.095, 41.750, 40.899, 35.722, 28.884, 24.835, &
         28.670, 39.646, 50.310, 55.725, 57.401, 58.110, 59.406, 59.360, &
         53.420, 43.004, 34.787, 33.697, 39.682, 47.554, 52.605, 53.632, &
         51.001, 45.266, 37.844, 31.030, 25.936, 22.799, 21.882, 23.484, &
         27.857, 33.447, 37.319, 39.195, 42.826, 50.398, 58.752, 63.301, &
         61.094, 53.532, 46.046, 41.118, 37.646, 36.304, 40.426, 50.893, &
         61.553, 65.395, 62.680, 58.087, 54.622, 51.330, 46.874, 42.870, &
         40.547, 39.760, 40.217, 40.359, 39.559, 40.667, 46.260, 53.413, &
         56.041, 52.566, 46.674, 41.073, 35.511, 31.231, 31.082, 35.955, &
         45.199, 55.464, 61.802, 63.505, 61.850, 56.412, 49.388, 46.369, &
         50.058, 56.694, 60.884, 61.030, 58.107, 54.303, 51.940, 50.508, &
         46.749, 39.155, 31.535, 28.959, 30.973, 32.670, 31.567, 29.340, &
         27.275, 25.184, 24.264, 27.068, 34.296, 42.475, 47.230, 47.425, &
         44.435, 40.538, 36.868, 33.020, 29.405, 28.753, 34.079, 44.246 /)

!    solar spectrum from  42800 to  44230 cm-1,  in steps of 10 cm-
    solarb(1441:1584)=(/ &
         53.780, 57.974, 56.376, 51.200, 45.308, 40.273, 35.900, 33.344, &
         34.011, 36.858, 41.283, 47.374, 53.088, 56.201, 55.633, 50.843, &
         43.997, 38.767, 36.248, 36.380, 40.762, 50.700, 63.371, 73.432, &
         76.418, 70.373, 58.741, 47.034, 38.598, 34.664, 35.794, 42.084, &
         49.973, 54.338, 53.956, 52.287, 52.778, 55.571, 59.034, 60.268, &
         56.247, 47.362, 38.056, 32.889, 31.739, 31.734, 32.476, 35.060, &
         39.091, 43.398, 48.131, 53.574, 58.749, 63.599, 68.971, 73.421, &
         73.861, 69.003, 60.557, 51.865, 44.879, 42.060, 44.802, 47.950, &
         46.882, 42.973, 39.293, 37.711, 37.137, 35.222, 32.243, 30.488, &
         32.605, 40.429, 51.099, 57.710, 57.150, 52.992, 50.275, 49.986, &
         49.778, 48.371, 46.421, 44.604, 42.730, 41.244, 41.565, 43.805, &
         47.013, 48.992, 46.428, 40.595, 37.840, 42.353, 52.248, 60.529, &
         61.566, 56.800, 52.041, 52.260, 57.077, 61.019, 60.712, 57.048, &
         51.481, 46.352, 44.366, 44.947, 45.478, 44.944, 43.825, 42.105, &
         39.466, 36.826, 35.907, 36.357, 35.661, 33.947, 33.690, 34.429, &
         34.000, 32.645, 31.410, 30.281, 29.409, 29.127, 29.326, 29.869, &
         30.601, 31.311, 32.099, 32.779, 32.757, 32.098, 31.975, 33.484, &
         36.048, 39.169, 43.365, 47.244, 48.214, 45.786, 41.586, 38.775 /)

!    solar spectrum from  44240 to  45670 cm-1,  in steps of 10 cm-
    solarb(1585:1728)=(/ &
         40.753, 46.752, 51.684, 52.597, 51.449, 50.684, 49.450, 46.747, &
         45.369, 47.685, 50.240, 48.961, 46.693, 48.600, 53.694, 56.465, &
         54.341, 50.722, 49.877, 51.246, 52.088, 52.765, 56.254, 63.326, &
         69.744, 71.066, 68.349, 65.123, 62.551, 59.195, 53.705, 48.161, &
         46.236, 47.710, 49.660, 50.799, 51.836, 54.537, 59.647, 64.707, &
         65.844, 61.634, 55.570, 54.083, 58.781, 64.888, 69.777, 74.008, &
         76.492, 76.226, 74.746, 74.941, 77.801, 79.619, 76.190, 67.190, &
         55.231, 45.813, 43.141, 45.647, 49.466, 52.231, 52.221, 48.886, &
         44.716, 42.613, 43.385, 45.968, 48.121, 48.998, 49.885, 50.707, &
         49.893, 48.319, 48.198, 50.280, 53.830, 55.914, 54.822, 52.939, &
         51.944, 49.438, 42.956, 34.614, 28.100, 24.503, 24.203, 27.839, &
         34.604, 41.615, 45.324, 45.444, 45.527, 47.179, 45.756, 36.862, &
         26.037, 20.569, 20.329, 24.263, 30.863, 35.939, 36.711, 35.693, &
         37.256, 40.862, 44.416, 48.800, 54.182, 57.655, 58.427, 59.965, &
         63.940, 66.820, 65.465, 59.482, 49.396, 39.422, 34.182, 35.388, &
         42.875, 52.034, 57.595, 59.093, 57.272, 52.172, 45.493, 39.419, &
         35.581, 35.902, 40.354, 46.732, 53.309, 58.781, 61.785, 59.255, &
         50.030, 41.567, 40.523, 43.584, 44.875, 42.754, 40.077, 39.941 /)

!    solar spectrum from  45680 to  47110 cm-1,  in steps of 10 cm-
    solarb(1729:1872)=(/ &
         40.977, 39.567, 34.955, 30.424, 31.039, 38.687, 47.480, 49.830, &
         46.790, 44.829, 46.546, 50.415, 54.602, 57.656, 58.463, 57.276, &
         55.621, 54.514, 53.338, 50.026, 42.817, 33.636, 27.134, 25.516, &
         27.897, 31.392, 32.125, 29.463, 26.581, 25.956, 27.737, 31.175, &
         34.959, 37.671, 38.641, 37.958, 36.733, 35.681, 33.877, 30.849, &
         28.059, 27.615, 29.319, 29.375, 25.390, 20.659, 19.484, 22.297, &
         27.282, 32.467, 35.906, 37.137, 37.895, 39.130, 39.777, 39.872, &
         40.778, 42.317, 42.934, 40.430, 34.227, 27.701, 23.880, 22.174, &
         21.639, 22.589, 25.184, 29.017, 32.981, 36.110, 38.580, 41.239, &
         44.426, 46.939, 47.010, 44.165, 39.659, 35.556, 32.838, 31.546, &
         32.676, 36.963, 42.333, 44.931, 43.704, 40.943, 37.973, 35.199, &
         33.574, 33.339, 34.185, 36.347, 39.963, 43.964, 47.162, 48.987, &
         48.976, 47.948, 48.004, 49.892, 51.065, 47.834, 40.489, 32.665, &
         26.795, 24.461, 26.655, 31.928, 37.634, 41.345, 40.956, 36.827, &
         32.110, 28.612, 26.482, 26.602, 28.831, 30.877, 30.976, 30.063, &
         29.887, 30.305, 29.974, 28.265, 26.517, 27.066, 30.403, 34.539, &
         37.104, 37.598, 37.252, 37.060, 36.498, 34.167, 29.814, 24.192, &
         18.515, 15.086, 15.040, 17.158, 20.807, 25.682, 30.352, 34.203 /)

!    solar spectrum from  47120 to  48550 cm-1,  in steps of 10 cm-
    solarb(1873:2016)=(/ &
         37.902, 42.531, 47.832, 50.509, 48.019, 42.616, 38.321, 37.370, &
         40.172, 44.395, 46.132, 43.911, 38.396, 31.379, 26.275, 25.075, &
         26.652, 28.963, 31.168, 34.168, 38.050, 40.231, 38.347, 32.741, &
         26.199, 21.863, 20.249, 20.185, 21.726, 25.562, 30.318, 33.431, &
         34.453, 34.959, 36.374, 37.870, 36.655, 31.966, 25.920, 21.264, &
         20.663, 24.658, 30.263, 34.021, 34.336, 31.356, 26.926, 23.109, &
         20.867, 20.684, 22.416, 24.878, 26.779, 27.334, 26.537, 25.210, &
         24.013, 22.944, 21.800, 20.449, 19.290, 19.528, 21.742, 24.125, &
         23.994, 21.559, 19.555, 18.915, 18.342, 17.335, 16.549, 16.479, &
         17.211, 18.445, 19.294, 18.980, 17.912, 17.156, 17.103, 17.256, &
         16.925, 15.842, 14.485, 13.683, 13.647, 13.914, 14.009, 13.770, &
         13.456, 13.399, 13.547, 13.760, 14.060, 14.427, 14.644, 14.438, &
         13.986, 13.749, 13.927, 14.390, 14.759, 14.822, 14.679, 14.448, &
         14.186, 13.937, 13.754, 13.657, 13.540, 13.308, 13.053, 12.841, &
         12.704, 12.742, 12.811, 12.662, 12.355, 12.100, 12.003, 12.014, &
         12.067, 12.223, 12.444, 12.472, 12.164, 11.732, 11.515, 11.619, &
         11.873, 12.028, 11.947, 11.722, 11.399, 10.930, 10.473, 10.205, &
         10.224, 10.694, 11.468, 12.007, 12.083, 11.905, 11.498, 10.891 /)

!   solar spectrum from  48560 to  49990 cm-1,  in steps of 10 cm-
    solarb(2017:2160)=(/ &
         10.575, 10.846, 11.353, 11.612, 11.411, 10.876, 10.383, 10.305, &
         10.695, 11.245, 11.636, 11.828, 11.918, 11.865, 11.674, 11.510, &
         11.407, 11.303, 11.216, 11.143, 11.039, 10.983, 11.004, 10.900, &
         10.653, 10.562, 10.781, 11.186, 11.605, 11.806, 11.582, 11.056, &
         10.567, 10.335, 10.408, 10.729, 11.165, 11.540, 11.646, 11.372, &
         10.933, 10.524, 9.9973, 9.3783, 8.9883, 9.0163, 9.4125, 9.9179, &
         10.278, 10.472, 10.553, 10.575, 10.519, 10.216, 9.6821, 9.1499, &
         8.7057, 8.3894, 8.3442, 8.6241, 9.1371, 9.7184, 10.191, 10.443, &
         10.458, 10.289, 9.9772, 9.5829, 9.3097, 9.3195, 9.4694, 9.5182, &
         9.4326, 9.2478, 8.8197, 7.9809, 6.9996, 6.4856, 6.7462, 7.5406, &
         8.2813, 8.7258, 9.0682, 9.1665, 8.8637, 8.4638, 8.2393, 8.1656, &
         8.1880, 8.3578, 8.6488, 8.8980, 9.0117, 9.0659, 9.1955, 9.4207, &
         9.5526, 9.4237, 9.1290, 8.8441, 8.6138, 8.4237, 8.2979, 8.2598, &
         8.2859, 8.3475, 8.4533, 8.6285, 8.8310, 8.8866, 8.6750, 8.3312, &
         8.0091, 7.7296, 7.6239, 7.8692, 8.2725, 8.4086, 8.2515, 8.0914, &
         8.0003, 7.9367, 7.9266, 7.9580, 8.0492, 8.2376, 8.4263, 8.4811, &
         8.3309, 8.0263, 7.7632, 7.6987, 7.8124, 7.9390, 8.0183, 8.0816, &
         8.0428, 7.8923, 7.6963, 7.4969, 7.4013, 7.4289, 7.4489, 7.4059 /)

!    solar spectrum from  50000 to  51430 cm-1,  in steps of 10 cm-
    solarb(2161:2304)=(/ &
         7.4198, 7.5261, 7.5252, 7.3239, 7.1263, 7.1423, 7.3340, 7.5049, &
         7.5484, 7.5319, 7.5163, 7.4995, 7.5728, 7.8104, 8.0588, 8.0948, &
         7.9140, 7.6978, 7.5116, 7.2138, 6.8063, 6.5430, 6.5232, 6.5869, &
         6.5610, 6.3984, 6.1889, 6.0587, 6.0676, 6.1988, 6.3140, 6.2527, &
         6.0929, 6.0277, 6.0941, 6.3031, 6.6594, 6.9398, 6.9566, 6.8310, &
         6.7374, 6.6812, 6.6558, 6.8336, 7.2020, 7.4012, 7.2950, 7.0488, &
         6.7966, 6.6293, 6.5868, 6.5980, 6.6007, 6.6501, 6.7627, 6.7853, &
         6.6321, 6.4856, 6.5198, 6.6486, 6.7271, 6.7227, 6.6696, 6.6189, &
         6.5979, 6.6188, 6.7110, 6.8343, 6.8750, 6.8250, 6.7885, 6.8266, &
         6.8556, 6.8068, 6.8377, 7.0467, 7.2779, 7.4139, 7.4712, 7.4621, &
         7.4071, 7.3592, 7.3372, 7.3220, 7.2938, 7.2531, 7.2052, 7.1335, &
         7.0298, 6.8533, 6.5535, 6.2227, 6.0139, 5.9384, 5.9038, 5.8568, &
         5.7909, 5.7326, 5.7745, 5.9608, 6.1865, 6.3681, 6.4997, 6.5437, &
         6.4637, 6.2708, 6.0451, 5.9557, 6.0855, 6.2542, 6.2454, 6.0795, &
         5.9102, 5.8447, 5.9218, 6.1063, 6.2895, 6.3271, 6.1097, 5.7421, &
         5.4452, 5.2981, 5.3256, 5.4935, 5.6819, 5.8245, 5.8933, 5.9630, &
         6.1703, 6.4525, 6.6325, 6.6965, 6.7185, 6.6238, 6.3107, 5.9241, &
         5.6987, 5.6651, 5.7428, 5.8790, 5.9715, 5.9618, 5.9674, 6.0754 /)

!    solar spectrum from  51440 to  52870 cm-1,  in steps of 10 cm-
    solarb(2305:2448)=(/ &
         6.2541, 6.4300, 6.4968, 6.4564, 6.4082, 6.3024, 6.0135, 5.6431, &
         5.3963, 5.2989, 5.2635, 5.2227, 5.1279, 4.9315, 4.6348, 4.3168, &
         4.0151, 3.6625, 3.2906, 3.1028, 3.1349, 3.1994, 3.2596, 3.4144, &
         3.5949, 3.6534, 3.6296, 3.6281, 3.5876, 3.4292, 3.2659, 3.2284, &
         3.2576, 3.3002, 3.4535, 3.7372, 4.0573, 4.3558, 4.5999, 4.7781, &
         4.8855, 4.8999, 4.8392, 4.7624, 4.7059, 4.6981, 4.7666, 4.8453, &
         4.8236, 4.7293, 4.6861, 4.7132, 4.7725, 4.8713, 4.9596, 4.9527, &
         4.8957, 4.9252, 5.0736, 5.2229, 5.2505, 5.1537, 5.0156, 4.8880, &
         4.7686, 4.6549, 4.5534, 4.4828, 4.4661, 4.5040, 4.5905, 4.7033, &
         4.7858, 4.8334, 4.9283, 5.0377, 5.0065, 4.8471, 4.6828, 4.5586, &
         4.4812, 4.4314, 4.3903, 4.3830, 4.4066, 4.3900, 4.2973, 4.1978, &
         4.1462, 4.1084, 4.1495, 4.3897, 4.6859, 4.8206, 4.7938, 4.6781, &
         4.5222, 4.3959, 4.3358, 4.2947, 4.2259, 4.1452, 4.1060, 4.1462, &
         4.2149, 4.2549, 4.3061, 4.3742, 4.3738, 4.2718, 4.1389, 4.0405, &
         3.9457, 3.8127, 3.7099, 3.7344, 3.8589, 3.9598, 3.9525, 3.8377, &
         3.6708, 3.5357, 3.4929, 3.5375, 3.6381, 3.7890, 3.9671, 4.0995, &
         4.1421, 4.1302, 4.1235, 4.1623, 4.2506, 4.2948, 4.2231, 4.0993, &
         3.9680, 3.9475, 4.1958, 4.5131, 4.6101, 4.5130, 4.3474, 4.1749 /)

!    solar spectrum from  52880 to  54310 cm-1,  in steps of 10 cm-
    solarb(2449:2592)=(/ &
         4.0467, 3.9956, 4.0078, 4.0374, 4.0255, 3.9379, 3.8192, 3.7529, &
         3.7675, 3.8260, 3.8654, 3.8518, 3.8148, 3.8028, 3.8098, 3.7934, &
         3.7660, 3.7944, 3.8689, 3.8978, 3.8856, 3.8923, 3.8570, 3.6940, &
         3.4693, 3.3222, 3.2824, 3.2887, 3.3039, 3.3222, 3.3313, 3.3326, &
         3.3482, 3.3807, 3.4188, 3.4602, 3.4972, 3.5151, 3.5155, 3.5165, &
         3.5258, 3.5406, 3.5478, 3.5345, 3.5339, 3.5820, 3.6396, 3.6448, &
         3.5872, 3.5112, 3.4804, 3.5257, 3.6238, 3.7290, 3.8023, 3.8024, &
         3.7268, 3.6578, 3.6439, 3.6422, 3.6373, 3.6397, 3.6410, 3.6494, &
         3.6608, 3.6251, 3.5212, 3.4020, 3.2845, 3.1230, 2.9483, 2.8515, &
         2.8432, 2.8638, 2.8967, 2.9505, 3.0025, 3.0552, 3.1106, 3.1178, &
         3.0596, 2.9854, 2.9316, 2.8903, 2.8590, 2.8500, 2.8450, 2.8121, &
         2.7626, 2.7424, 2.7667, 2.8024, 2.8165, 2.8111, 2.8128, 2.8569, &
         2.9659, 3.1062, 3.1990, 3.2128, 3.2088, 3.2391, 3.2661, 3.2364, &
         3.1173, 2.9094, 2.6952, 2.5324, 2.3959, 2.2953, 2.2510, 2.2245, &
         2.1811, 2.1301, 2.1482, 2.3257, 2.5856, 2.7226, 2.6495, 2.4508, &
         2.2444, 2.0850, 1.9891, 1.9843, 2.0816, 2.2233, 2.3248, 2.3551, &
         2.3479, 2.3606, 2.4296, 2.5361, 2.6128, 2.6216, 2.6069, 2.6196, &
         2.6464, 2.6427, 2.5823, 2.4682, 2.3320, 2.2405, 2.2637, 2.3973 /)

!    solar spectrum from  54320 to  55750 cm-1,  in steps of 10 cm-
    solarb(2593:2736)=(/ &
         2.5524, 2.6891, 2.8508, 3.0103, 3.0681, 3.0064, 2.9114, 2.8609, &
         2.8517, 2.8374, 2.7894, 2.7288, 2.7138, 2.7729, 2.8707, 2.9536, &
         2.9953, 2.9911, 2.9398, 2.8550, 2.7732, 2.7303, 2.7366, 2.7650, &
         2.7705, 2.7374, 2.6830, 2.6218, 2.5663, 2.5341, 2.5351, 2.5681, &
         2.6124, 2.6305, 2.6024, 2.5431, 2.4840, 2.4546, 2.4684, 2.5100, &
         2.5445, 2.5532, 2.5564, 2.5889, 2.6616, 2.7553, 2.8466, 2.9290, &
         2.9958, 3.0175, 2.9774, 2.8990, 2.8001, 2.6927, 2.6171, 2.5931, &
         2.5809, 2.5276, 2.4284, 2.3365, 2.3162, 2.3855, 2.4872, 2.5455, &
         2.5773, 2.6809, 2.9720, 3.5757, 4.4006, 5.0044, 5.0295, 4.5135, &
         3.7071, 2.9059, 2.3600, 2.1418, 2.1119, 2.0871, 2.0301, 2.0043, &
         2.0361, 2.0963, 2.1520, 2.1878, 2.1955, 2.1864, 2.1899, 2.2170, &
         2.2574, 2.2895, 2.2783, 2.2148, 2.1641, 2.2343, 2.4726, 2.8119, &
         3.1288, 3.2984, 3.2206, 2.8859, 2.4473, 2.1436, 2.0729, 2.1391, &
         2.2171, 2.2580, 2.2654, 2.2481, 2.2103, 2.1657, 2.1356, 2.1321, &
         2.1438, 2.1461, 2.1396, 2.1460, 2.1588, 2.1581, 2.1481, 2.1343, &
         2.1101, 2.0754, 2.0400, 2.0121, 1.9930, 1.9799, 1.9699, 1.9613, &
         1.9537, 1.9454, 1.9312, 1.9058, 1.8726, 1.8470, 1.8465, 1.8693, &
         1.8844, 1.8635, 1.8143, 1.7618, 1.7188, 1.6853, 1.6656, 1.6708 /)

!    solar spectrum from  55760 to  57190 cm-1,  in steps of 10 cm-
    solarb(2737:2880)=(/ &
         1.7036, 1.7519, 1.8120, 1.9015, 2.0124, 2.0980, 2.1385, 2.1481, &
         2.1347, 2.1086, 2.0953, 2.1062, 2.1095, 2.0685, 2.0001, 1.9461, &
         1.9194, 1.9088, 1.9023, 1.8977, 1.9049, 1.9300, 1.9588, 1.9635, &
         1.9357, 1.9019, 1.8887, 1.8939, 1.9018, 1.9038, 1.8975, 1.8747, &
         1.8289, 1.7716, 1.7303, 1.7330, 1.7900, 1.8782, 1.9548, 1.9907, &
         1.9807, 1.9430, 1.9173, 1.9218, 1.9203, 1.8717, 1.7832, 1.6965, &
         1.6389, 1.6077, 1.5924, 1.5818, 1.5583, 1.5142, 1.4616, 1.4237, &
         1.4252, 1.4834, 1.5970, 1.7410, 1.8771, 1.9784, 2.0451, 2.0872, &
         2.0909, 2.0384, 1.9573, 1.9002, 1.8824, 1.8663, 1.8193, 1.7540, &
         1.6874, 1.6222, 1.5726, 1.5450, 1.5290, 1.5312, 1.5699, 1.6411, &
         1.7186, 1.7678, 1.7546, 1.6623, 1.5115, 1.3588, 1.2605, 1.2348, &
         1.2611, 1.3091, 1.3588, 1.3884, 1.3800, 1.3482, 1.3224, 1.3159, &
         1.3437, 1.4142, 1.4950, 1.5443, 1.5521, 1.5282, 1.4902, 1.4606, &
         1.4465, 1.4398, 1.4399, 1.4544, 1.4760, 1.4781, 1.4506, 1.4229, &
         1.4185, 1.4221, 1.4119, 1.3908, 1.3779, 1.3813, 1.3933, 1.4087, &
         1.4268, 1.4417, 1.4408, 1.4188, 1.3861, 1.3548, 1.3261, 1.2980, &
         1.2769, 1.2731, 1.2856, 1.3002, 1.3056, 1.2987, 1.2817, 1.2590, &
         1.2291, 1.1868, 1.1428, 1.1183, 1.1141, 1.1120, 1.1009, 1.0797 /)

!    solar spectrum from  57200 to  57490 cm-1,  in steps of 10 cm-
    solarb(2881:2910)=(/ &
         1.0523, 1.0284, 1.0251, 1.0577, 1.1195, 1.1791, 1.2061, 1.2013, &
         1.1936, 1.2000, 1.2040, 1.1824, 1.1489, 1.1400, 1.1539, 1.1629, &
         1.1617, 1.1586, 1.1564, 1.1572, 1.1565, 1.1399, 1.1037, 1.0627, &
         1.0341, 1.0223, 1.0199, 1.0188, 1.0174, 1.0163  /)
  end subroutine solar
end module sundat

function sunir(v)
!--- history
! 92. 4.24  registered from lowtran-7
! 03. 9. 9 Changed for free source form (Fortran 90) by M. Sekiguchi 
!--- input
! v        r        wavenumber (cm-1) 0 to 57490 cm-1
!--- output
! sunir    rf       the extra-terrestrial solar irradiance (watt/m2/micron)
!                   if 0 then v is out of range
!--  uses  block data solar   which contains the values for solara +
!
  use sundat, only: solara,solarb,solar
  implicit none
  real(8),intent(in)::v
  integer::i
  real(8)::p,wm,w0,w1,w2
  real(8),parameter::a=3.50187d-13,b=3.93281
  real(8)::sunir
!--exec
!     wm, w0, w1, w2  are statement functions used by
!     the 4 point lagrange interpolation
  wm(p) = p*(p - 1)*(p - 2)
  w0(p) = 3*(p**2 - 1)*(p - 2)
  w1(p) = 3*p*(p + 1)*(p - 2)
  w2(p) = p*(p**2 - 1)

  call solar(solara,solarb)

!     if  v  is too small,  write warning  +  return sunir = 0
  if(v < 0.0) then
     sunir = 0.0
     write(6, 900) v
     return

  elseif( v >= 0.0  .and.  v < 100.0 ) then
!     for low frequencies use a power law approximation
     sunir = a*v**b
     return
     
  elseif( v >= 100.0  .and.  v <= 28420.0 ) then
!     use  4 point interpolation  on  array  solara
!     which is at  20 cm-1  spacing  from 0 to 28720 cm-1
     i = 1 + int(v/20.0)
     p = (mod(int(v),20)+(v-int(v)))/20.0
     sunir = ( w2(p)*solara(i+2) - w1(p)*solara(i+1) + &
          w0(p)*solara(i) - wm(p)*solara(i-1) ) / 6.
     return

  elseif( v >= 28420.0  .and.  v <= 57470.0 ) then
!     use  4 point interpolation  on  array  solarb
!     which is at  10 cm-1  spacing  from 28400 to 57490 cm-1
     i = int(v/10.0) - 2839
     p = (mod(int(v),10)+(v-int(v)))/10.0
     sunir = ( w2(p)*solarb(i+2) - w1(p)*solarb(i+1) + &
          w0(p)*solarb(i) - wm(p)*solarb(i-1) ) / 6.
     return
!
  elseif( v > 57470.0 ) then
!     if  v  is too large,  write warning  +  return sunir = 0
     sunir = 0.0
     write(6, 900) v
     return
  endif

  return
900 format('0 *****  warning - input frequency = ', 1pg12.5, 'cm-1', &
         /, '   outside valid range of 0 to 57470 cm-1    *******', / )
end function sunir
module sundat2
  implicit none
  real(8),save:: wnc(8213),solarc(8213)

contains
  subroutine solar2(wnc,solarc)
    real(8)::wnc(8213), solarc(8213)
    wnc( 1: 240)=(/ &
          199.12d0,  199.48d0,  199.84d0,  200.20d0,  200.56d0,  200.92d0, &
          201.29d0,  201.65d0,  202.01d0,  202.37d0,  202.73d0,  203.09d0, &
          203.45d0,  203.81d0,  204.17d0,  204.53d0,  204.89d0,  205.24d0, &
          205.60d0,  205.96d0,  206.32d0,  206.68d0,  207.04d0,  207.40d0, &
          207.75d0,  208.11d0,  208.47d0,  208.83d0,  209.19d0,  209.54d0, &
          209.90d0,  210.26d0,  210.61d0,  210.97d0,  211.33d0,  211.68d0, &
          212.04d0,  212.40d0,  212.75d0,  213.11d0,  213.46d0,  213.82d0, &
          214.17d0,  214.53d0,  214.88d0,  215.24d0,  215.59d0,  215.95d0, &
          216.30d0,  216.66d0,  217.01d0,  217.37d0,  217.72d0,  218.07d0, &
          218.43d0,  218.78d0,  219.13d0,  219.49d0,  219.84d0,  220.19d0, &
          220.54d0,  220.90d0,  221.25d0,  221.60d0,  221.95d0,  222.31d0, &
          222.66d0,  223.01d0,  223.36d0,  223.71d0,  224.06d0,  224.41d0, &
          224.76d0,  225.11d0,  225.47d0,  225.82d0,  226.17d0,  226.52d0, &
          226.87d0,  227.22d0,  227.56d0,  227.91d0,  228.26d0,  228.61d0, &
          228.96d0,  229.31d0,  229.66d0,  230.01d0,  230.36d0,  230.70d0, &
          231.05d0,  231.40d0,  231.75d0,  232.09d0,  232.44d0,  232.79d0, &
          233.14d0,  233.48d0,  233.83d0,  234.18d0,  234.52d0,  234.87d0, &
          235.22d0,  235.56d0,  235.91d0,  236.25d0,  236.60d0,  236.94d0, &
          237.63d0,  237.98d0,  238.32d0,  238.67d0,  239.01d0,  239.36d0, &
          239.70d0,  240.05d0,  240.39d0,  240.73d0,  241.08d0,  241.42d0, &
          241.76d0,  242.11d0,  242.45d0,  243.14d0,  243.48d0,  243.82d0, &
          244.16d0,  244.50d0,  246.21d0,  246.55d0,  246.89d0,  247.24d0, &
          247.58d0,  247.92d0,  248.26d0,  248.60d0,  248.94d0,  249.28d0, &
          249.62d0,  249.96d0,  250.30d0,  250.64d0,  250.97d0,  251.31d0, &
          251.65d0,  251.99d0,  252.33d0,  252.67d0,  253.01d0,  253.34d0, &
          253.68d0,  254.02d0,  254.36d0,  254.70d0,  255.03d0,  255.37d0, &
          256.04d0,  256.38d0,  256.72d0,  257.05d0,  257.39d0,  257.73d0, &
          258.06d0,  258.40d0,  258.73d0,  259.07d0,  259.40d0,  259.74d0, &
          260.07d0,  260.41d0,  260.74d0,  261.08d0,  261.41d0,  261.75d0, &
          262.08d0,  262.41d0,  262.75d0,  263.08d0,  263.42d0,  263.75d0, &
          264.08d0,  264.41d0,  264.75d0,  265.08d0,  265.41d0,  265.75d0, &
          266.08d0,  266.41d0,  266.74d0,  267.07d0,  267.40d0,  267.74d0, &
          268.07d0,  268.40d0,  268.73d0,  269.06d0,  269.39d0,  269.72d0, &
          270.05d0,  270.38d0,  270.71d0,  271.04d0,  271.37d0,  271.70d0, &
          272.03d0,  272.36d0,  272.69d0,  273.02d0,  273.35d0,  273.68d0, &
          274.01d0,  274.33d0,  274.66d0,  274.99d0,  275.32d0,  275.65d0, &
          275.97d0,  276.30d0,  276.63d0,  276.96d0,  277.28d0,  277.61d0, &
          277.94d0,  278.26d0,  278.59d0,  278.92d0,  279.24d0,  279.57d0, &
          279.89d0,  280.22d0,  280.54d0,  280.87d0,  281.20d0,  281.52d0, &
          281.85d0,  282.17d0,  282.49d0,  282.82d0,  283.14d0,  283.47d0/)
 
    wnc( 241: 480)=(/ &
          283.79d0,  284.12d0,  284.44d0,  284.76d0,  285.09d0,  285.41d0, &
          285.73d0,  286.06d0,  286.38d0,  286.70d0,  287.02d0,  287.35d0, &
          287.67d0,  287.99d0,  288.31d0,  288.63d0,  288.95d0,  289.28d0, &
          289.60d0,  289.92d0,  290.24d0,  290.56d0,  290.88d0,  291.20d0, &
          291.52d0,  291.84d0,  292.16d0,  292.48d0,  292.80d0,  293.12d0, &
          293.44d0,  293.76d0,  294.08d0,  294.40d0,  294.72d0,  295.03d0, &
          295.35d0,  295.67d0,  295.99d0,  296.31d0,  296.63d0,  296.94d0, &
          297.26d0,  297.58d0,  297.90d0,  298.21d0,  298.53d0,  298.85d0, &
          299.16d0,  299.48d0,  299.80d0,  300.11d0,  300.43d0,  300.74d0, &
          301.06d0,  301.38d0,  301.69d0,  302.01d0,  302.32d0,  302.64d0, &
          302.95d0,  303.27d0,  303.58d0,  303.89d0,  304.21d0,  304.52d0, &
          304.84d0,  305.15d0,  305.46d0,  305.78d0,  306.09d0,  306.40d0, &
          306.72d0,  307.03d0,  307.34d0,  307.65d0,  307.97d0,  308.28d0, &
          308.59d0,  308.90d0,  309.22d0,  309.53d0,  309.84d0,  310.15d0, &
          310.46d0,  310.77d0,  311.08d0,  311.39d0,  311.70d0,  312.01d0, &
          312.32d0,  312.63d0,  312.94d0,  313.25d0,  313.56d0,  313.87d0, &
          314.18d0,  314.49d0,  314.80d0,  315.11d0,  315.42d0,  315.73d0, &
          316.03d0,  316.34d0,  316.65d0,  316.96d0,  317.27d0,  317.57d0, &
          317.88d0,  318.19d0,  318.50d0,  318.80d0,  319.11d0,  319.42d0, &
          319.72d0,  320.03d0,  320.34d0,  320.64d0,  320.95d0,  321.25d0, &
          321.56d0,  321.86d0,  322.17d0,  322.48d0,  322.78d0,  323.09d0, &
          323.39d0,  323.69d0,  324.00d0,  324.30d0,  324.61d0,  324.91d0, &
          325.22d0,  325.52d0,  325.82d0,  326.43d0,  326.73d0,  327.03d0, &
          327.34d0,  327.64d0,  327.94d0,  329.45d0,  329.75d0,  330.05d0, &
          330.36d0,  330.66d0,  330.96d0,  331.26d0,  331.56d0,  331.86d0, &
          332.16d0,  332.46d0,  332.76d0,  333.06d0,  333.36d0,  333.66d0, &
          333.96d0,  334.26d0,  334.56d0,  334.86d0,  335.15d0,  335.45d0, &
          335.75d0,  336.05d0,  336.35d0,  336.65d0,  336.94d0,  337.24d0, &
          337.54d0,  337.84d0,  338.13d0,  338.43d0,  338.73d0,  339.02d0, &
          339.32d0,  339.62d0,  339.91d0,  340.21d0,  340.51d0,  340.80d0, &
          341.10d0,  341.39d0,  341.69d0,  341.98d0,  342.28d0,  342.57d0, &
          342.87d0,  343.16d0,  343.46d0,  343.75d0,  344.05d0,  344.34d0, &
          344.38d0,  345.46d0,  346.53d0,  347.61d0,  349.76d0,  350.83d0, &
          351.91d0,  352.98d0,  354.06d0,  355.13d0,  356.20d0,  357.28d0, &
          358.35d0,  359.42d0,  360.49d0,  361.57d0,  362.64d0,  363.71d0, &
          364.78d0,  365.85d0,  366.92d0,  367.99d0,  369.06d0,  370.13d0, &
          371.19d0,  372.26d0,  373.33d0,  374.40d0,  375.47d0,  376.53d0, &
          377.60d0,  378.67d0,  379.73d0,  380.80d0,  381.86d0,  382.93d0, &
          383.99d0,  385.06d0,  386.12d0,  387.18d0,  388.25d0,  389.31d0, &
          390.37d0,  391.43d0,  392.50d0,  393.56d0,  394.62d0,  395.68d0/)
 
    wnc( 481: 720)=(/ &
          396.74d0,  397.80d0,  398.86d0,  399.92d0,  400.98d0,  402.04d0, &
          403.10d0,  404.15d0,  405.21d0,  406.27d0,  409.44d0,  410.50d0, &
          413.66d0,  414.72d0,  415.77d0,  416.83d0,  417.88d0,  418.93d0, &
          419.99d0,  421.04d0,  422.09d0,  423.14d0,  424.19d0,  425.25d0, &
          426.30d0,  427.35d0,  428.40d0,  429.45d0,  430.50d0,  431.55d0, &
          432.60d0,  433.65d0,  434.69d0,  435.74d0,  436.79d0,  437.84d0, &
          438.88d0,  439.93d0,  440.98d0,  442.02d0,  443.07d0,  444.11d0, &
          445.16d0,  446.20d0,  447.25d0,  448.29d0,  449.34d0,  450.38d0, &
          451.42d0,  452.46d0,  453.51d0,  454.55d0,  455.59d0,  456.63d0, &
          457.67d0,  458.71d0,  459.75d0,  460.79d0,  461.83d0,  462.87d0, &
          463.91d0,  464.95d0,  465.99d0,  467.03d0,  468.06d0,  469.10d0, &
          470.14d0,  471.18d0,  472.21d0,  473.25d0,  474.28d0,  475.32d0, &
          476.35d0,  477.39d0,  478.42d0,  479.46d0,  480.49d0,  481.52d0, &
          482.56d0,  483.59d0,  484.62d0,  485.65d0,  486.69d0,  487.72d0, &
          488.75d0,  489.78d0,  490.81d0,  491.84d0,  492.87d0,  493.90d0, &
          494.93d0,  495.95d0,  496.98d0,  498.01d0,  499.04d0,  500.07d0, &
          501.09d0,  502.12d0,  503.14d0,  504.17d0,  505.20d0,  506.22d0, &
          509.30d0,  510.32d0,  511.34d0,  512.37d0,  513.39d0,  514.41d0, &
          515.43d0,  516.46d0,  517.48d0,  518.50d0,  519.52d0,  520.54d0, &
          521.56d0,  522.58d0,  523.60d0,  524.62d0,  525.64d0,  526.66d0, &
          527.67d0,  528.69d0,  529.71d0,  530.73d0,  531.74d0,  533.78d0, &
          534.79d0,  535.81d0,  536.82d0,  537.84d0,  538.85d0,  539.87d0, &
          540.88d0,  541.89d0,  542.91d0,  543.92d0,  544.93d0,  545.94d0, &
          546.95d0,  547.97d0,  548.98d0,  549.99d0,  551.00d0,  552.01d0, &
          553.02d0,  554.03d0,  555.04d0,  556.05d0,  557.05d0,  558.06d0, &
          559.07d0,  560.08d0,  561.08d0,  562.09d0,  564.10d0,  565.11d0, &
          566.11d0,  567.12d0,  568.12d0,  569.13d0,  570.13d0,  571.14d0, &
          572.14d0,  573.14d0,  574.15d0,  575.15d0,  576.15d0,  577.15d0, &
          578.15d0,  579.15d0,  580.15d0,  581.15d0,  582.15d0,  583.15d0, &
          584.15d0,  585.15d0,  586.15d0,  587.15d0,  588.15d0,  589.15d0, &
          590.14d0,  591.14d0,  592.14d0,  593.13d0,  594.13d0,  595.12d0, &
          596.12d0,  597.11d0,  598.11d0,  599.10d0,  600.10d0,  601.09d0, &
          602.08d0,  603.08d0,  604.07d0,  605.06d0,  606.05d0,  607.05d0, &
          608.04d0,  609.03d0,  610.02d0,  611.01d0,  612.00d0,  612.99d0, &
          613.98d0,  614.97d0,  615.96d0,  616.94d0,  617.93d0,  618.92d0, &
          619.91d0,  620.89d0,  621.88d0,  622.87d0,  624.84d0,  625.82d0, &
          626.81d0,  627.79d0,  628.78d0,  629.76d0,  630.74d0,  631.73d0, &
          632.71d0,  633.69d0,  634.67d0,  635.66d0,  636.64d0,  637.62d0, &
          638.60d0,  639.58d0,  640.56d0,  641.54d0,  642.52d0,  643.50d0, &
          644.48d0,  645.46d0,  646.43d0,  647.41d0,  648.39d0,  649.37d0/)
 
    wnc( 721: 960)=(/ &
          650.34d0,  651.32d0,  652.30d0,  653.27d0,  654.25d0,  655.22d0, &
          656.20d0,  657.17d0,  658.15d0,  659.12d0,  660.09d0,  661.07d0, &
          662.04d0,  663.01d0,  663.98d0,  664.96d0,  665.93d0,  666.90d0, &
          667.87d0,  668.84d0,  669.81d0,  670.78d0,  671.75d0,  672.72d0, &
          673.69d0,  674.66d0,  675.62d0,  676.59d0,  677.56d0,  678.53d0, &
          679.49d0,  680.46d0,  681.43d0,  682.39d0,  683.36d0,  684.32d0, &
          685.29d0,  686.25d0,  687.21d0,  688.18d0,  689.14d0,  690.10d0, &
          691.07d0,  692.03d0,  692.99d0,  693.95d0,  694.91d0,  695.88d0, &
          696.84d0,  697.80d0,  698.76d0,  699.72d0,  700.68d0,  701.64d0, &
          702.59d0,  703.55d0,  704.51d0,  705.47d0,  706.43d0,  707.38d0, &
          708.34d0,  709.29d0,  710.25d0,  711.21d0,  712.16d0,  713.12d0, &
          714.07d0,  715.03d0,  715.98d0,  716.93d0,  717.89d0,  718.84d0, &
          719.79d0,  720.74d0,  721.70d0,  722.65d0,  723.60d0,  724.55d0, &
          725.50d0,  726.45d0,  727.40d0,  728.35d0,  729.30d0,  730.25d0, &
          731.20d0,  732.15d0,  733.09d0,  734.04d0,  734.99d0,  735.94d0, &
          736.88d0,  737.83d0,  738.77d0,  739.72d0,  740.67d0,  741.61d0, &
          742.55d0,  743.50d0,  744.44d0,  745.39d0,  746.33d0,  747.27d0, &
          748.22d0,  749.16d0,  750.10d0,  751.04d0,  751.98d0,  752.92d0, &
          753.86d0,  754.80d0,  755.74d0,  756.68d0,  757.62d0,  758.56d0, &
          759.50d0,  760.44d0,  761.38d0,  762.31d0,  763.25d0,  764.19d0, &
          765.12d0,  766.06d0,  767.00d0,  767.93d0,  768.87d0,  769.80d0, &
          770.74d0,  771.67d0,  772.60d0,  777.27d0,  778.20d0,  779.13d0, &
          780.06d0,  780.99d0,  781.92d0,  782.85d0,  783.78d0,  784.71d0, &
          786.57d0,  787.50d0,  788.43d0,  789.35d0,  790.28d0,  791.21d0, &
          792.14d0,  793.06d0,  793.99d0,  794.91d0,  795.84d0,  796.76d0, &
          797.69d0,  798.61d0,  799.54d0,  800.46d0,  801.38d0,  802.31d0, &
          803.23d0,  804.15d0,  805.08d0,  806.00d0,  806.92d0,  807.84d0, &
          808.76d0,  809.68d0,  810.60d0,  811.52d0,  812.44d0,  813.36d0, &
          814.28d0,  815.20d0,  816.11d0,  817.03d0,  817.95d0,  818.87d0, &
          819.78d0,  820.70d0,  821.61d0,  822.53d0,  823.45d0,  824.36d0, &
          825.28d0,  826.19d0,  827.10d0,  828.02d0,  828.93d0,  829.84d0, &
          830.76d0,  831.67d0,  832.58d0,  833.49d0,  834.40d0,  835.31d0, &
          836.22d0,  837.14d0,  838.04d0,  838.95d0,  839.86d0,  840.77d0, &
          841.68d0,  842.59d0,  843.50d0,  844.41d0,  845.31d0,  846.22d0, &
          847.13d0,  848.03d0,  848.94d0,  849.84d0,  850.75d0,  851.65d0, &
          852.56d0,  853.46d0,  854.37d0,  855.27d0,  856.17d0,  857.08d0, &
          857.98d0,  858.88d0,  859.78d0,  860.68d0,  861.59d0,  862.49d0, &
          863.39d0,  864.29d0,  865.19d0,  866.09d0,  866.99d0,  867.88d0, &
          868.78d0,  869.68d0,  870.58d0,  871.48d0,  872.37d0,  873.27d0, &
          874.17d0,  875.04d0,  875.12d0,  875.20d0,  875.27d0,  875.35d0/)
 
    wnc( 961:1200)=(/ &
          875.43d0,  875.50d0,  875.58d0,  875.66d0,  875.73d0,  875.81d0, &
          875.89d0,  875.96d0,  876.04d0,  876.12d0,  876.19d0,  876.27d0, &
          876.35d0,  876.42d0,  876.50d0,  876.58d0,  876.66d0,  876.73d0, &
          876.81d0,  876.89d0,  876.96d0,  877.04d0,  877.12d0,  877.19d0, &
          877.27d0,  877.35d0,  877.42d0,  877.50d0,  877.58d0,  877.66d0, &
          877.73d0,  877.81d0,  877.89d0,  877.96d0,  878.04d0,  878.12d0, &
          878.19d0,  878.27d0,  878.35d0,  878.43d0,  878.50d0,  878.58d0, &
          878.66d0,  878.73d0,  878.81d0,  878.89d0,  878.97d0,  879.04d0, &
          879.12d0,  879.20d0,  879.28d0,  879.35d0,  879.43d0,  879.51d0, &
          879.59d0,  879.66d0,  879.74d0,  879.82d0,  879.89d0,  879.97d0, &
          880.05d0,  880.13d0,  880.20d0,  880.28d0,  880.36d0,  880.44d0, &
          880.51d0,  880.59d0,  880.67d0,  880.75d0,  880.82d0,  880.90d0, &
          880.98d0,  881.06d0,  881.14d0,  881.21d0,  881.29d0,  881.37d0, &
          881.45d0,  881.52d0,  881.60d0,  881.68d0,  881.76d0,  881.83d0, &
          881.91d0,  881.99d0,  882.07d0,  882.15d0,  882.22d0,  882.30d0, &
          882.38d0,  882.46d0,  882.53d0,  882.61d0,  882.69d0,  882.77d0, &
          882.85d0,  882.92d0,  883.00d0,  883.08d0,  883.16d0,  883.24d0, &
          883.31d0,  883.39d0,  883.47d0,  883.55d0,  883.63d0,  883.70d0, &
          883.78d0,  883.86d0,  883.94d0,  884.02d0,  884.09d0,  884.17d0, &
          884.25d0,  884.33d0,  884.41d0,  884.49d0,  884.56d0,  884.64d0, &
          884.72d0,  884.80d0,  884.88d0,  884.96d0,  885.03d0,  885.11d0, &
          885.19d0,  885.27d0,  885.35d0,  885.43d0,  885.50d0,  885.58d0, &
          885.66d0,  885.74d0,  885.82d0,  885.90d0,  885.97d0,  886.05d0, &
          886.13d0,  886.21d0,  886.29d0,  886.37d0,  886.45d0,  886.53d0, &
          886.60d0,  886.68d0,  886.76d0,  886.84d0,  886.92d0,  887.00d0, &
          887.08d0,  887.15d0,  887.23d0,  887.31d0,  887.39d0,  887.47d0, &
          887.55d0,  887.63d0,  887.71d0,  887.78d0,  887.86d0,  887.94d0, &
          888.02d0,  888.10d0,  888.18d0,  888.26d0,  888.34d0,  888.41d0, &
          888.49d0,  888.57d0,  888.65d0,  888.73d0,  888.81d0,  888.89d0, &
          888.97d0,  889.05d0,  889.13d0,  889.21d0,  889.28d0,  889.36d0, &
          889.44d0,  889.52d0,  889.60d0,  889.68d0,  889.76d0,  889.84d0, &
          889.92d0,  890.00d0,  890.08d0,  890.16d0,  890.23d0,  890.31d0, &
          890.39d0,  890.47d0,  890.55d0,  890.63d0,  890.71d0,  890.79d0, &
          890.87d0,  890.95d0,  891.03d0,  891.11d0,  891.19d0,  891.27d0, &
          891.34d0,  891.42d0,  891.50d0,  891.58d0,  891.66d0,  891.74d0, &
          891.82d0,  891.90d0,  891.98d0,  892.06d0,  892.14d0,  892.22d0, &
          892.30d0,  892.38d0,  892.46d0,  892.54d0,  892.62d0,  892.70d0, &
          892.78d0,  892.86d0,  892.94d0,  893.02d0,  893.10d0,  893.18d0, &
          893.26d0,  893.34d0,  893.42d0,  893.49d0,  893.58d0,  893.66d0, &
          893.73d0,  893.82d0,  893.90d0,  893.97d0,  894.05d0,  894.13d0/)
 
    wnc(1201:1440)=(/ &
          894.21d0,  894.29d0,  894.37d0,  894.45d0,  894.53d0,  894.61d0, &
          894.69d0,  894.77d0,  894.85d0,  894.93d0,  895.02d0,  895.09d0, &
          895.17d0,  895.26d0,  895.34d0,  895.41d0,  895.50d0,  895.58d0, &
          895.66d0,  895.74d0,  895.82d0,  895.90d0,  895.98d0,  896.06d0, &
          896.14d0,  896.22d0,  896.30d0,  896.38d0,  896.46d0,  896.54d0, &
          896.62d0,  896.70d0,  896.78d0,  896.86d0,  896.94d0,  897.02d0, &
          897.10d0,  897.18d0,  897.26d0,  897.34d0,  897.42d0,  897.51d0, &
          897.59d0,  897.67d0,  897.75d0,  897.83d0,  897.91d0,  897.99d0, &
          898.07d0,  898.15d0,  898.23d0,  898.31d0,  898.39d0,  898.47d0, &
          898.55d0,  898.63d0,  898.72d0,  898.80d0,  898.88d0,  898.96d0, &
          899.04d0,  899.12d0,  899.20d0,  899.28d0,  899.36d0,  899.44d0, &
          899.52d0,  899.60d0,  899.68d0,  899.77d0,  899.85d0,  899.93d0, &
          900.01d0,  900.09d0,  900.17d0,  900.25d0,  900.33d0,  900.41d0, &
          900.49d0,  900.58d0,  900.66d0,  900.74d0,  900.82d0,  900.90d0, &
          900.98d0,  901.06d0,  901.14d0,  901.23d0,  901.31d0,  901.39d0, &
          901.47d0,  901.55d0,  901.63d0,  901.71d0,  901.79d0,  901.88d0, &
          901.96d0,  902.04d0,  902.12d0,  902.20d0,  902.28d0,  902.36d0, &
          902.45d0,  902.53d0,  902.61d0,  902.69d0,  902.77d0,  902.85d0, &
          902.93d0,  903.02d0,  903.10d0,  903.18d0,  903.26d0,  903.34d0, &
          903.42d0,  903.51d0,  903.59d0,  903.67d0,  903.75d0,  903.83d0, &
          903.91d0,  904.00d0,  904.08d0,  904.16d0,  904.24d0,  904.32d0, &
          904.40d0,  904.49d0,  904.57d0,  904.65d0,  904.73d0,  904.81d0, &
          904.90d0,  904.98d0,  905.06d0,  905.14d0,  905.22d0,  905.30d0, &
          905.39d0,  905.47d0,  905.55d0,  905.63d0,  905.72d0,  905.80d0, &
          905.88d0,  905.96d0,  906.04d0,  906.13d0,  906.21d0,  906.29d0, &
          906.37d0,  906.45d0,  906.54d0,  906.62d0,  906.70d0,  906.78d0, &
          906.86d0,  906.95d0,  907.03d0,  907.11d0,  907.19d0,  907.28d0, &
          907.36d0,  907.44d0,  907.52d0,  907.61d0,  907.69d0,  907.77d0, &
          907.85d0,  907.93d0,  908.02d0,  908.10d0,  908.18d0,  908.27d0, &
          908.35d0,  908.43d0,  908.51d0,  908.59d0,  908.68d0,  908.76d0, &
          908.84d0,  908.93d0,  909.01d0,  909.09d0,  909.17d0,  909.26d0, &
          909.34d0,  909.42d0,  909.50d0,  909.59d0,  909.67d0,  909.75d0, &
          909.84d0,  909.92d0,  910.00d0,  910.08d0,  910.17d0,  910.25d0, &
          910.33d0,  910.41d0,  910.50d0,  910.58d0,  910.66d0,  910.75d0, &
          910.83d0,  910.91d0,  911.00d0,  911.08d0,  911.16d0,  911.24d0, &
          911.33d0,  911.41d0,  911.49d0,  911.58d0,  911.66d0,  911.74d0, &
          911.83d0,  911.91d0,  911.99d0,  912.08d0,  912.16d0,  912.24d0, &
          912.33d0,  912.41d0,  912.49d0,  912.58d0,  912.66d0,  912.74d0, &
          912.83d0,  912.91d0,  912.99d0,  913.08d0,  913.16d0,  913.24d0, &
          913.33d0,  913.41d0,  913.49d0,  913.58d0,  913.66d0,  913.74d0/)
 
    wnc(1441:1680)=(/ &
          913.83d0,  913.91d0,  913.99d0,  914.08d0,  914.16d0,  914.24d0, &
          914.33d0,  914.41d0,  914.49d0,  914.58d0,  914.66d0,  914.75d0, &
          914.83d0,  914.91d0,  915.00d0,  915.08d0,  915.16d0,  915.25d0, &
          915.33d0,  915.42d0,  915.50d0,  915.58d0,  915.67d0,  915.75d0, &
          915.84d0,  915.92d0,  916.00d0,  916.09d0,  916.17d0,  916.25d0, &
          916.34d0,  916.42d0,  916.51d0,  916.59d0,  916.67d0,  916.76d0, &
          916.84d0,  916.93d0,  917.01d0,  917.09d0,  917.18d0,  917.26d0, &
          917.35d0,  917.43d0,  917.52d0,  917.60d0,  917.68d0,  917.77d0, &
          917.85d0,  917.94d0,  918.02d0,  918.10d0,  918.19d0,  918.27d0, &
          918.36d0,  918.44d0,  918.53d0,  918.61d0,  918.70d0,  918.78d0, &
          918.86d0,  918.95d0,  919.03d0,  919.12d0,  919.20d0,  919.29d0, &
          919.37d0,  919.46d0,  919.54d0,  919.63d0,  919.71d0,  919.79d0, &
          919.88d0,  919.96d0,  920.05d0,  920.13d0,  920.22d0,  920.30d0, &
          920.39d0,  920.47d0,  920.56d0,  920.64d0,  920.73d0,  920.81d0, &
          920.90d0,  920.98d0,  921.07d0,  921.15d0,  921.23d0,  921.32d0, &
          921.40d0,  921.49d0,  921.57d0,  921.66d0,  921.74d0,  921.83d0, &
          921.91d0,  922.00d0,  922.08d0,  922.17d0,  922.25d0,  922.34d0, &
          922.42d0,  922.51d0,  922.59d0,  922.68d0,  922.77d0,  922.85d0, &
          922.93d0,  923.02d0,  923.10d0,  923.19d0,  923.28d0,  923.36d0, &
          923.45d0,  923.53d0,  923.62d0,  923.70d0,  923.79d0,  923.87d0, &
          923.96d0,  924.04d0,  924.13d0,  924.21d0,  924.30d0,  924.39d0, &
          924.47d0,  924.56d0,  924.64d0,  924.73d0,  924.81d0,  924.90d0, &
          924.98d0,  925.07d0,  925.16d0,  925.24d0,  925.33d0,  925.41d0, &
          925.50d0,  925.58d0,  925.67d0,  925.76d0,  925.84d0,  925.93d0, &
          926.01d0,  926.10d0,  926.18d0,  926.27d0,  926.35d0,  926.44d0, &
          926.53d0,  926.61d0,  926.70d0,  926.78d0,  926.87d0,  926.96d0, &
          927.04d0,  927.13d0,  927.21d0,  927.30d0,  927.39d0,  927.47d0, &
          927.56d0,  927.64d0,  927.73d0,  927.82d0,  927.90d0,  927.99d0, &
          928.07d0,  928.16d0,  928.25d0,  928.33d0,  928.42d0,  928.51d0, &
          928.59d0,  928.68d0,  928.76d0,  928.85d0,  928.94d0,  929.02d0, &
          929.11d0,  929.20d0,  929.28d0,  929.37d0,  929.45d0,  929.54d0, &
          929.63d0,  929.71d0,  929.80d0,  929.89d0,  929.97d0,  930.06d0, &
          930.15d0,  930.23d0,  930.32d0,  930.41d0,  930.49d0,  930.58d0, &
          930.66d0,  930.75d0,  930.84d0,  930.92d0,  931.01d0,  931.10d0, &
          931.18d0,  931.27d0,  931.36d0,  931.45d0,  931.53d0,  931.62d0, &
          931.71d0,  931.79d0,  931.88d0,  931.97d0,  932.05d0,  932.14d0, &
          932.23d0,  932.31d0,  932.40d0,  932.49d0,  932.58d0,  932.66d0, &
          932.75d0,  932.84d0,  932.92d0,  933.01d0,  933.10d0,  933.18d0, &
          933.27d0,  933.36d0,  933.45d0,  933.53d0,  933.62d0,  933.71d0, &
          933.79d0,  933.88d0,  933.97d0,  934.06d0,  934.14d0,  934.23d0/)
 
    wnc(1681:1920)=(/ &
          934.32d0,  934.41d0,  934.49d0,  934.58d0,  934.67d0,  934.75d0, &
          934.84d0,  934.93d0,  935.02d0,  935.10d0,  935.19d0,  935.28d0, &
          935.37d0,  935.45d0,  935.54d0,  935.63d0,  935.72d0,  935.80d0, &
          935.89d0,  935.98d0,  936.07d0,  936.15d0,  936.24d0,  936.33d0, &
          936.42d0,  936.51d0,  936.59d0,  936.68d0,  936.77d0,  936.86d0, &
          936.94d0,  937.03d0,  937.12d0,  937.21d0,  937.29d0,  937.38d0, &
          937.47d0,  937.56d0,  937.65d0,  937.73d0,  937.82d0,  937.91d0, &
          938.00d0,  938.09d0,  938.17d0,  938.26d0,  938.35d0,  938.44d0, &
          938.53d0,  938.61d0,  938.70d0,  938.79d0,  938.88d0,  938.97d0, &
          939.05d0,  939.14d0,  939.23d0,  939.32d0,  939.41d0,  939.50d0, &
          939.59d0,  939.67d0,  939.76d0,  939.85d0,  939.94d0,  940.03d0, &
          940.11d0,  940.20d0,  940.29d0,  940.38d0,  940.47d0,  940.56d0, &
          940.65d0,  940.73d0,  940.82d0,  940.91d0,  941.00d0,  941.09d0, &
          941.18d0,  941.27d0,  941.35d0,  941.44d0,  941.53d0,  941.62d0, &
          941.71d0,  941.80d0,  941.89d0,  941.97d0,  942.06d0,  942.15d0, &
          942.24d0,  942.33d0,  942.42d0,  942.51d0,  942.60d0,  942.68d0, &
          942.77d0,  942.86d0,  942.95d0,  943.04d0,  943.13d0,  943.22d0, &
          943.31d0,  943.40d0,  943.48d0,  943.57d0,  943.66d0,  943.75d0, &
          943.84d0,  943.93d0,  944.02d0,  944.11d0,  944.20d0,  944.29d0, &
          944.38d0,  944.47d0,  944.55d0,  944.64d0,  944.73d0,  944.82d0, &
          944.91d0,  945.00d0,  945.09d0,  945.18d0,  945.27d0,  945.36d0, &
          945.45d0,  945.54d0,  945.63d0,  945.72d0,  945.80d0,  945.90d0, &
          945.98d0,  946.07d0,  946.16d0,  946.25d0,  946.34d0,  946.43d0, &
          946.52d0,  946.61d0,  946.70d0,  946.79d0,  946.88d0,  946.97d0, &
          947.06d0,  947.15d0,  947.24d0,  947.33d0,  947.42d0,  947.51d0, &
          947.60d0,  947.69d0,  947.78d0,  947.87d0,  947.96d0,  948.05d0, &
          948.14d0,  948.23d0,  948.32d0,  948.41d0,  948.50d0,  948.59d0, &
          948.68d0,  948.77d0,  948.86d0,  948.95d0,  949.04d0,  949.13d0, &
          949.22d0,  949.31d0,  949.40d0,  949.49d0,  949.58d0,  949.67d0, &
          949.76d0,  949.85d0,  949.94d0,  950.03d0,  950.12d0,  950.21d0, &
          950.30d0,  950.39d0,  950.48d0,  950.57d0,  950.66d0,  950.75d0, &
          950.84d0,  950.93d0,  951.02d0,  951.11d0,  951.20d0,  951.29d0, &
          951.38d0,  951.47d0,  951.57d0,  951.66d0,  951.75d0,  951.84d0, &
          951.93d0,  952.02d0,  952.11d0,  952.20d0,  952.29d0,  952.38d0, &
          952.47d0,  952.56d0,  952.65d0,  952.74d0,  952.84d0,  952.92d0, &
          953.02d0,  953.11d0,  953.20d0,  953.29d0,  953.38d0,  953.47d0, &
          953.56d0,  953.65d0,  953.74d0,  953.83d0,  953.92d0,  954.02d0, &
          954.11d0,  954.20d0,  954.29d0,  954.38d0,  954.47d0,  954.56d0, &
          954.65d0,  954.74d0,  954.84d0,  954.93d0,  955.02d0,  955.11d0, &
          955.20d0,  955.29d0,  955.38d0,  955.47d0,  955.57d0,  955.66d0/)
 
    wnc(1921:2160)=(/ &
          955.75d0,  955.84d0,  955.93d0,  956.02d0,  956.11d0,  956.21d0, &
          956.30d0,  956.39d0,  956.48d0,  956.57d0,  956.66d0,  956.76d0, &
          956.85d0,  956.94d0,  957.03d0,  957.12d0,  957.21d0,  957.30d0, &
          957.40d0,  957.49d0,  957.58d0,  957.67d0,  957.76d0,  957.85d0, &
          957.95d0,  958.04d0,  958.13d0,  958.22d0,  958.31d0,  958.41d0, &
          958.50d0,  958.59d0,  958.68d0,  958.77d0,  958.86d0,  958.96d0, &
          959.05d0,  959.14d0,  959.23d0,  959.33d0,  959.42d0,  959.51d0, &
          959.60d0,  959.69d0,  959.78d0,  959.88d0,  959.97d0,  960.06d0, &
          960.15d0,  960.25d0,  960.34d0,  960.43d0,  960.52d0,  960.61d0, &
          960.71d0,  960.80d0,  960.89d0,  960.98d0,  961.08d0,  961.17d0, &
          961.26d0,  961.35d0,  961.45d0,  961.54d0,  961.63d0,  961.72d0, &
          961.82d0,  961.91d0,  962.00d0,  962.09d0,  962.19d0,  962.28d0, &
          962.37d0,  962.46d0,  962.56d0,  962.65d0,  962.74d0,  962.84d0, &
          962.93d0,  963.02d0,  963.11d0,  963.21d0,  963.30d0,  963.39d0, &
          963.48d0,  963.58d0,  963.67d0,  963.76d0,  963.85d0,  963.95d0, &
          964.04d0,  964.13d0,  964.23d0,  964.32d0,  964.41d0,  964.51d0, &
          964.60d0,  964.69d0,  964.78d0,  964.88d0,  964.97d0,  965.07d0, &
          965.16d0,  965.25d0,  965.34d0,  965.44d0,  965.53d0,  965.62d0, &
          965.72d0,  965.81d0,  965.90d0,  966.00d0,  966.09d0,  966.18d0, &
          966.28d0,  966.37d0,  966.46d0,  966.56d0,  966.65d0,  966.74d0, &
          966.84d0,  966.93d0,  967.02d0,  967.12d0,  967.21d0,  967.30d0, &
          967.40d0,  967.49d0,  967.59d0,  967.68d0,  967.77d0,  967.87d0, &
          967.96d0,  968.05d0,  968.15d0,  968.24d0,  968.34d0,  968.43d0, &
          968.52d0,  968.62d0,  968.71d0,  968.80d0,  968.90d0,  968.99d0, &
          969.09d0,  969.18d0,  969.27d0,  969.37d0,  969.46d0,  969.56d0, &
          969.65d0,  969.74d0,  969.84d0,  969.93d0,  970.03d0,  970.12d0, &
          970.21d0,  970.31d0,  970.40d0,  970.50d0,  970.59d0,  970.68d0, &
          970.78d0,  970.87d0,  970.97d0,  971.06d0,  971.16d0,  971.25d0, &
          971.34d0,  971.44d0,  971.53d0,  971.63d0,  971.72d0,  971.82d0, &
          971.91d0,  972.01d0,  972.10d0,  972.20d0,  972.29d0,  972.38d0, &
          972.48d0,  972.57d0,  972.67d0,  972.76d0,  972.86d0,  972.95d0, &
          973.05d0,  973.14d0,  973.24d0,  973.33d0,  973.43d0,  973.52d0, &
          973.61d0,  973.71d0,  973.80d0,  973.90d0,  973.99d0,  974.09d0, &
          974.18d0,  974.28d0,  974.37d0,  974.47d0,  974.56d0,  974.66d0, &
          974.75d0,  974.85d0,  974.94d0,  975.04d0,  975.13d0,  975.23d0, &
          975.32d0,  975.42d0,  975.52d0,  975.61d0,  975.71d0,  975.80d0, &
          975.90d0,  975.99d0,  976.09d0,  976.18d0,  976.28d0,  976.37d0, &
          976.47d0,  976.56d0,  976.66d0,  976.75d0,  976.85d0,  976.94d0, &
          977.04d0,  977.14d0,  977.23d0,  977.33d0,  977.42d0,  977.52d0, &
          977.61d0,  977.71d0,  977.80d0,  977.90d0,  977.99d0,  978.09d0/)
 
    wnc(2161:2400)=(/ &
          978.19d0,  978.28d0,  978.38d0,  978.47d0,  978.57d0,  978.66d0, &
          978.76d0,  978.86d0,  978.95d0,  979.05d0,  979.14d0,  979.24d0, &
          979.34d0,  979.43d0,  979.53d0,  979.62d0,  979.72d0,  979.82d0, &
          979.91d0,  980.01d0,  980.10d0,  980.20d0,  980.30d0,  980.39d0, &
          980.49d0,  980.58d0,  980.68d0,  980.78d0,  980.87d0,  980.97d0, &
          981.07d0,  981.16d0,  981.26d0,  981.35d0,  981.45d0,  981.55d0, &
          981.64d0,  981.74d0,  981.84d0,  981.93d0,  982.03d0,  982.13d0, &
          982.22d0,  982.32d0,  982.41d0,  982.51d0,  982.61d0,  982.70d0, &
          982.80d0,  982.90d0,  982.99d0,  983.09d0,  983.19d0,  983.28d0, &
          983.38d0,  983.48d0,  983.57d0,  983.67d0,  983.77d0,  983.86d0, &
          983.96d0,  984.06d0,  984.16d0,  984.25d0,  984.35d0,  984.45d0, &
          984.54d0,  984.64d0,  984.74d0,  984.83d0,  984.93d0,  985.03d0, &
          985.13d0,  985.22d0,  985.32d0,  985.42d0,  985.51d0,  985.61d0, &
          985.71d0,  985.80d0,  985.90d0,  986.00d0,  986.10d0,  986.19d0, &
          986.29d0,  986.39d0,  986.48d0,  986.58d0,  986.68d0,  986.78d0, &
          986.88d0,  986.97d0,  987.07d0,  987.17d0,  987.26d0,  987.36d0, &
          987.46d0,  987.56d0,  987.65d0,  987.75d0,  987.85d0,  987.95d0, &
          988.04d0,  988.14d0,  988.24d0,  988.34d0,  988.43d0,  988.53d0, &
          988.63d0,  988.73d0,  988.83d0,  988.92d0,  989.02d0,  989.12d0, &
          989.22d0,  989.32d0,  989.41d0,  989.51d0,  989.61d0,  989.71d0, &
          989.80d0,  989.90d0,  990.00d0,  990.10d0,  990.20d0,  990.29d0, &
          990.39d0,  990.49d0,  990.59d0,  990.69d0,  990.79d0,  990.88d0, &
          990.98d0,  991.08d0,  991.18d0,  991.28d0,  991.38d0,  991.47d0, &
          991.57d0,  991.67d0,  991.77d0,  991.87d0,  991.97d0,  992.06d0, &
          992.16d0,  992.26d0,  992.36d0,  992.46d0,  992.56d0,  992.65d0, &
          992.75d0,  992.85d0,  992.95d0,  993.05d0,  993.15d0,  993.25d0, &
          993.34d0,  993.44d0,  993.54d0,  993.64d0,  993.74d0,  993.84d0, &
          993.94d0,  994.04d0,  994.14d0,  994.23d0,  994.33d0,  994.43d0, &
          994.53d0,  994.63d0,  994.73d0,  994.83d0,  994.93d0,  995.03d0, &
          995.12d0,  995.22d0,  995.32d0,  995.42d0,  995.52d0,  995.62d0, &
          995.72d0,  995.82d0,  995.92d0,  996.02d0,  996.11d0,  996.21d0, &
          996.31d0,  996.41d0,  996.51d0,  996.61d0,  996.71d0,  996.81d0, &
          996.91d0,  997.01d0,  997.11d0,  997.21d0,  997.31d0,  997.41d0, &
          997.51d0,  997.61d0,  997.71d0,  997.80d0,  997.90d0,  998.00d0, &
          998.10d0,  998.20d0,  998.30d0,  998.40d0,  998.50d0,  998.60d0, &
          998.70d0,  998.80d0,  998.90d0,  999.00d0,  999.10d0,  999.20d0, &
          999.30d0,  999.40d0,  999.50d0,  999.60d0,  999.70d0,  999.80d0, &
          999.90d0, 1000.00d0, 1000.10d0, 1000.20d0, 1000.30d0, 1000.40d0, &
         1000.50d0, 1000.60d0, 1000.70d0, 1000.80d0, 1000.90d0, 1001.00d0, &
         1001.10d0, 1001.20d0, 1001.30d0, 1001.40d0, 1001.50d0, 1001.60d0/)
 
    wnc(2401:2640)=(/ &
         1001.70d0, 1001.80d0, 1001.90d0, 1002.00d0, 1002.10d0, 1002.21d0, &
         1002.30d0, 1002.41d0, 1002.51d0, 1002.61d0, 1002.71d0, 1002.81d0, &
         1002.91d0, 1003.01d0, 1003.11d0, 1003.21d0, 1003.31d0, 1003.41d0, &
         1003.51d0, 1003.61d0, 1003.71d0, 1003.81d0, 1003.91d0, 1004.02d0, &
         1004.12d0, 1004.22d0, 1004.32d0, 1004.42d0, 1004.52d0, 1004.62d0, &
         1004.72d0, 1004.82d0, 1004.92d0, 1005.03d0, 1005.13d0, 1005.23d0, &
         1005.33d0, 1005.43d0, 1005.53d0, 1005.63d0, 1005.73d0, 1005.83d0, &
         1005.93d0, 1006.04d0, 1006.14d0, 1006.24d0, 1006.34d0, 1006.44d0, &
         1006.54d0, 1006.64d0, 1006.74d0, 1006.85d0, 1006.95d0, 1007.05d0, &
         1007.15d0, 1007.25d0, 1007.35d0, 1007.46d0, 1007.56d0, 1007.66d0, &
         1007.76d0, 1007.86d0, 1007.96d0, 1008.07d0, 1008.17d0, 1008.27d0, &
         1008.37d0, 1008.47d0, 1008.57d0, 1008.67d0, 1008.78d0, 1008.88d0, &
         1008.98d0, 1009.08d0, 1009.18d0, 1009.28d0, 1009.39d0, 1009.49d0, &
         1009.59d0, 1009.69d0, 1009.79d0, 1009.90d0, 1010.00d0, 1010.10d0, &
         1010.20d0, 1010.30d0, 1010.41d0, 1010.51d0, 1010.61d0, 1010.71d0, &
         1010.82d0, 1010.92d0, 1011.02d0, 1011.12d0, 1011.22d0, 1011.33d0, &
         1011.43d0, 1011.53d0, 1011.63d0, 1011.74d0, 1011.84d0, 1011.94d0, &
         1012.04d0, 1012.15d0, 1012.25d0, 1012.35d0, 1012.45d0, 1012.56d0, &
         1012.66d0, 1012.76d0, 1012.86d0, 1012.97d0, 1013.07d0, 1013.17d0, &
         1013.27d0, 1013.38d0, 1013.48d0, 1013.58d0, 1013.68d0, 1013.79d0, &
         1013.89d0, 1013.99d0, 1014.10d0, 1014.20d0, 1014.30d0, 1014.41d0, &
         1014.51d0, 1014.61d0, 1014.71d0, 1014.82d0, 1014.92d0, 1015.02d0, &
         1015.13d0, 1015.23d0, 1015.33d0, 1015.43d0, 1015.54d0, 1015.64d0, &
         1015.74d0, 1015.85d0, 1015.95d0, 1016.05d0, 1016.16d0, 1016.26d0, &
         1016.36d0, 1016.47d0, 1016.57d0, 1016.67d0, 1016.78d0, 1016.88d0, &
         1016.98d0, 1017.09d0, 1017.19d0, 1017.29d0, 1017.40d0, 1017.50d0, &
         1017.60d0, 1017.71d0, 1017.81d0, 1017.91d0, 1018.02d0, 1018.12d0, &
         1018.23d0, 1018.33d0, 1018.43d0, 1018.54d0, 1018.64d0, 1018.74d0, &
         1018.85d0, 1018.95d0, 1019.06d0, 1019.16d0, 1019.26d0, 1019.37d0, &
         1019.47d0, 1019.58d0, 1019.68d0, 1019.78d0, 1019.89d0, 1019.99d0, &
         1020.10d0, 1020.20d0, 1020.30d0, 1020.41d0, 1020.51d0, 1020.62d0, &
         1020.72d0, 1020.83d0, 1020.93d0, 1021.03d0, 1021.14d0, 1021.24d0, &
         1021.35d0, 1021.45d0, 1021.55d0, 1021.66d0, 1021.76d0, 1021.87d0, &
         1021.97d0, 1022.08d0, 1022.18d0, 1022.29d0, 1022.39d0, 1022.49d0, &
         1022.60d0, 1022.70d0, 1022.81d0, 1022.91d0, 1023.02d0, 1023.12d0, &
         1023.23d0, 1023.33d0, 1023.44d0, 1023.54d0, 1023.65d0, 1023.75d0, &
         1023.86d0, 1023.96d0, 1024.07d0, 1024.17d0, 1024.28d0, 1024.38d0, &
         1024.48d0, 1024.59d0, 1024.69d0, 1024.80d0, 1024.91d0, 1025.01d0, &
         1025.11d0, 1025.22d0, 1025.33d0, 1025.43d0, 1025.54d0, 1025.64d0, &
         1025.75d0, 1025.85d0, 1025.96d0, 1026.06d0, 1026.17d0, 1026.27d0/)
 
    wnc(2641:2880)=(/ &
         1026.38d0, 1026.48d0, 1026.59d0, 1026.69d0, 1026.80d0, 1026.91d0, &
         1027.01d0, 1027.12d0, 1027.22d0, 1027.33d0, 1027.43d0, 1027.54d0, &
         1027.64d0, 1027.75d0, 1027.85d0, 1027.96d0, 1028.07d0, 1028.17d0, &
         1028.28d0, 1028.38d0, 1028.49d0, 1028.59d0, 1028.70d0, 1028.81d0, &
         1028.91d0, 1029.02d0, 1029.12d0, 1029.23d0, 1029.34d0, 1029.44d0, &
         1029.55d0, 1029.65d0, 1029.76d0, 1029.87d0, 1029.97d0, 1030.08d0, &
         1030.18d0, 1030.29d0, 1030.40d0, 1030.50d0, 1030.61d0, 1030.71d0, &
         1030.82d0, 1030.93d0, 1031.03d0, 1031.14d0, 1031.25d0, 1031.35d0, &
         1031.46d0, 1031.57d0, 1031.67d0, 1031.78d0, 1031.89d0, 1031.99d0, &
         1032.10d0, 1032.20d0, 1032.31d0, 1032.42d0, 1032.52d0, 1032.63d0, &
         1032.74d0, 1032.84d0, 1032.95d0, 1033.06d0, 1033.17d0, 1033.27d0, &
         1033.38d0, 1033.48d0, 1033.59d0, 1033.70d0, 1033.81d0, 1033.91d0, &
         1034.02d0, 1034.13d0, 1034.23d0, 1034.34d0, 1034.45d0, 1034.55d0, &
         1034.66d0, 1034.77d0, 1034.88d0, 1034.98d0, 1035.09d0, 1035.20d0, &
         1035.30d0, 1035.41d0, 1035.52d0, 1035.63d0, 1035.73d0, 1035.84d0, &
         1035.95d0, 1036.06d0, 1036.16d0, 1036.27d0, 1036.38d0, 1036.48d0, &
         1036.59d0, 1036.70d0, 1036.81d0, 1036.91d0, 1037.02d0, 1037.13d0, &
         1037.24d0, 1037.34d0, 1037.45d0, 1037.56d0, 1037.67d0, 1037.78d0, &
         1037.88d0, 1037.99d0, 1038.10d0, 1038.21d0, 1038.31d0, 1038.42d0, &
         1038.53d0, 1038.64d0, 1038.74d0, 1038.85d0, 1038.96d0, 1039.07d0, &
         1039.18d0, 1039.29d0, 1039.39d0, 1039.50d0, 1039.61d0, 1039.72d0, &
         1039.82d0, 1039.93d0, 1040.04d0, 1040.15d0, 1040.26d0, 1040.37d0, &
         1040.47d0, 1040.58d0, 1040.69d0, 1040.80d0, 1040.91d0, 1041.02d0, &
         1041.13d0, 1041.23d0, 1041.34d0, 1041.45d0, 1041.56d0, 1041.67d0, &
         1041.78d0, 1041.88d0, 1041.99d0, 1042.10d0, 1042.21d0, 1042.32d0, &
         1042.43d0, 1042.54d0, 1042.64d0, 1042.75d0, 1042.86d0, 1042.97d0, &
         1043.08d0, 1043.19d0, 1043.30d0, 1043.41d0, 1043.52d0, 1043.62d0, &
         1043.73d0, 1043.84d0, 1043.95d0, 1044.06d0, 1044.17d0, 1044.28d0, &
         1044.39d0, 1044.49d0, 1044.60d0, 1044.71d0, 1044.82d0, 1044.93d0, &
         1045.04d0, 1045.15d0, 1045.26d0, 1045.37d0, 1045.48d0, 1045.59d0, &
         1045.70d0, 1045.81d0, 1045.92d0, 1046.03d0, 1046.14d0, 1046.24d0, &
         1046.35d0, 1046.46d0, 1046.57d0, 1046.68d0, 1046.79d0, 1046.90d0, &
         1047.01d0, 1047.12d0, 1047.23d0, 1047.34d0, 1047.45d0, 1047.56d0, &
         1047.67d0, 1047.78d0, 1047.89d0, 1048.00d0, 1048.11d0, 1048.22d0, &
         1048.33d0, 1048.44d0, 1048.55d0, 1048.66d0, 1048.77d0, 1048.88d0, &
         1048.99d0, 1049.10d0, 1049.21d0, 1049.32d0, 1049.43d0, 1049.54d0, &
         1049.65d0, 1049.76d0, 1049.87d0, 1049.98d0, 1050.09d0, 1050.20d0, &
         1050.31d0, 1050.42d0, 1050.53d0, 1050.64d0, 1050.75d0, 1050.86d0, &
         1050.97d0, 1051.08d0, 1051.19d0, 1051.30d0, 1051.41d0, 1051.53d0, &
         1051.64d0, 1051.75d0, 1051.86d0, 1051.97d0, 1052.08d0, 1052.19d0/)
 
    wnc(2881:3120)=(/ &
         1052.30d0, 1052.41d0, 1052.52d0, 1052.63d0, 1052.74d0, 1052.85d0, &
         1052.96d0, 1053.07d0, 1053.19d0, 1053.30d0, 1053.41d0, 1053.52d0, &
         1053.63d0, 1053.74d0, 1053.85d0, 1053.96d0, 1054.07d0, 1054.19d0, &
         1054.30d0, 1054.41d0, 1054.52d0, 1054.63d0, 1054.74d0, 1054.85d0, &
         1054.96d0, 1055.07d0, 1055.19d0, 1055.30d0, 1055.41d0, 1055.52d0, &
         1055.63d0, 1055.74d0, 1055.85d0, 1055.97d0, 1056.08d0, 1056.19d0, &
         1056.30d0, 1056.41d0, 1056.52d0, 1056.64d0, 1056.75d0, 1056.86d0, &
         1056.97d0, 1057.08d0, 1057.19d0, 1057.31d0, 1057.42d0, 1057.53d0, &
         1057.64d0, 1057.75d0, 1057.86d0, 1057.98d0, 1058.09d0, 1058.20d0, &
         1058.31d0, 1058.43d0, 1058.54d0, 1058.65d0, 1058.76d0, 1058.87d0, &
         1058.98d0, 1059.10d0, 1059.21d0, 1059.32d0, 1059.43d0, 1059.55d0, &
         1059.66d0, 1059.77d0, 1059.88d0, 1060.00d0, 1060.11d0, 1060.22d0, &
         1060.33d0, 1060.44d0, 1060.56d0, 1060.67d0, 1060.78d0, 1060.90d0, &
         1061.01d0, 1061.12d0, 1061.23d0, 1061.35d0, 1061.46d0, 1061.57d0, &
         1061.68d0, 1061.80d0, 1061.91d0, 1062.02d0, 1062.14d0, 1062.25d0, &
         1062.36d0, 1062.47d0, 1062.59d0, 1062.70d0, 1062.81d0, 1062.93d0, &
         1063.04d0, 1063.15d0, 1063.26d0, 1063.38d0, 1063.49d0, 1063.60d0, &
         1063.72d0, 1063.83d0, 1063.94d0, 1064.06d0, 1064.17d0, 1064.28d0, &
         1064.40d0, 1064.51d0, 1064.62d0, 1064.74d0, 1064.85d0, 1064.96d0, &
         1065.08d0, 1065.19d0, 1065.30d0, 1065.42d0, 1065.53d0, 1065.64d0, &
         1065.76d0, 1065.87d0, 1065.98d0, 1066.10d0, 1066.21d0, 1066.32d0, &
         1066.44d0, 1066.55d0, 1066.67d0, 1066.78d0, 1066.89d0, 1067.01d0, &
         1067.12d0, 1067.24d0, 1067.35d0, 1067.46d0, 1067.58d0, 1067.69d0, &
         1067.81d0, 1067.92d0, 1068.03d0, 1068.15d0, 1068.26d0, 1068.38d0, &
         1068.49d0, 1068.60d0, 1068.72d0, 1068.83d0, 1068.95d0, 1069.06d0, &
         1069.18d0, 1069.29d0, 1069.40d0, 1069.52d0, 1069.63d0, 1069.75d0, &
         1069.86d0, 1069.98d0, 1070.09d0, 1070.20d0, 1070.32d0, 1070.44d0, &
         1070.55d0, 1070.66d0, 1070.78d0, 1070.89d0, 1071.01d0, 1071.12d0, &
         1071.24d0, 1071.35d0, 1071.47d0, 1071.58d0, 1071.70d0, 1071.81d0, &
         1071.93d0, 1072.04d0, 1072.16d0, 1072.27d0, 1072.39d0, 1072.50d0, &
         1072.62d0, 1072.73d0, 1072.85d0, 1072.96d0, 1073.08d0, 1073.19d0, &
         1073.31d0, 1073.42d0, 1073.54d0, 1073.65d0, 1073.77d0, 1073.88d0, &
         1074.00d0, 1074.11d0, 1074.23d0, 1074.34d0, 1074.46d0, 1074.58d0, &
         1074.69d0, 1074.81d0, 1074.92d0, 1075.04d0, 1075.15d0, 1075.27d0, &
         1075.39d0, 1075.50d0, 1075.62d0, 1075.73d0, 1075.85d0, 1075.96d0, &
         1076.08d0, 1076.19d0, 1076.31d0, 1076.43d0, 1076.54d0, 1076.66d0, &
         1076.77d0, 1076.89d0, 1077.01d0, 1077.12d0, 1077.24d0, 1077.35d0, &
         1077.47d0, 1077.59d0, 1077.70d0, 1077.82d0, 1077.94d0, 1078.05d0, &
         1078.17d0, 1078.28d0, 1078.40d0, 1078.52d0, 1078.63d0, 1078.75d0, &
         1078.86d0, 1078.98d0, 1079.10d0, 1079.21d0, 1079.33d0, 1079.45d0/)
 
    wnc(3121:3360)=(/ &
         1079.56d0, 1079.68d0, 1079.80d0, 1079.91d0, 1080.03d0, 1080.15d0, &
         1080.26d0, 1080.38d0, 1080.50d0, 1080.61d0, 1080.73d0, 1080.85d0, &
         1080.96d0, 1081.08d0, 1081.20d0, 1081.31d0, 1081.43d0, 1081.55d0, &
         1081.67d0, 1081.78d0, 1081.90d0, 1082.02d0, 1082.13d0, 1082.25d0, &
         1082.37d0, 1082.48d0, 1082.60d0, 1082.72d0, 1082.84d0, 1082.95d0, &
         1083.07d0, 1083.19d0, 1083.31d0, 1083.42d0, 1083.54d0, 1083.66d0, &
         1083.78d0, 1083.89d0, 1084.01d0, 1084.13d0, 1084.25d0, 1084.36d0, &
         1084.48d0, 1084.60d0, 1084.72d0, 1084.83d0, 1084.95d0, 1085.07d0, &
         1085.19d0, 1085.31d0, 1085.42d0, 1085.54d0, 1085.66d0, 1085.78d0, &
         1085.89d0, 1086.01d0, 1086.13d0, 1086.25d0, 1086.37d0, 1086.48d0, &
         1086.60d0, 1086.72d0, 1086.84d0, 1086.96d0, 1087.07d0, 1087.19d0, &
         1087.31d0, 1087.43d0, 1087.55d0, 1087.67d0, 1087.78d0, 1087.90d0, &
         1088.02d0, 1088.14d0, 1088.26d0, 1088.38d0, 1088.49d0, 1088.61d0, &
         1088.73d0, 1088.85d0, 1088.97d0, 1089.09d0, 1089.21d0, 1089.32d0, &
         1089.44d0, 1089.56d0, 1089.68d0, 1089.80d0, 1089.92d0, 1090.04d0, &
         1090.16d0, 1090.28d0, 1090.39d0, 1090.51d0, 1090.63d0, 1090.75d0, &
         1090.87d0, 1090.99d0, 1091.11d0, 1091.23d0, 1091.35d0, 1091.46d0, &
         1091.58d0, 1091.70d0, 1091.82d0, 1091.94d0, 1092.06d0, 1092.18d0, &
         1092.30d0, 1092.42d0, 1092.54d0, 1092.66d0, 1092.78d0, 1092.90d0, &
         1093.02d0, 1093.14d0, 1093.26d0, 1093.37d0, 1093.49d0, 1093.61d0, &
         1093.73d0, 1093.85d0, 1093.97d0, 1094.09d0, 1094.21d0, 1094.33d0, &
         1094.45d0, 1094.57d0, 1094.69d0, 1094.81d0, 1094.93d0, 1095.05d0, &
         1095.17d0, 1095.29d0, 1095.41d0, 1095.53d0, 1095.65d0, 1095.77d0, &
         1095.89d0, 1096.01d0, 1096.13d0, 1096.25d0, 1096.37d0, 1096.49d0, &
         1096.61d0, 1096.73d0, 1096.85d0, 1096.97d0, 1097.09d0, 1097.21d0, &
         1097.33d0, 1097.45d0, 1097.57d0, 1097.69d0, 1097.81d0, 1097.94d0, &
         1098.06d0, 1098.18d0, 1098.30d0, 1098.42d0, 1098.54d0, 1098.66d0, &
         1098.78d0, 1098.90d0, 1099.02d0, 1099.14d0, 1099.26d0, 1099.38d0, &
         1099.51d0, 1099.63d0, 1099.75d0, 1099.87d0, 1099.99d0, 1100.11d0, &
         1100.23d0, 1100.35d0, 1100.47d0, 1100.59d0, 1100.72d0, 1100.84d0, &
         1100.96d0, 1101.08d0, 1101.20d0, 1101.32d0, 1101.44d0, 1101.56d0, &
         1101.69d0, 1101.81d0, 1101.93d0, 1102.05d0, 1102.17d0, 1102.29d0, &
         1102.41d0, 1102.54d0, 1102.66d0, 1102.78d0, 1102.90d0, 1103.02d0, &
         1103.14d0, 1103.27d0, 1103.39d0, 1103.51d0, 1103.63d0, 1103.75d0, &
         1103.88d0, 1104.00d0, 1104.12d0, 1104.24d0, 1104.36d0, 1104.48d0, &
         1104.61d0, 1104.73d0, 1104.85d0, 1104.97d0, 1105.09d0, 1105.22d0, &
         1105.34d0, 1105.46d0, 1105.58d0, 1105.70d0, 1105.83d0, 1105.95d0, &
         1106.07d0, 1106.19d0, 1106.32d0, 1106.44d0, 1106.56d0, 1106.68d0, &
         1106.81d0, 1106.93d0, 1107.05d0, 1107.18d0, 1107.30d0, 1107.42d0, &
         1107.54d0, 1107.67d0, 1107.79d0, 1107.91d0, 1108.03d0, 1108.16d0/)
 
    wnc(3361:3600)=(/ &
         1108.28d0, 1108.40d0, 1108.53d0, 1108.65d0, 1108.77d0, 1108.89d0, &
         1109.02d0, 1109.14d0, 1109.26d0, 1109.39d0, 1109.51d0, 1109.63d0, &
         1109.76d0, 1109.88d0, 1110.00d0, 1110.12d0, 1110.25d0, 1110.37d0, &
         1110.49d0, 1110.62d0, 1110.74d0, 1110.86d0, 1110.99d0, 1111.11d0, &
         1111.23d0, 1111.36d0, 1111.48d0, 1111.60d0, 1111.73d0, 1111.85d0, &
         1111.98d0, 1112.10d0, 1112.22d0, 1112.35d0, 1112.47d0, 1112.59d0, &
         1112.72d0, 1112.84d0, 1112.97d0, 1113.09d0, 1113.21d0, 1113.34d0, &
         1113.46d0, 1113.59d0, 1113.71d0, 1113.83d0, 1113.96d0, 1114.08d0, &
         1114.21d0, 1114.33d0, 1114.45d0, 1114.58d0, 1114.70d0, 1114.83d0, &
         1114.95d0, 1115.08d0, 1115.20d0, 1115.32d0, 1115.45d0, 1115.57d0, &
         1115.70d0, 1115.82d0, 1115.95d0, 1116.07d0, 1116.20d0, 1116.32d0, &
         1116.44d0, 1116.57d0, 1116.69d0, 1116.82d0, 1116.94d0, 1117.07d0, &
         1117.19d0, 1117.32d0, 1117.44d0, 1117.57d0, 1117.69d0, 1117.82d0, &
         1117.94d0, 1118.07d0, 1118.19d0, 1118.32d0, 1118.44d0, 1118.57d0, &
         1118.69d0, 1118.82d0, 1118.94d0, 1119.07d0, 1119.19d0, 1119.32d0, &
         1119.44d0, 1119.57d0, 1119.69d0, 1119.82d0, 1119.95d0, 1120.07d0, &
         1120.20d0, 1120.32d0, 1120.45d0, 1120.57d0, 1120.70d0, 1120.82d0, &
         1120.95d0, 1121.08d0, 1121.20d0, 1121.33d0, 1121.45d0, 1121.58d0, &
         1121.70d0, 1121.83d0, 1121.96d0, 1122.08d0, 1122.21d0, 1122.33d0, &
         1122.46d0, 1122.59d0, 1122.71d0, 1122.84d0, 1122.96d0, 1123.09d0, &
         1123.22d0, 1123.34d0, 1123.47d0, 1123.59d0, 1123.72d0, 1123.85d0, &
         1123.97d0, 1124.10d0, 1124.23d0, 1124.35d0, 1124.48d0, 1124.61d0, &
         1124.73d0, 1124.86d0, 1124.99d0, 1125.11d0, 1125.24d0, 1125.37d0, &
         1125.49d0, 1125.62d0, 1125.75d0, 1125.87d0, 1126.00d0, 1126.13d0, &
         1126.25d0, 1126.38d0, 1126.51d0, 1126.63d0, 1126.76d0, 1126.89d0, &
         1127.02d0, 1127.14d0, 1127.27d0, 1127.40d0, 1127.52d0, 1127.65d0, &
         1127.78d0, 1127.90d0, 1128.03d0, 1128.16d0, 1128.29d0, 1128.41d0, &
         1128.54d0, 1128.67d0, 1128.80d0, 1128.92d0, 1129.05d0, 1129.18d0, &
         1129.31d0, 1129.43d0, 1129.56d0, 1129.69d0, 1129.82d0, 1129.94d0, &
         1130.07d0, 1130.20d0, 1130.33d0, 1130.45d0, 1130.58d0, 1130.71d0, &
         1130.84d0, 1130.97d0, 1131.09d0, 1131.22d0, 1131.35d0, 1131.48d0, &
         1131.61d0, 1131.73d0, 1131.86d0, 1131.99d0, 1132.12d0, 1132.25d0, &
         1132.38d0, 1132.50d0, 1132.63d0, 1132.76d0, 1132.89d0, 1133.02d0, &
         1133.15d0, 1133.27d0, 1133.40d0, 1133.53d0, 1133.66d0, 1133.79d0, &
         1133.92d0, 1134.04d0, 1134.17d0, 1134.30d0, 1134.43d0, 1134.56d0, &
         1134.69d0, 1134.82d0, 1134.94d0, 1135.07d0, 1135.20d0, 1135.33d0, &
         1135.46d0, 1135.59d0, 1135.72d0, 1135.85d0, 1135.98d0, 1136.10d0, &
         1136.23d0, 1136.36d0, 1136.49d0, 1136.62d0, 1136.75d0, 1136.88d0, &
         1137.01d0, 1137.14d0, 1137.27d0, 1137.40d0, 1137.53d0, 1137.66d0, &
         1137.79d0, 1137.92d0, 1138.05d0, 1138.17d0, 1138.30d0, 1138.43d0/)
 
    wnc(3601:3840)=(/ &
         1138.56d0, 1138.69d0, 1138.82d0, 1138.95d0, 1139.08d0, 1139.21d0, &
         1139.34d0, 1139.47d0, 1139.60d0, 1139.73d0, 1139.86d0, 1139.99d0, &
         1140.12d0, 1140.25d0, 1140.38d0, 1140.51d0, 1140.64d0, 1140.77d0, &
         1140.90d0, 1141.03d0, 1141.16d0, 1141.29d0, 1141.42d0, 1141.55d0, &
         1141.68d0, 1141.81d0, 1141.94d0, 1142.07d0, 1142.20d0, 1142.33d0, &
         1142.46d0, 1142.60d0, 1142.73d0, 1142.86d0, 1142.99d0, 1143.12d0, &
         1143.25d0, 1143.38d0, 1143.51d0, 1143.64d0, 1143.77d0, 1143.90d0, &
         1144.03d0, 1144.17d0, 1144.30d0, 1144.43d0, 1144.56d0, 1144.69d0, &
         1144.82d0, 1144.95d0, 1145.08d0, 1145.21d0, 1145.34d0, 1145.47d0, &
         1145.61d0, 1145.74d0, 1145.87d0, 1146.00d0, 1146.13d0, 1146.26d0, &
         1146.40d0, 1146.53d0, 1146.66d0, 1146.79d0, 1146.92d0, 1147.05d0, &
         1147.18d0, 1147.31d0, 1147.45d0, 1147.58d0, 1147.71d0, 1147.84d0, &
         1147.97d0, 1148.11d0, 1148.24d0, 1148.37d0, 1148.50d0, 1148.63d0, &
         1148.77d0, 1148.90d0, 1149.03d0, 1149.16d0, 1149.29d0, 1149.43d0, &
         1149.56d0, 1149.69d0, 1149.82d0, 1149.95d0, 1150.09d0, 1150.22d0, &
         1150.35d0, 1150.48d0, 1150.62d0, 1150.75d0, 1150.88d0, 1151.01d0, &
         1151.15d0, 1151.28d0, 1151.41d0, 1151.54d0, 1151.68d0, 1151.81d0, &
         1151.94d0, 1152.07d0, 1152.21d0, 1152.34d0, 1152.47d0, 1152.60d0, &
         1152.74d0, 1152.87d0, 1153.00d0, 1153.14d0, 1153.27d0, 1153.40d0, &
         1153.54d0, 1153.67d0, 1153.80d0, 1153.94d0, 1154.07d0, 1154.20d0, &
         1154.33d0, 1154.47d0, 1154.60d0, 1154.73d0, 1154.87d0, 1155.00d0, &
         1155.14d0, 1155.27d0, 1155.40d0, 1155.54d0, 1155.67d0, 1155.80d0, &
         1155.94d0, 1156.07d0, 1156.20d0, 1156.34d0, 1156.47d0, 1156.60d0, &
         1156.74d0, 1156.87d0, 1157.01d0, 1157.14d0, 1157.27d0, 1157.41d0, &
         1157.54d0, 1157.68d0, 1157.81d0, 1157.94d0, 1158.08d0, 1158.21d0, &
         1158.35d0, 1158.48d0, 1158.61d0, 1158.75d0, 1158.88d0, 1159.02d0, &
         1159.15d0, 1159.29d0, 1159.42d0, 1159.56d0, 1159.69d0, 1159.82d0, &
         1159.96d0, 1160.09d0, 1160.23d0, 1160.36d0, 1160.50d0, 1160.63d0, &
         1160.77d0, 1160.90d0, 1161.04d0, 1161.17d0, 1161.31d0, 1161.44d0, &
         1161.57d0, 1161.71d0, 1161.84d0, 1161.98d0, 1162.11d0, 1162.25d0, &
         1162.39d0, 1162.52d0, 1162.66d0, 1162.79d0, 1162.93d0, 1163.06d0, &
         1163.20d0, 1163.33d0, 1163.47d0, 1163.60d0, 1163.74d0, 1163.87d0, &
         1164.01d0, 1164.14d0, 1164.28d0, 1164.42d0, 1164.55d0, 1164.69d0, &
         1164.82d0, 1164.96d0, 1165.09d0, 1165.23d0, 1165.36d0, 1165.50d0, &
         1165.64d0, 1165.77d0, 1165.91d0, 1166.05d0, 1166.18d0, 1166.32d0, &
         1166.45d0, 1166.59d0, 1166.72d0, 1166.86d0, 1167.00d0, 1167.13d0, &
         1167.27d0, 1167.41d0, 1167.54d0, 1167.68d0, 1167.81d0, 1167.95d0, &
         1168.09d0, 1168.22d0, 1168.36d0, 1168.50d0, 1168.63d0, 1168.77d0, &
         1168.91d0, 1169.04d0, 1169.18d0, 1169.32d0, 1169.45d0, 1169.59d0, &
         1169.73d0, 1169.86d0, 1170.00d0, 1170.14d0, 1170.28d0, 1170.41d0/)
 
    wnc(3841:4080)=(/ &
         1170.55d0, 1170.69d0, 1170.82d0, 1170.96d0, 1171.10d0, 1171.23d0, &
         1171.37d0, 1171.51d0, 1171.65d0, 1171.78d0, 1171.92d0, 1172.06d0, &
         1172.20d0, 1172.33d0, 1172.47d0, 1172.61d0, 1172.74d0, 1172.88d0, &
         1173.02d0, 1173.16d0, 1173.30d0, 1173.43d0, 1173.57d0, 1173.71d0, &
         1173.85d0, 1173.98d0, 1174.12d0, 1174.26d0, 1174.40d0, 1174.54d0, &
         1174.67d0, 1174.81d0, 1174.95d0, 1175.09d0, 1175.23d0, 1175.36d0, &
         1175.50d0, 1175.64d0, 1175.78d0, 1175.92d0, 1176.06d0, 1176.19d0, &
         1176.33d0, 1176.47d0, 1176.61d0, 1176.75d0, 1176.89d0, 1177.03d0, &
         1177.16d0, 1177.30d0, 1177.44d0, 1177.58d0, 1177.72d0, 1177.86d0, &
         1177.99d0, 1178.13d0, 1178.27d0, 1178.41d0, 1178.55d0, 1178.69d0, &
         1178.83d0, 1178.97d0, 1179.11d0, 1179.24d0, 1179.38d0, 1179.52d0, &
         1179.66d0, 1179.80d0, 1179.94d0, 1180.08d0, 1180.22d0, 1180.36d0, &
         1180.50d0, 1180.64d0, 1180.78d0, 1180.92d0, 1181.06d0, 1181.19d0, &
         1181.33d0, 1181.47d0, 1181.61d0, 1181.75d0, 1181.89d0, 1182.03d0, &
         1182.17d0, 1182.31d0, 1182.45d0, 1182.59d0, 1182.73d0, 1182.87d0, &
         1183.01d0, 1183.15d0, 1183.29d0, 1183.43d0, 1183.57d0, 1183.71d0, &
         1183.85d0, 1183.99d0, 1184.13d0, 1184.27d0, 1184.41d0, 1184.55d0, &
         1184.69d0, 1184.83d0, 1184.97d0, 1185.11d0, 1185.26d0, 1185.40d0, &
         1185.54d0, 1185.68d0, 1185.82d0, 1185.96d0, 1186.10d0, 1186.24d0, &
         1186.38d0, 1186.52d0, 1186.66d0, 1186.80d0, 1186.94d0, 1187.08d0, &
         1187.22d0, 1187.37d0, 1187.51d0, 1187.65d0, 1187.79d0, 1187.93d0, &
         1188.07d0, 1188.21d0, 1188.35d0, 1188.49d0, 1188.64d0, 1188.78d0, &
         1188.92d0, 1189.06d0, 1189.20d0, 1189.34d0, 1189.48d0, 1189.63d0, &
         1189.77d0, 1189.91d0, 1190.05d0, 1190.19d0, 1190.33d0, 1190.48d0, &
         1190.62d0, 1190.76d0, 1190.90d0, 1191.04d0, 1191.19d0, 1191.33d0, &
         1191.47d0, 1191.61d0, 1191.75d0, 1191.90d0, 1192.04d0, 1192.18d0, &
         1192.32d0, 1192.46d0, 1192.61d0, 1192.75d0, 1192.89d0, 1193.03d0, &
         1193.18d0, 1193.32d0, 1193.46d0, 1193.60d0, 1193.74d0, 1193.89d0, &
         1194.03d0, 1194.17d0, 1194.31d0, 1194.46d0, 1194.60d0, 1194.74d0, &
         1194.89d0, 1195.03d0, 1195.17d0, 1195.31d0, 1195.46d0, 1195.60d0, &
         1195.74d0, 1195.89d0, 1196.03d0, 1196.17d0, 1196.31d0, 1196.46d0, &
         1196.60d0, 1196.74d0, 1196.89d0, 1197.03d0, 1197.18d0, 1197.32d0, &
         1197.46d0, 1197.60d0, 1197.75d0, 1197.89d0, 1198.04d0, 1198.18d0, &
         1198.32d0, 1198.47d0, 1198.61d0, 1198.75d0, 1198.90d0, 1199.04d0, &
         1199.19d0, 1199.33d0, 1199.47d0, 1199.62d0, 1199.76d0, 1199.90d0, &
         1200.05d0, 1200.19d0, 1200.34d0, 1200.48d0, 1200.62d0, 1200.77d0, &
         1200.91d0, 1201.06d0, 1201.20d0, 1201.35d0, 1201.49d0, 1201.63d0, &
         1201.78d0, 1201.92d0, 1202.07d0, 1202.21d0, 1202.36d0, 1202.50d0, &
         1202.65d0, 1202.79d0, 1202.94d0, 1203.08d0, 1203.22d0, 1203.37d0, &
         1203.51d0, 1203.66d0, 1203.80d0, 1203.95d0, 1204.09d0, 1204.24d0/)
 
    wnc(4081:4320)=(/ &
         1204.38d0, 1204.53d0, 1204.67d0, 1204.82d0, 1204.96d0, 1205.11d0, &
         1205.26d0, 1205.40d0, 1205.55d0, 1205.69d0, 1205.84d0, 1205.98d0, &
         1206.13d0, 1206.27d0, 1206.42d0, 1206.56d0, 1206.71d0, 1206.85d0, &
         1207.00d0, 1207.15d0, 1207.29d0, 1207.44d0, 1207.58d0, 1207.73d0, &
         1207.88d0, 1208.02d0, 1208.17d0, 1208.31d0, 1208.46d0, 1208.60d0, &
         1208.75d0, 1208.90d0, 1209.04d0, 1209.19d0, 1209.34d0, 1209.48d0, &
         1209.63d0, 1209.78d0, 1209.92d0, 1210.07d0, 1210.21d0, 1210.36d0, &
         1210.51d0, 1210.65d0, 1210.80d0, 1210.95d0, 1211.09d0, 1211.24d0, &
         1211.39d0, 1211.53d0, 1211.68d0, 1211.83d0, 1211.97d0, 1212.12d0, &
         1212.27d0, 1212.42d0, 1212.56d0, 1212.71d0, 1212.86d0, 1213.00d0, &
         1213.15d0, 1213.30d0, 1213.44d0, 1213.59d0, 1213.74d0, 1213.89d0, &
         1214.03d0, 1214.18d0, 1214.33d0, 1214.48d0, 1214.62d0, 1214.77d0, &
         1214.92d0, 1215.07d0, 1215.21d0, 1215.36d0, 1215.51d0, 1215.66d0, &
         1215.81d0, 1215.95d0, 1216.10d0, 1216.25d0, 1216.40d0, 1216.55d0, &
         1216.69d0, 1216.84d0, 1216.99d0, 1217.14d0, 1217.29d0, 1217.43d0, &
         1217.58d0, 1217.73d0, 1217.88d0, 1218.03d0, 1218.18d0, 1218.32d0, &
         1218.47d0, 1218.62d0, 1218.77d0, 1218.92d0, 1219.07d0, 1219.21d0, &
         1219.36d0, 1219.51d0, 1219.66d0, 1219.81d0, 1219.96d0, 1220.11d0, &
         1220.26d0, 1220.41d0, 1220.55d0, 1220.70d0, 1220.85d0, 1221.00d0, &
         1221.15d0, 1221.30d0, 1221.45d0, 1221.60d0, 1221.75d0, 1221.90d0, &
         1222.05d0, 1222.19d0, 1222.34d0, 1222.49d0, 1222.64d0, 1222.79d0, &
         1222.94d0, 1223.09d0, 1223.24d0, 1223.39d0, 1223.54d0, 1223.69d0, &
         1223.84d0, 1223.99d0, 1224.14d0, 1224.29d0, 1224.44d0, 1224.59d0, &
         1224.74d0, 1224.89d0, 1225.04d0, 1225.19d0, 1225.34d0, 1225.49d0, &
         1225.64d0, 1225.79d0, 1225.94d0, 1226.09d0, 1226.24d0, 1226.39d0, &
         1226.54d0, 1226.69d0, 1226.84d0, 1226.99d0, 1227.15d0, 1227.30d0, &
         1227.45d0, 1227.60d0, 1227.75d0, 1227.90d0, 1228.05d0, 1228.20d0, &
         1228.35d0, 1228.50d0, 1228.65d0, 1228.80d0, 1228.95d0, 1229.10d0, &
         1229.26d0, 1229.41d0, 1229.56d0, 1229.71d0, 1229.86d0, 1230.01d0, &
         1230.16d0, 1230.31d0, 1230.47d0, 1230.62d0, 1230.77d0, 1230.92d0, &
         1231.07d0, 1231.22d0, 1231.38d0, 1231.53d0, 1231.68d0, 1231.83d0, &
         1231.98d0, 1232.13d0, 1232.29d0, 1232.44d0, 1232.59d0, 1232.74d0, &
         1232.89d0, 1233.05d0, 1233.20d0, 1233.35d0, 1233.50d0, 1233.65d0, &
         1233.81d0, 1233.96d0, 1234.11d0, 1234.26d0, 1234.42d0, 1234.57d0, &
         1234.72d0, 1234.87d0, 1235.03d0, 1235.18d0, 1235.33d0, 1235.48d0, &
         1235.64d0, 1235.79d0, 1235.94d0, 1236.09d0, 1236.25d0, 1236.40d0, &
         1236.55d0, 1236.70d0, 1236.86d0, 1237.01d0, 1237.16d0, 1237.32d0, &
         1237.47d0, 1237.62d0, 1237.78d0, 1237.93d0, 1238.08d0, 1238.24d0, &
         1238.39d0, 1238.54d0, 1238.70d0, 1238.85d0, 1239.00d0, 1239.16d0, &
         1239.31d0, 1239.46d0, 1239.62d0, 1239.77d0, 1239.93d0, 1240.08d0/)
 
    wnc(4321:4560)=(/ &
         1240.23d0, 1240.39d0, 1240.54d0, 1240.69d0, 1240.85d0, 1241.00d0, &
         1241.16d0, 1241.31d0, 1241.46d0, 1241.62d0, 1241.77d0, 1241.93d0, &
         1242.08d0, 1242.24d0, 1242.39d0, 1242.55d0, 1242.70d0, 1242.85d0, &
         1243.01d0, 1243.16d0, 1243.32d0, 1243.47d0, 1243.63d0, 1243.78d0, &
         1243.94d0, 1244.09d0, 1244.24d0, 1244.40d0, 1244.56d0, 1244.71d0, &
         1244.86d0, 1245.02d0, 1245.18d0, 1245.33d0, 1245.48d0, 1245.64d0, &
         1245.80d0, 1245.95d0, 1246.11d0, 1246.26d0, 1246.42d0, 1246.57d0, &
         1246.73d0, 1246.88d0, 1247.04d0, 1247.19d0, 1247.35d0, 1247.51d0, &
         1247.66d0, 1247.82d0, 1247.97d0, 1248.13d0, 1248.28d0, 1248.44d0, &
         1248.59d0, 1248.75d0, 1248.91d0, 1249.06d0, 1249.22d0, 1249.38d0, &
         1249.53d0, 1249.69d0, 1249.84d0, 1250.00d0, 1250.16d0, 1250.31d0, &
         1250.47d0, 1250.63d0, 1250.78d0, 1250.94d0, 1251.09d0, 1251.25d0, &
         1251.41d0, 1251.56d0, 1251.72d0, 1251.88d0, 1252.04d0, 1252.19d0, &
         1252.35d0, 1252.51d0, 1252.66d0, 1252.82d0, 1252.98d0, 1253.13d0, &
         1253.29d0, 1253.45d0, 1253.60d0, 1253.76d0, 1253.92d0, 1254.08d0, &
         1254.23d0, 1254.39d0, 1254.55d0, 1254.70d0, 1254.86d0, 1255.02d0, &
         1255.18d0, 1255.33d0, 1255.49d0, 1255.65d0, 1255.81d0, 1255.97d0, &
         1256.12d0, 1256.28d0, 1256.44d0, 1256.60d0, 1256.76d0, 1256.91d0, &
         1257.07d0, 1257.23d0, 1257.39d0, 1257.55d0, 1257.70d0, 1257.86d0, &
         1258.02d0, 1258.18d0, 1258.34d0, 1258.49d0, 1258.65d0, 1258.81d0, &
         1258.97d0, 1259.13d0, 1259.29d0, 1259.45d0, 1259.60d0, 1259.76d0, &
         1259.92d0, 1260.08d0, 1260.24d0, 1260.40d0, 1260.56d0, 1260.72d0, &
         1260.88d0, 1261.03d0, 1261.19d0, 1261.35d0, 1261.51d0, 1261.67d0, &
         1261.83d0, 1261.99d0, 1262.15d0, 1262.31d0, 1262.47d0, 1262.63d0, &
         1262.79d0, 1262.94d0, 1263.10d0, 1263.26d0, 1263.42d0, 1263.58d0, &
         1263.74d0, 1263.90d0, 1264.06d0, 1264.22d0, 1264.38d0, 1264.54d0, &
         1264.70d0, 1264.86d0, 1265.02d0, 1265.18d0, 1265.34d0, 1265.50d0, &
         1265.66d0, 1265.82d0, 1265.98d0, 1266.14d0, 1266.30d0, 1266.46d0, &
         1266.63d0, 1266.79d0, 1266.94d0, 1267.11d0, 1267.27d0, 1267.43d0, &
         1267.59d0, 1267.75d0, 1267.91d0, 1268.07d0, 1268.23d0, 1268.39d0, &
         1268.55d0, 1268.71d0, 1268.88d0, 1269.04d0, 1269.20d0, 1269.36d0, &
         1269.52d0, 1269.68d0, 1269.84d0, 1270.00d0, 1270.16d0, 1270.32d0, &
         1270.49d0, 1270.65d0, 1270.81d0, 1270.97d0, 1271.13d0, 1271.29d0, &
         1271.46d0, 1271.62d0, 1271.78d0, 1271.94d0, 1272.10d0, 1272.27d0, &
         1272.43d0, 1272.59d0, 1272.75d0, 1272.91d0, 1273.07d0, 1273.24d0, &
         1273.40d0, 1273.56d0, 1273.72d0, 1273.89d0, 1274.05d0, 1274.21d0, &
         1274.37d0, 1274.54d0, 1274.70d0, 1274.86d0, 1275.02d0, 1275.19d0, &
         1275.35d0, 1275.51d0, 1275.67d0, 1275.84d0, 1276.00d0, 1276.16d0, &
         1276.32d0, 1276.49d0, 1276.65d0, 1276.81d0, 1276.98d0, 1277.14d0, &
         1277.30d0, 1277.46d0, 1277.63d0, 1277.79d0, 1277.95d0, 1278.12d0/)
 
    wnc(4561:4800)=(/ &
         1278.28d0, 1278.44d0, 1278.61d0, 1278.77d0, 1278.94d0, 1279.10d0, &
         1279.26d0, 1279.43d0, 1279.59d0, 1279.75d0, 1279.92d0, 1280.08d0, &
         1280.25d0, 1280.41d0, 1280.57d0, 1280.74d0, 1280.90d0, 1281.07d0, &
         1281.23d0, 1281.39d0, 1281.56d0, 1281.72d0, 1281.89d0, 1282.05d0, &
         1282.22d0, 1282.38d0, 1282.55d0, 1282.71d0, 1282.87d0, 1283.04d0, &
         1283.20d0, 1283.37d0, 1283.53d0, 1283.70d0, 1283.86d0, 1284.03d0, &
         1284.19d0, 1284.36d0, 1284.52d0, 1284.69d0, 1284.85d0, 1285.02d0, &
         1285.18d0, 1285.35d0, 1285.51d0, 1285.68d0, 1285.84d0, 1286.01d0, &
         1286.17d0, 1286.34d0, 1286.51d0, 1286.67d0, 1286.84d0, 1287.00d0, &
         1287.17d0, 1287.33d0, 1287.50d0, 1287.66d0, 1287.83d0, 1288.00d0, &
         1288.16d0, 1288.33d0, 1288.49d0, 1288.66d0, 1288.83d0, 1288.99d0, &
         1289.16d0, 1289.32d0, 1289.49d0, 1289.66d0, 1289.82d0, 1289.99d0, &
         1290.16d0, 1290.32d0, 1290.49d0, 1290.66d0, 1290.82d0, 1290.99d0, &
         1291.16d0, 1291.32d0, 1291.49d0, 1291.66d0, 1291.82d0, 1291.99d0, &
         1292.16d0, 1292.32d0, 1292.49d0, 1292.66d0, 1292.82d0, 1292.99d0, &
         1293.16d0, 1293.33d0, 1293.49d0, 1293.66d0, 1293.83d0, 1294.00d0, &
         1294.16d0, 1294.33d0, 1294.50d0, 1294.67d0, 1294.83d0, 1295.00d0, &
         1295.17d0, 1295.34d0, 1295.51d0, 1295.67d0, 1295.84d0, 1296.01d0, &
         1296.18d0, 1296.34d0, 1296.51d0, 1296.68d0, 1296.85d0, 1297.02d0, &
         1297.19d0, 1297.35d0, 1297.52d0, 1297.69d0, 1297.86d0, 1298.03d0, &
         1298.19d0, 1298.36d0, 1298.53d0, 1298.70d0, 1298.87d0, 1299.04d0, &
         1299.21d0, 1299.38d0, 1299.55d0, 1299.71d0, 1299.88d0, 1300.05d0, &
         1300.22d0, 1300.39d0, 1300.56d0, 1300.73d0, 1300.90d0, 1301.07d0, &
         1301.24d0, 1301.41d0, 1301.57d0, 1301.74d0, 1301.91d0, 1302.08d0, &
         1302.25d0, 1302.42d0, 1302.59d0, 1302.76d0, 1302.93d0, 1303.10d0, &
         1303.27d0, 1303.44d0, 1303.61d0, 1303.78d0, 1303.95d0, 1304.12d0, &
         1304.29d0, 1304.46d0, 1304.63d0, 1304.80d0, 1304.97d0, 1305.14d0, &
         1305.31d0, 1305.48d0, 1305.65d0, 1305.82d0, 1305.99d0, 1306.17d0, &
         1306.34d0, 1306.51d0, 1306.68d0, 1306.85d0, 1307.02d0, 1307.19d0, &
         1307.36d0, 1307.53d0, 1307.70d0, 1307.87d0, 1308.04d0, 1308.22d0, &
         1308.39d0, 1308.56d0, 1308.73d0, 1308.90d0, 1309.07d0, 1309.24d0, &
         1309.42d0, 1309.59d0, 1309.76d0, 1309.93d0, 1310.10d0, 1310.27d0, &
         1310.44d0, 1310.62d0, 1310.79d0, 1310.96d0, 1311.13d0, 1311.30d0, &
         1311.47d0, 1311.65d0, 1311.82d0, 1311.99d0, 1312.16d0, 1312.34d0, &
         1312.51d0, 1312.68d0, 1312.85d0, 1313.03d0, 1313.20d0, 1313.37d0, &
         1313.54d0, 1313.71d0, 1313.89d0, 1314.06d0, 1314.23d0, 1314.41d0, &
         1314.58d0, 1314.75d0, 1314.92d0, 1315.10d0, 1315.27d0, 1315.44d0, &
         1315.62d0, 1315.79d0, 1315.96d0, 1316.14d0, 1316.31d0, 1316.48d0, &
         1316.66d0, 1316.83d0, 1317.00d0, 1317.18d0, 1317.35d0, 1317.52d0, &
         1317.70d0, 1317.87d0, 1318.04d0, 1318.22d0, 1318.39d0, 1318.56d0/)
 
    wnc(4801:5040)=(/ &
         1318.74d0, 1318.91d0, 1319.09d0, 1319.26d0, 1319.44d0, 1319.61d0, &
         1319.78d0, 1319.96d0, 1320.13d0, 1320.31d0, 1320.48d0, 1320.66d0, &
         1320.83d0, 1321.00d0, 1321.18d0, 1321.35d0, 1321.53d0, 1321.70d0, &
         1321.88d0, 1322.05d0, 1322.23d0, 1322.40d0, 1322.58d0, 1322.75d0, &
         1322.93d0, 1323.10d0, 1323.28d0, 1323.45d0, 1323.63d0, 1323.80d0, &
         1323.98d0, 1324.15d0, 1324.33d0, 1324.50d0, 1324.68d0, 1324.85d0, &
         1325.03d0, 1325.20d0, 1325.38d0, 1325.56d0, 1325.73d0, 1325.91d0, &
         1326.08d0, 1326.26d0, 1326.44d0, 1326.61d0, 1326.79d0, 1326.96d0, &
         1327.14d0, 1327.32d0, 1327.49d0, 1327.67d0, 1327.84d0, 1328.02d0, &
         1328.20d0, 1328.37d0, 1328.55d0, 1328.73d0, 1328.90d0, 1329.08d0, &
         1329.26d0, 1329.43d0, 1329.61d0, 1329.79d0, 1329.96d0, 1330.14d0, &
         1330.32d0, 1330.49d0, 1330.67d0, 1330.85d0, 1331.03d0, 1331.20d0, &
         1331.38d0, 1331.56d0, 1331.73d0, 1331.91d0, 1332.09d0, 1332.27d0, &
         1332.44d0, 1332.62d0, 1332.80d0, 1332.98d0, 1333.16d0, 1333.33d0, &
         1333.51d0, 1333.69d0, 1333.87d0, 1334.05d0, 1334.22d0, 1334.40d0, &
         1334.58d0, 1334.76d0, 1334.94d0, 1335.11d0, 1335.29d0, 1335.47d0, &
         1335.65d0, 1335.83d0, 1336.01d0, 1336.18d0, 1336.36d0, 1336.54d0, &
         1336.72d0, 1336.90d0, 1337.08d0, 1337.26d0, 1337.44d0, 1337.61d0, &
         1337.79d0, 1337.97d0, 1338.15d0, 1338.33d0, 1338.51d0, 1338.69d0, &
         1338.87d0, 1339.05d0, 1339.23d0, 1339.41d0, 1339.58d0, 1339.76d0, &
         1339.94d0, 1340.12d0, 1340.30d0, 1340.48d0, 1340.66d0, 1340.84d0, &
         1341.02d0, 1341.20d0, 1341.38d0, 1341.56d0, 1341.74d0, 1341.92d0, &
         1342.10d0, 1342.28d0, 1342.46d0, 1342.64d0, 1342.82d0, 1343.00d0, &
         1343.18d0, 1343.36d0, 1343.54d0, 1343.72d0, 1343.91d0, 1344.09d0, &
         1344.27d0, 1344.45d0, 1344.63d0, 1344.81d0, 1344.99d0, 1345.17d0, &
         1345.35d0, 1345.53d0, 1345.71d0, 1345.90d0, 1346.08d0, 1346.26d0, &
         1346.44d0, 1346.62d0, 1346.80d0, 1346.98d0, 1347.16d0, 1347.35d0, &
         1347.53d0, 1347.71d0, 1347.89d0, 1348.07d0, 1348.25d0, 1348.44d0, &
         1348.62d0, 1348.80d0, 1348.98d0, 1349.16d0, 1349.35d0, 1349.53d0, &
         1349.71d0, 1349.89d0, 1350.07d0, 1350.26d0, 1350.44d0, 1350.62d0, &
         1350.80d0, 1350.99d0, 1351.17d0, 1351.35d0, 1351.53d0, 1351.72d0, &
         1351.90d0, 1352.08d0, 1352.27d0, 1352.45d0, 1352.63d0, 1352.81d0, &
         1353.00d0, 1353.18d0, 1353.36d0, 1353.55d0, 1353.73d0, 1353.91d0, &
         1354.10d0, 1354.28d0, 1354.46d0, 1354.65d0, 1354.83d0, 1355.01d0, &
         1355.20d0, 1355.38d0, 1355.56d0, 1355.75d0, 1355.93d0, 1356.12d0, &
         1356.30d0, 1356.48d0, 1356.67d0, 1356.85d0, 1357.04d0, 1357.22d0, &
         1357.41d0, 1357.59d0, 1357.77d0, 1357.96d0, 1358.14d0, 1358.33d0, &
         1358.51d0, 1358.70d0, 1358.88d0, 1359.06d0, 1359.25d0, 1359.43d0, &
         1359.62d0, 1359.80d0, 1359.99d0, 1360.17d0, 1360.36d0, 1360.54d0, &
         1360.73d0, 1360.92d0, 1361.10d0, 1361.29d0, 1361.47d0, 1361.66d0/)
 
    wnc(5041:5280)=(/ &
         1361.84d0, 1362.03d0, 1362.21d0, 1362.40d0, 1362.58d0, 1362.77d0, &
         1362.95d0, 1363.14d0, 1363.33d0, 1363.51d0, 1363.70d0, 1363.88d0, &
         1364.07d0, 1364.26d0, 1364.44d0, 1364.63d0, 1364.81d0, 1365.00d0, &
         1365.19d0, 1365.37d0, 1365.56d0, 1365.75d0, 1365.93d0, 1366.12d0, &
         1366.31d0, 1366.49d0, 1366.68d0, 1366.87d0, 1367.05d0, 1367.24d0, &
         1367.43d0, 1367.61d0, 1367.80d0, 1367.99d0, 1368.18d0, 1368.36d0, &
         1368.55d0, 1368.74d0, 1368.93d0, 1369.11d0, 1369.30d0, 1369.49d0, &
         1369.68d0, 1369.86d0, 1370.05d0, 1370.24d0, 1370.43d0, 1370.61d0, &
         1370.80d0, 1370.99d0, 1371.18d0, 1371.37d0, 1371.55d0, 1371.74d0, &
         1371.93d0, 1372.12d0, 1372.31d0, 1372.49d0, 1372.68d0, 1372.87d0, &
         1373.06d0, 1373.25d0, 1373.44d0, 1373.63d0, 1373.81d0, 1374.00d0, &
         1374.19d0, 1374.38d0, 1374.57d0, 1374.76d0, 1374.95d0, 1375.14d0, &
         1375.33d0, 1375.52d0, 1375.70d0, 1375.89d0, 1376.08d0, 1376.27d0, &
         1376.46d0, 1376.65d0, 1376.84d0, 1377.03d0, 1377.22d0, 1377.41d0, &
         1377.60d0, 1377.79d0, 1377.98d0, 1378.17d0, 1378.36d0, 1378.55d0, &
         1378.74d0, 1378.93d0, 1379.12d0, 1379.31d0, 1379.50d0, 1379.69d0, &
         1379.88d0, 1380.07d0, 1380.26d0, 1380.45d0, 1380.64d0, 1380.83d0, &
         1381.03d0, 1381.21d0, 1381.41d0, 1381.60d0, 1381.79d0, 1381.98d0, &
         1382.17d0, 1382.36d0, 1382.55d0, 1382.74d0, 1382.94d0, 1383.13d0, &
         1383.32d0, 1383.51d0, 1383.70d0, 1383.89d0, 1384.08d0, 1384.28d0, &
         1384.47d0, 1384.66d0, 1384.85d0, 1385.04d0, 1385.23d0, 1385.43d0, &
         1385.62d0, 1385.81d0, 1386.00d0, 1386.19d0, 1386.39d0, 1386.58d0, &
         1386.77d0, 1386.96d0, 1387.16d0, 1387.35d0, 1387.54d0, 1387.73d0, &
         1387.93d0, 1388.12d0, 1388.31d0, 1388.50d0, 1388.70d0, 1388.89d0, &
         1389.08d0, 1389.28d0, 1389.47d0, 1389.66d0, 1389.85d0, 1390.05d0, &
         1390.24d0, 1390.43d0, 1390.63d0, 1390.82d0, 1391.01d0, 1391.21d0, &
         1391.40d0, 1391.59d0, 1391.79d0, 1391.98d0, 1392.18d0, 1392.37d0, &
         1392.56d0, 1392.76d0, 1392.95d0, 1393.15d0, 1393.34d0, 1393.53d0, &
         1393.73d0, 1393.92d0, 1394.12d0, 1394.31d0, 1394.51d0, 1394.70d0, &
         1394.90d0, 1395.09d0, 1395.28d0, 1395.48d0, 1395.67d0, 1395.87d0, &
         1396.06d0, 1396.26d0, 1396.45d0, 1396.65d0, 1396.84d0, 1397.04d0, &
         1397.23d0, 1397.43d0, 1397.62d0, 1397.82d0, 1398.02d0, 1398.21d0, &
         1398.41d0, 1398.60d0, 1398.80d0, 1398.99d0, 1399.19d0, 1399.38d0, &
         1399.58d0, 1399.78d0, 1399.97d0, 1400.17d0, 1400.36d0, 1400.56d0, &
         1400.76d0, 1400.95d0, 1401.15d0, 1401.34d0, 1401.54d0, 1401.74d0, &
         1401.94d0, 1402.13d0, 1402.33d0, 1402.53d0, 1402.72d0, 1402.92d0, &
         1403.11d0, 1403.31d0, 1403.51d0, 1403.71d0, 1403.90d0, 1404.10d0, &
         1404.30d0, 1404.49d0, 1404.69d0, 1404.89d0, 1405.09d0, 1405.28d0, &
         1405.48d0, 1405.68d0, 1405.88d0, 1406.07d0, 1406.27d0, 1406.47d0, &
         1406.67d0, 1406.86d0, 1407.06d0, 1407.26d0, 1407.46d0, 1407.66d0/)
 
    wnc(5281:5520)=(/ &
         1407.86d0, 1408.05d0, 1408.25d0, 1408.45d0, 1408.65d0, 1408.85d0, &
         1409.05d0, 1409.24d0, 1409.44d0, 1409.64d0, 1409.84d0, 1410.04d0, &
         1410.24d0, 1410.44d0, 1410.64d0, 1410.83d0, 1411.03d0, 1411.23d0, &
         1411.43d0, 1411.63d0, 1411.83d0, 1412.03d0, 1412.23d0, 1412.43d0, &
         1412.63d0, 1412.83d0, 1413.03d0, 1413.23d0, 1413.43d0, 1413.63d0, &
         1413.83d0, 1414.03d0, 1414.23d0, 1414.43d0, 1414.63d0, 1414.83d0, &
         1415.03d0, 1415.23d0, 1415.43d0, 1415.63d0, 1415.83d0, 1416.03d0, &
         1416.23d0, 1416.43d0, 1416.63d0, 1416.83d0, 1417.03d0, 1417.23d0, &
         1417.43d0, 1417.64d0, 1417.84d0, 1418.04d0, 1418.24d0, 1418.44d0, &
         1418.64d0, 1418.84d0, 1419.04d0, 1419.24d0, 1419.45d0, 1419.65d0, &
         1419.85d0, 1420.05d0, 1420.25d0, 1420.45d0, 1420.66d0, 1420.86d0, &
         1421.06d0, 1421.26d0, 1421.46d0, 1421.67d0, 1421.87d0, 1422.07d0, &
         1422.27d0, 1422.47d0, 1422.68d0, 1422.88d0, 1423.08d0, 1423.29d0, &
         1423.49d0, 1423.69d0, 1423.89d0, 1424.10d0, 1424.30d0, 1424.50d0, &
         1424.70d0, 1424.91d0, 1425.11d0, 1425.31d0, 1425.52d0, 1425.72d0, &
         1425.92d0, 1426.13d0, 1426.33d0, 1426.53d0, 1426.74d0, 1426.94d0, &
         1427.14d0, 1427.35d0, 1427.55d0, 1427.76d0, 1427.96d0, 1428.16d0, &
         1428.37d0, 1428.57d0, 1428.78d0, 1428.98d0, 1429.18d0, 1429.39d0, &
         1429.59d0, 1429.80d0, 1430.00d0, 1430.21d0, 1430.41d0, 1430.61d0, &
         1430.82d0, 1431.03d0, 1431.23d0, 1431.43d0, 1431.64d0, 1431.84d0, &
         1432.05d0, 1432.25d0, 1432.46d0, 1432.67d0, 1432.87d0, 1433.07d0, &
         1433.28d0, 1433.49d0, 1433.69d0, 1433.90d0, 1434.10d0, 1434.31d0, &
         1434.51d0, 1434.72d0, 1434.93d0, 1435.13d0, 1435.34d0, 1435.54d0, &
         1435.75d0, 1435.96d0, 1436.16d0, 1436.37d0, 1436.57d0, 1436.78d0, &
         1436.99d0, 1437.19d0, 1437.40d0, 1437.61d0, 1437.81d0, 1438.02d0, &
         1438.23d0, 1438.44d0, 1438.64d0, 1438.85d0, 1439.06d0, 1439.26d0, &
         1439.47d0, 1439.68d0, 1439.89d0, 1440.09d0, 1440.30d0, 1440.51d0, &
         1440.71d0, 1440.92d0, 1441.13d0, 1441.34d0, 1441.55d0, 1441.75d0, &
         1441.96d0, 1442.17d0, 1442.38d0, 1442.58d0, 1442.79d0, 1443.00d0, &
         1443.21d0, 1443.42d0, 1443.63d0, 1443.83d0, 1444.04d0, 1444.25d0, &
         1444.46d0, 1444.67d0, 1444.88d0, 1445.09d0, 1445.30d0, 1445.50d0, &
         1445.71d0, 1445.92d0, 1446.13d0, 1446.34d0, 1446.55d0, 1446.76d0, &
         1446.97d0, 1447.18d0, 1447.39d0, 1447.60d0, 1447.81d0, 1448.02d0, &
         1448.23d0, 1448.44d0, 1448.65d0, 1448.85d0, 1449.06d0, 1449.28d0, &
         1449.48d0, 1449.70d0, 1449.91d0, 1450.12d0, 1450.33d0, 1450.54d0, &
         1450.75d0, 1450.96d0, 1451.17d0, 1451.38d0, 1451.59d0, 1451.80d0, &
         1452.01d0, 1452.22d0, 1452.43d0, 1452.64d0, 1452.85d0, 1453.07d0, &
         1453.28d0, 1453.49d0, 1453.70d0, 1453.91d0, 1454.12d0, 1454.33d0, &
         1454.55d0, 1454.76d0, 1454.97d0, 1455.18d0, 1455.39d0, 1455.60d0, &
         1455.82d0, 1456.03d0, 1456.24d0, 1456.45d0, 1456.66d0, 1456.88d0/)
 
    wnc(5521:5760)=(/ &
         1457.09d0, 1457.30d0, 1457.51d0, 1457.73d0, 1457.94d0, 1458.15d0, &
         1458.36d0, 1458.58d0, 1458.79d0, 1459.00d0, 1459.21d0, 1459.43d0, &
         1459.64d0, 1459.85d0, 1460.07d0, 1460.28d0, 1460.49d0, 1460.71d0, &
         1460.92d0, 1461.13d0, 1461.35d0, 1461.56d0, 1461.78d0, 1461.99d0, &
         1462.20d0, 1462.42d0, 1462.63d0, 1462.84d0, 1463.06d0, 1463.27d0, &
         1463.49d0, 1463.70d0, 1463.92d0, 1464.13d0, 1464.34d0, 1464.56d0, &
         1464.77d0, 1464.99d0, 1465.20d0, 1465.42d0, 1465.63d0, 1465.85d0, &
         1466.06d0, 1466.28d0, 1466.49d0, 1466.71d0, 1466.92d0, 1467.14d0, &
         1467.35d0, 1467.57d0, 1467.78d0, 1468.00d0, 1468.21d0, 1468.43d0, &
         1468.65d0, 1468.86d0, 1469.08d0, 1469.29d0, 1469.51d0, 1469.72d0, &
         1469.94d0, 1470.16d0, 1470.37d0, 1470.59d0, 1470.81d0, 1471.02d0, &
         1471.24d0, 1471.45d0, 1471.67d0, 1471.89d0, 1472.10d0, 1472.32d0, &
         1472.54d0, 1472.75d0, 1472.97d0, 1473.19d0, 1473.41d0, 1473.62d0, &
         1473.84d0, 1474.06d0, 1474.27d0, 1474.49d0, 1474.71d0, 1474.93d0, &
         1475.14d0, 1475.36d0, 1475.58d0, 1475.80d0, 1476.02d0, 1476.23d0, &
         1476.45d0, 1476.67d0, 1476.89d0, 1477.10d0, 1477.32d0, 1477.54d0, &
         1477.76d0, 1477.98d0, 1478.20d0, 1478.42d0, 1478.63d0, 1478.85d0, &
         1479.07d0, 1479.29d0, 1479.51d0, 1479.73d0, 1479.95d0, 1480.17d0, &
         1480.39d0, 1480.60d0, 1480.82d0, 1481.04d0, 1481.26d0, 1481.48d0, &
         1481.70d0, 1481.92d0, 1482.14d0, 1482.36d0, 1482.58d0, 1482.80d0, &
         1483.02d0, 1483.24d0, 1483.46d0, 1483.68d0, 1483.90d0, 1484.12d0, &
         1484.34d0, 1484.56d0, 1484.78d0, 1485.00d0, 1485.22d0, 1485.44d0, &
         1485.66d0, 1485.88d0, 1486.10d0, 1486.33d0, 1486.55d0, 1486.77d0, &
         1486.99d0, 1487.21d0, 1487.43d0, 1487.65d0, 1487.87d0, 1488.09d0, &
         1488.32d0, 1488.54d0, 1488.76d0, 1488.98d0, 1489.20d0, 1489.43d0, &
         1489.65d0, 1489.87d0, 1490.09d0, 1490.31d0, 1490.54d0, 1490.76d0, &
         1490.98d0, 1491.20d0, 1491.42d0, 1491.65d0, 1491.87d0, 1492.09d0, &
         1492.31d0, 1492.54d0, 1492.76d0, 1492.98d0, 1493.21d0, 1493.43d0, &
         1493.65d0, 1493.88d0, 1494.10d0, 1494.32d0, 1494.55d0, 1494.77d0, &
         1494.99d0, 1495.21d0, 1495.44d0, 1495.66d0, 1495.89d0, 1496.11d0, &
         1496.33d0, 1496.56d0, 1496.78d0, 1497.01d0, 1497.23d0, 1497.45d0, &
         1497.68d0, 1497.90d0, 1498.13d0, 1498.35d0, 1498.58d0, 1498.80d0, &
         1499.03d0, 1499.25d0, 1499.47d0, 1499.70d0, 1499.93d0, 1500.15d0, &
         1500.38d0, 1500.60d0, 1500.82d0, 1501.05d0, 1501.28d0, 1501.50d0, &
         1501.73d0, 1501.95d0, 1502.18d0, 1502.40d0, 1502.63d0, 1502.85d0, &
         1503.08d0, 1503.31d0, 1503.53d0, 1503.76d0, 1503.98d0, 1504.21d0, &
         1504.44d0, 1504.66d0, 1504.89d0, 1505.12d0, 1505.34d0, 1505.57d0, &
         1505.80d0, 1506.02d0, 1506.25d0, 1506.48d0, 1506.70d0, 1506.93d0, &
         1507.16d0, 1507.39d0, 1507.61d0, 1507.84d0, 1508.07d0, 1508.30d0, &
         1508.52d0, 1508.75d0, 1508.98d0, 1509.21d0, 1509.43d0, 1509.66d0/)
 
    wnc(5761:6000)=(/ &
         1509.89d0, 1510.12d0, 1510.35d0, 1510.57d0, 1510.80d0, 1511.03d0, &
         1511.26d0, 1511.49d0, 1511.72d0, 1511.94d0, 1512.17d0, 1512.40d0, &
         1512.63d0, 1512.86d0, 1513.09d0, 1513.32d0, 1513.55d0, 1513.78d0, &
         1514.01d0, 1514.23d0, 1514.46d0, 1514.69d0, 1514.92d0, 1515.15d0, &
         1515.38d0, 1515.61d0, 1515.84d0, 1516.07d0, 1516.30d0, 1516.53d0, &
         1516.76d0, 1516.99d0, 1517.22d0, 1517.45d0, 1517.68d0, 1517.91d0, &
         1518.14d0, 1518.37d0, 1518.60d0, 1518.83d0, 1519.06d0, 1519.30d0, &
         1519.53d0, 1519.76d0, 1519.99d0, 1520.22d0, 1520.45d0, 1520.68d0, &
         1520.91d0, 1521.14d0, 1521.38d0, 1521.61d0, 1521.84d0, 1522.07d0, &
         1522.30d0, 1522.53d0, 1522.77d0, 1523.00d0, 1523.23d0, 1523.46d0, &
         1523.69d0, 1523.93d0, 1524.16d0, 1524.39d0, 1524.62d0, 1524.85d0, &
         1525.09d0, 1525.32d0, 1525.55d0, 1525.79d0, 1526.02d0, 1526.25d0, &
         1526.48d0, 1526.72d0, 1526.95d0, 1527.18d0, 1527.42d0, 1527.65d0, &
         1527.88d0, 1528.12d0, 1528.35d0, 1528.58d0, 1528.82d0, 1529.05d0, &
         1529.29d0, 1529.52d0, 1529.75d0, 1529.99d0, 1530.22d0, 1530.46d0, &
         1530.69d0, 1530.93d0, 1531.16d0, 1531.39d0, 1531.63d0, 1531.86d0, &
         1532.10d0, 1532.33d0, 1532.57d0, 1532.80d0, 1533.04d0, 1533.27d0, &
         1533.51d0, 1533.74d0, 1533.98d0, 1534.21d0, 1534.45d0, 1534.68d0, &
         1534.92d0, 1535.16d0, 1535.39d0, 1535.63d0, 1535.86d0, 1536.10d0, &
         1536.33d0, 1536.57d0, 1536.81d0, 1537.04d0, 1537.28d0, 1537.52d0, &
         1537.75d0, 1537.99d0, 1538.22d0, 1538.46d0, 1538.70d0, 1538.94d0, &
         1539.17d0, 1539.41d0, 1539.65d0, 1539.88d0, 1540.12d0, 1540.36d0, &
         1540.59d0, 1540.83d0, 1541.07d0, 1541.31d0, 1541.55d0, 1541.78d0, &
         1542.02d0, 1542.26d0, 1542.50d0, 1542.73d0, 1542.97d0, 1543.21d0, &
         1543.45d0, 1543.69d0, 1543.93d0, 1544.16d0, 1544.40d0, 1544.64d0, &
         1544.88d0, 1545.12d0, 1545.36d0, 1545.59d0, 1545.83d0, 1546.07d0, &
         1546.31d0, 1546.55d0, 1546.79d0, 1547.03d0, 1547.27d0, 1547.51d0, &
         1547.75d0, 1547.99d0, 1548.23d0, 1548.47d0, 1548.71d0, 1548.95d0, &
         1549.19d0, 1549.43d0, 1549.67d0, 1549.91d0, 1550.15d0, 1550.39d0, &
         1550.63d0, 1550.87d0, 1551.11d0, 1551.35d0, 1551.59d0, 1551.83d0, &
         1552.07d0, 1552.31d0, 1552.55d0, 1552.80d0, 1553.04d0, 1553.28d0, &
         1553.52d0, 1553.76d0, 1554.00d0, 1554.24d0, 1554.48d0, 1554.73d0, &
         1554.97d0, 1555.21d0, 1555.45d0, 1555.69d0, 1555.94d0, 1556.18d0, &
         1556.42d0, 1556.66d0, 1556.91d0, 1557.15d0, 1557.39d0, 1557.63d0, &
         1557.88d0, 1558.12d0, 1558.36d0, 1558.60d0, 1558.85d0, 1559.09d0, &
         1559.33d0, 1559.58d0, 1559.82d0, 1560.06d0, 1560.31d0, 1560.55d0, &
         1560.79d0, 1561.04d0, 1561.28d0, 1561.52d0, 1561.77d0, 1562.01d0, &
         1562.26d0, 1562.50d0, 1562.74d0, 1562.99d0, 1563.23d0, 1563.48d0, &
         1563.72d0, 1563.97d0, 1564.21d0, 1564.46d0, 1564.70d0, 1564.94d0, &
         1565.19d0, 1565.44d0, 1565.68d0, 1565.93d0, 1566.17d0, 1566.42d0/)
 
    wnc(6001:6240)=(/ &
         1566.66d0, 1566.91d0, 1567.15d0, 1567.40d0, 1567.64d0, 1567.89d0, &
         1568.14d0, 1568.38d0, 1568.63d0, 1568.87d0, 1569.12d0, 1569.37d0, &
         1569.61d0, 1569.86d0, 1570.10d0, 1570.35d0, 1570.60d0, 1570.84d0, &
         1571.09d0, 1571.34d0, 1571.59d0, 1571.83d0, 1572.08d0, 1572.33d0, &
         1572.57d0, 1572.82d0, 1573.07d0, 1573.32d0, 1573.56d0, 1573.81d0, &
         1574.06d0, 1574.31d0, 1574.56d0, 1574.80d0, 1575.05d0, 1575.30d0, &
         1575.55d0, 1575.80d0, 1576.04d0, 1576.29d0, 1576.54d0, 1576.79d0, &
         1577.04d0, 1577.29d0, 1577.54d0, 1577.79d0, 1578.03d0, 1578.28d0, &
         1578.53d0, 1578.78d0, 1579.03d0, 1579.28d0, 1579.53d0, 1579.78d0, &
         1580.03d0, 1580.28d0, 1580.53d0, 1580.78d0, 1581.03d0, 1581.28d0, &
         1581.53d0, 1581.78d0, 1582.03d0, 1582.28d0, 1582.53d0, 1582.78d0, &
         1583.03d0, 1583.28d0, 1583.53d0, 1583.78d0, 1584.03d0, 1584.28d0, &
         1584.54d0, 1584.79d0, 1585.04d0, 1585.29d0, 1585.54d0, 1585.79d0, &
         1586.04d0, 1586.29d0, 1586.55d0, 1586.80d0, 1587.05d0, 1587.30d0, &
         1587.55d0, 1587.81d0, 1588.06d0, 1588.31d0, 1588.56d0, 1588.81d0, &
         1589.07d0, 1589.32d0, 1589.57d0, 1589.82d0, 1590.08d0, 1590.33d0, &
         1590.58d0, 1590.84d0, 1591.09d0, 1591.34d0, 1591.60d0, 1591.85d0, &
         1592.10d0, 1592.36d0, 1592.61d0, 1592.86d0, 1593.12d0, 1593.37d0, &
         1593.63d0, 1593.88d0, 1594.13d0, 1594.39d0, 1594.64d0, 1594.90d0, &
         1595.15d0, 1595.41d0, 1595.66d0, 1595.91d0, 1596.17d0, 1596.42d0, &
         1596.68d0, 1596.93d0, 1597.19d0, 1597.44d0, 1597.70d0, 1597.95d0, &
         1598.21d0, 1598.46d0, 1598.72d0, 1598.98d0, 1599.23d0, 1599.49d0, &
         1599.74d0, 1600.00d0, 1600.26d0, 1600.51d0, 1600.77d0, 1601.03d0, &
         1601.28d0, 1601.54d0, 1601.79d0, 1602.05d0, 1602.31d0, 1602.56d0, &
         1602.82d0, 1603.08d0, 1603.33d0, 1603.59d0, 1603.85d0, 1604.11d0, &
         1604.36d0, 1604.62d0, 1604.88d0, 1605.14d0, 1605.39d0, 1605.65d0, &
         1605.91d0, 1606.17d0, 1606.43d0, 1606.68d0, 1606.94d0, 1607.20d0, &
         1607.46d0, 1607.72d0, 1607.98d0, 1608.23d0, 1608.49d0, 1608.75d0, &
         1609.01d0, 1609.27d0, 1609.53d0, 1609.79d0, 1610.05d0, 1610.31d0, &
         1610.56d0, 1610.82d0, 1611.08d0, 1611.34d0, 1611.60d0, 1611.86d0, &
         1612.12d0, 1612.38d0, 1612.64d0, 1612.90d0, 1613.16d0, 1613.42d0, &
         1613.68d0, 1613.94d0, 1614.20d0, 1614.47d0, 1614.73d0, 1614.99d0, &
         1615.25d0, 1615.51d0, 1615.77d0, 1616.03d0, 1616.29d0, 1616.55d0, &
         1616.81d0, 1617.08d0, 1617.34d0, 1617.60d0, 1617.86d0, 1618.12d0, &
         1618.39d0, 1618.65d0, 1618.91d0, 1619.17d0, 1619.43d0, 1619.70d0, &
         1619.96d0, 1620.22d0, 1620.48d0, 1620.74d0, 1621.01d0, 1621.27d0, &
         1621.53d0, 1621.80d0, 1622.06d0, 1622.32d0, 1622.59d0, 1622.85d0, &
         1623.11d0, 1623.38d0, 1623.64d0, 1623.90d0, 1624.17d0, 1624.43d0, &
         1624.69d0, 1624.96d0, 1625.22d0, 1625.49d0, 1625.75d0, 1626.02d0, &
         1626.28d0, 1626.55d0, 1626.81d0, 1627.07d0, 1627.34d0, 1627.60d0/)
 
    wnc(6241:6480)=(/ &
         1627.87d0, 1628.13d0, 1628.40d0, 1628.67d0, 1628.93d0, 1629.19d0, &
         1629.46d0, 1629.73d0, 1629.99d0, 1630.26d0, 1630.52d0, 1630.79d0, &
         1631.06d0, 1631.32d0, 1631.59d0, 1631.85d0, 1632.12d0, 1632.39d0, &
         1632.65d0, 1632.92d0, 1633.19d0, 1633.45d0, 1633.72d0, 1633.99d0, &
         1634.25d0, 1634.52d0, 1634.79d0, 1635.06d0, 1635.32d0, 1635.59d0, &
         1635.86d0, 1636.13d0, 1636.39d0, 1636.66d0, 1636.93d0, 1637.20d0, &
         1637.46d0, 1637.73d0, 1638.00d0, 1638.27d0, 1638.54d0, 1638.81d0, &
         1639.08d0, 1639.34d0, 1639.61d0, 1639.88d0, 1640.15d0, 1640.42d0, &
         1640.69d0, 1640.96d0, 1641.23d0, 1641.50d0, 1641.77d0, 1642.04d0, &
         1642.31d0, 1642.58d0, 1642.84d0, 1643.11d0, 1643.39d0, 1643.66d0, &
         1643.93d0, 1644.20d0, 1644.47d0, 1644.74d0, 1645.01d0, 1645.28d0, &
         1645.55d0, 1645.82d0, 1646.09d0, 1646.36d0, 1646.63d0, 1646.90d0, &
         1647.18d0, 1647.45d0, 1647.72d0, 1647.99d0, 1648.26d0, 1648.53d0, &
         1648.81d0, 1649.08d0, 1649.35d0, 1649.62d0, 1649.89d0, 1650.17d0, &
         1650.44d0, 1650.71d0, 1650.98d0, 1651.26d0, 1651.53d0, 1651.80d0, &
         1652.07d0, 1652.35d0, 1652.62d0, 1652.89d0, 1653.17d0, 1653.44d0, &
         1653.71d0, 1653.99d0, 1654.26d0, 1654.53d0, 1654.81d0, 1655.08d0, &
         1655.35d0, 1655.63d0, 1655.90d0, 1656.18d0, 1656.45d0, 1656.73d0, &
         1657.00d0, 1657.28d0, 1657.55d0, 1657.82d0, 1658.10d0, 1658.38d0, &
         1658.65d0, 1658.93d0, 1659.20d0, 1659.48d0, 1659.75d0, 1660.03d0, &
         1660.30d0, 1660.58d0, 1660.85d0, 1661.13d0, 1661.41d0, 1661.68d0, &
         1661.96d0, 1662.23d0, 1662.51d0, 1662.79d0, 1663.06d0, 1663.34d0, &
         1663.62d0, 1663.89d0, 1664.17d0, 1664.45d0, 1664.72d0, 1665.00d0, &
         1665.28d0, 1665.56d0, 1665.83d0, 1666.11d0, 1666.39d0, 1666.67d0, &
         1666.94d0, 1667.22d0, 1667.50d0, 1667.78d0, 1668.06d0, 1668.33d0, &
         1668.61d0, 1668.89d0, 1669.17d0, 1669.45d0, 1669.73d0, 1670.01d0, &
         1670.29d0, 1670.56d0, 1670.84d0, 1671.12d0, 1671.40d0, 1671.68d0, &
         1671.96d0, 1672.24d0, 1672.52d0, 1672.80d0, 1673.08d0, 1673.36d0, &
         1673.64d0, 1673.92d0, 1674.20d0, 1674.48d0, 1674.76d0, 1675.04d0, &
         1675.32d0, 1675.60d0, 1675.88d0, 1676.17d0, 1676.45d0, 1676.73d0, &
         1677.01d0, 1677.29d0, 1677.57d0, 1677.85d0, 1678.13d0, 1678.42d0, &
         1678.70d0, 1678.98d0, 1679.26d0, 1679.54d0, 1679.82d0, 1680.11d0, &
         1680.39d0, 1680.67d0, 1680.95d0, 1681.24d0, 1681.52d0, 1681.80d0, &
         1682.09d0, 1682.37d0, 1682.65d0, 1682.94d0, 1683.22d0, 1683.50d0, &
         1683.79d0, 1684.07d0, 1684.35d0, 1684.64d0, 1684.92d0, 1685.20d0, &
         1685.49d0, 1685.77d0, 1686.06d0, 1686.34d0, 1686.63d0, 1686.91d0, &
         1687.19d0, 1687.48d0, 1687.76d0, 1688.05d0, 1688.33d0, 1688.62d0, &
         1688.90d0, 1689.19d0, 1689.47d0, 1689.76d0, 1690.05d0, 1690.33d0, &
         1690.62d0, 1690.90d0, 1691.19d0, 1691.47d0, 1691.76d0, 1692.05d0, &
         1692.33d0, 1692.62d0, 1692.91d0, 1693.19d0, 1693.48d0, 1693.77d0/)
 
    wnc(6481:6720)=(/ &
         1694.05d0, 1694.34d0, 1694.63d0, 1694.92d0, 1695.20d0, 1695.49d0, &
         1695.78d0, 1696.06d0, 1696.35d0, 1696.64d0, 1696.93d0, 1697.22d0, &
         1697.51d0, 1697.79d0, 1698.08d0, 1698.37d0, 1698.66d0, 1698.95d0, &
         1699.23d0, 1699.52d0, 1699.81d0, 1700.10d0, 1700.39d0, 1700.68d0, &
         1700.97d0, 1701.26d0, 1701.55d0, 1701.84d0, 1702.13d0, 1702.42d0, &
         1702.71d0, 1703.00d0, 1703.29d0, 1703.58d0, 1703.87d0, 1704.16d0, &
         1704.45d0, 1704.74d0, 1705.03d0, 1705.32d0, 1705.61d0, 1705.90d0, &
         1706.19d0, 1706.48d0, 1706.78d0, 1707.07d0, 1707.36d0, 1707.65d0, &
         1707.94d0, 1708.23d0, 1708.53d0, 1708.82d0, 1709.11d0, 1709.40d0, &
         1709.69d0, 1709.99d0, 1710.28d0, 1710.57d0, 1710.86d0, 1711.16d0, &
         1711.45d0, 1711.74d0, 1712.04d0, 1712.33d0, 1712.62d0, 1712.92d0, &
         1713.21d0, 1713.50d0, 1713.80d0, 1714.09d0, 1714.38d0, 1714.68d0, &
         1714.97d0, 1715.27d0, 1715.56d0, 1715.85d0, 1716.15d0, 1716.44d0, &
         1716.74d0, 1717.03d0, 1717.33d0, 1717.62d0, 1717.92d0, 1718.21d0, &
         1718.51d0, 1718.80d0, 1719.10d0, 1719.40d0, 1719.69d0, 1719.99d0, &
         1720.28d0, 1720.58d0, 1720.87d0, 1721.17d0, 1721.47d0, 1721.76d0, &
         1722.06d0, 1722.36d0, 1722.65d0, 1722.95d0, 1723.25d0, 1723.54d0, &
         1723.84d0, 1724.14d0, 1724.44d0, 1724.73d0, 1725.03d0, 1725.33d0, &
         1725.63d0, 1725.92d0, 1726.22d0, 1726.52d0, 1726.82d0, 1727.12d0, &
         1727.41d0, 1727.71d0, 1728.01d0, 1728.31d0, 1728.61d0, 1728.91d0, &
         1729.21d0, 1729.51d0, 1729.81d0, 1730.10d0, 1730.40d0, 1730.70d0, &
         1731.00d0, 1731.30d0, 1731.60d0, 1731.90d0, 1732.20d0, 1732.50d0, &
         1732.80d0, 1733.10d0, 1733.40d0, 1733.70d0, 1734.00d0, 1734.31d0, &
         1734.60d0, 1734.91d0, 1735.21d0, 1735.51d0, 1735.81d0, 1736.11d0, &
         1736.41d0, 1736.71d0, 1737.02d0, 1737.32d0, 1737.62d0, 1737.92d0, &
         1738.22d0, 1738.53d0, 1738.83d0, 1739.13d0, 1739.43d0, 1739.74d0, &
         1740.04d0, 1740.34d0, 1740.64d0, 1740.95d0, 1741.25d0, 1741.55d0, &
         1741.86d0, 1742.16d0, 1742.46d0, 1742.77d0, 1743.07d0, 1743.38d0, &
         1743.68d0, 1743.98d0, 1744.29d0, 1744.59d0, 1744.90d0, 1745.20d0, &
         1745.51d0, 1745.81d0, 1746.11d0, 1746.42d0, 1746.72d0, 1747.03d0, &
         1747.33d0, 1747.64d0, 1747.95d0, 1748.25d0, 1748.56d0, 1748.86d0, &
         1749.17d0, 1749.47d0, 1749.78d0, 1750.09d0, 1750.39d0, 1750.70d0, &
         1751.01d0, 1751.31d0, 1751.62d0, 1751.93d0, 1752.23d0, 1752.54d0, &
         1752.85d0, 1753.16d0, 1753.46d0, 1753.77d0, 1754.08d0, 1754.39d0, &
         1754.69d0, 1755.00d0, 1755.31d0, 1755.62d0, 1755.93d0, 1756.23d0, &
         1756.54d0, 1756.85d0, 1757.16d0, 1757.47d0, 1757.78d0, 1758.09d0, &
         1758.40d0, 1758.71d0, 1759.02d0, 1759.32d0, 1759.63d0, 1759.94d0, &
         1760.25d0, 1760.56d0, 1760.87d0, 1761.18d0, 1761.49d0, 1761.80d0, &
         1762.11d0, 1762.43d0, 1762.74d0, 1763.05d0, 1763.36d0, 1763.67d0, &
         1763.98d0, 1764.29d0, 1764.60d0, 1764.91d0, 1765.22d0, 1765.54d0/)
 
    wnc(6721:6960)=(/ &
         1765.85d0, 1766.16d0, 1766.47d0, 1766.78d0, 1767.10d0, 1767.41d0, &
         1767.72d0, 1768.03d0, 1768.35d0, 1768.66d0, 1768.97d0, 1769.29d0, &
         1769.60d0, 1769.91d0, 1770.22d0, 1770.54d0, 1770.85d0, 1771.17d0, &
         1771.48d0, 1771.79d0, 1772.11d0, 1772.42d0, 1772.73d0, 1773.05d0, &
         1773.36d0, 1773.68d0, 1773.99d0, 1774.31d0, 1774.62d0, 1774.94d0, &
         1775.25d0, 1775.57d0, 1775.88d0, 1776.20d0, 1776.52d0, 1776.83d0, &
         1777.15d0, 1777.46d0, 1777.78d0, 1778.09d0, 1778.41d0, 1778.73d0, &
         1779.04d0, 1779.36d0, 1779.68d0, 1779.99d0, 1780.31d0, 1780.63d0, &
         1780.94d0, 1781.26d0, 1781.58d0, 1781.90d0, 1782.21d0, 1782.53d0, &
         1782.85d0, 1783.17d0, 1783.48d0, 1783.80d0, 1784.12d0, 1784.44d0, &
         1784.76d0, 1785.08d0, 1785.40d0, 1785.71d0, 1786.03d0, 1786.35d0, &
         1786.67d0, 1786.99d0, 1787.31d0, 1787.63d0, 1787.95d0, 1788.27d0, &
         1788.59d0, 1788.91d0, 1789.23d0, 1789.55d0, 1789.87d0, 1790.19d0, &
         1790.51d0, 1790.83d0, 1791.15d0, 1791.47d0, 1791.79d0, 1792.11d0, &
         1792.44d0, 1792.76d0, 1793.08d0, 1793.40d0, 1793.72d0, 1794.04d0, &
         1794.37d0, 1794.69d0, 1795.01d0, 1795.33d0, 1795.66d0, 1795.98d0, &
         1796.30d0, 1796.62d0, 1796.94d0, 1797.27d0, 1797.59d0, 1797.91d0, &
         1798.24d0, 1798.56d0, 1798.89d0, 1799.21d0, 1799.53d0, 1799.86d0, &
         1800.18d0, 1800.50d0, 1800.83d0, 1801.15d0, 1801.48d0, 1801.80d0, &
         1802.13d0, 1802.45d0, 1802.78d0, 1803.10d0, 1803.43d0, 1803.75d0, &
         1804.08d0, 1804.40d0, 1804.73d0, 1805.05d0, 1805.38d0, 1805.71d0, &
         1806.03d0, 1806.36d0, 1806.69d0, 1807.01d0, 1807.34d0, 1807.67d0, &
         1807.99d0, 1808.32d0, 1808.65d0, 1808.97d0, 1809.30d0, 1809.63d0, &
         1809.95d0, 1810.28d0, 1810.61d0, 1810.94d0, 1811.27d0, 1811.59d0, &
         1811.92d0, 1812.25d0, 1812.58d0, 1812.91d0, 1813.24d0, 1813.57d0, &
         1813.89d0, 1814.22d0, 1814.55d0, 1814.88d0, 1815.21d0, 1815.54d0, &
         1815.87d0, 1816.20d0, 1816.53d0, 1816.86d0, 1817.19d0, 1817.52d0, &
         1817.85d0, 1818.18d0, 1818.51d0, 1818.84d0, 1819.17d0, 1819.51d0, &
         1819.84d0, 1820.17d0, 1820.50d0, 1820.83d0, 1821.16d0, 1821.49d0, &
         1821.83d0, 1822.16d0, 1822.49d0, 1822.82d0, 1823.15d0, 1823.49d0, &
         1823.82d0, 1824.15d0, 1824.48d0, 1824.82d0, 1825.15d0, 1825.48d0, &
         1825.82d0, 1826.15d0, 1826.48d0, 1826.82d0, 1827.15d0, 1827.48d0, &
         1827.82d0, 1828.15d0, 1828.49d0, 1828.82d0, 1829.16d0, 1829.49d0, &
         1829.83d0, 1830.16d0, 1830.50d0, 1830.83d0, 1831.17d0, 1831.50d0, &
         1831.84d0, 1832.17d0, 1832.51d0, 1832.84d0, 1833.18d0, 1833.52d0, &
         1833.85d0, 1834.19d0, 1834.53d0, 1834.86d0, 1835.20d0, 1835.54d0, &
         1835.87d0, 1836.21d0, 1836.55d0, 1836.89d0, 1837.22d0, 1837.56d0, &
         1837.90d0, 1838.23d0, 1838.57d0, 1838.91d0, 1839.25d0, 1839.59d0, &
         1839.93d0, 1840.27d0, 1840.60d0, 1840.94d0, 1841.28d0, 1841.62d0, &
         1841.96d0, 1842.30d0, 1842.64d0, 1842.98d0, 1843.32d0, 1843.66d0/)
 
    wnc(6961:7200)=(/ &
         1844.00d0, 1844.34d0, 1844.68d0, 1845.02d0, 1845.36d0, 1845.70d0, &
         1846.04d0, 1846.38d0, 1846.72d0, 1847.06d0, 1847.40d0, 1847.75d0, &
         1848.09d0, 1848.43d0, 1848.77d0, 1849.11d0, 1849.45d0, 1849.80d0, &
         1850.14d0, 1850.48d0, 1850.82d0, 1851.17d0, 1851.51d0, 1851.85d0, &
         1852.19d0, 1852.54d0, 1852.88d0, 1853.22d0, 1853.57d0, 1853.91d0, &
         1854.26d0, 1854.60d0, 1854.94d0, 1855.29d0, 1855.63d0, 1855.98d0, &
         1856.32d0, 1856.67d0, 1857.01d0, 1857.35d0, 1857.70d0, 1858.05d0, &
         1858.39d0, 1858.74d0, 1859.08d0, 1859.43d0, 1859.77d0, 1860.12d0, &
         1860.46d0, 1860.81d0, 1861.16d0, 1861.50d0, 1861.85d0, 1862.20d0, &
         1862.54d0, 1862.89d0, 1863.24d0, 1863.59d0, 1863.93d0, 1864.28d0, &
         1864.63d0, 1864.98d0, 1865.32d0, 1865.67d0, 1866.02d0, 1866.37d0, &
         1866.72d0, 1867.06d0, 1867.41d0, 1867.76d0, 1868.11d0, 1868.46d0, &
         1868.81d0, 1869.16d0, 1869.51d0, 1869.86d0, 1870.21d0, 1870.56d0, &
         1870.91d0, 1871.26d0, 1871.61d0, 1871.96d0, 1872.31d0, 1872.66d0, &
         1873.01d0, 1873.36d0, 1873.71d0, 1874.06d0, 1874.41d0, 1874.77d0, &
         1875.12d0, 1875.47d0, 1875.82d0, 1876.17d0, 1876.53d0, 1876.88d0, &
         1877.23d0, 1877.58d0, 1877.93d0, 1878.29d0, 1878.64d0, 1878.99d0, &
         1879.35d0, 1879.70d0, 1880.05d0, 1880.41d0, 1880.76d0, 1881.11d0, &
         1881.47d0, 1881.82d0, 1882.18d0, 1882.53d0, 1882.89d0, 1883.24d0, &
         1883.59d0, 1883.95d0, 1884.30d0, 1884.66d0, 1885.01d0, 1885.37d0, &
         1885.72d0, 1886.08d0, 1886.44d0, 1886.79d0, 1887.15d0, 1887.51d0, &
         1887.86d0, 1888.22d0, 1888.57d0, 1888.93d0, 1889.29d0, 1889.65d0, &
         1890.00d0, 1890.36d0, 1890.72d0, 1891.07d0, 1891.43d0, 1891.79d0, &
         1892.15d0, 1892.51d0, 1892.86d0, 1893.22d0, 1893.58d0, 1893.94d0, &
         1894.30d0, 1894.66d0, 1895.02d0, 1895.38d0, 1895.73d0, 1896.09d0, &
         1896.45d0, 1896.81d0, 1897.17d0, 1897.53d0, 1897.89d0, 1898.25d0, &
         1898.61d0, 1898.97d0, 1899.33d0, 1899.70d0, 1900.06d0, 1900.42d0, &
         1900.78d0, 1901.14d0, 1901.50d0, 1901.86d0, 1902.23d0, 1902.59d0, &
         1902.95d0, 1903.31d0, 1903.67d0, 1904.04d0, 1904.40d0, 1904.76d0, &
         1905.13d0, 1905.49d0, 1905.85d0, 1906.21d0, 1906.58d0, 1906.94d0, &
         1907.31d0, 1907.67d0, 1908.03d0, 1908.40d0, 1908.76d0, 1909.13d0, &
         1909.49d0, 1909.85d0, 1910.22d0, 1910.58d0, 1910.95d0, 1911.31d0, &
         1911.68d0, 1912.05d0, 1912.41d0, 1912.78d0, 1913.14d0, 1913.51d0, &
         1913.88d0, 1914.24d0, 1914.61d0, 1914.97d0, 1915.34d0, 1915.71d0, &
         1916.08d0, 1916.44d0, 1916.81d0, 1917.18d0, 1917.55d0, 1917.91d0, &
         1918.28d0, 1918.65d0, 1919.02d0, 1919.39d0, 1919.75d0, 1920.12d0, &
         1920.49d0, 1920.86d0, 1921.23d0, 1921.60d0, 1921.97d0, 1922.34d0, &
         1922.71d0, 1923.08d0, 1923.45d0, 1923.82d0, 1924.19d0, 1924.56d0, &
         1924.93d0, 1925.30d0, 1925.67d0, 1926.04d0, 1926.41d0, 1926.78d0, &
         1927.15d0, 1927.53d0, 1927.90d0, 1928.27d0, 1928.64d0, 1929.01d0/)
 
    wnc(7201:7440)=(/ &
         1929.39d0, 1929.76d0, 1930.13d0, 1930.50d0, 1930.88d0, 1931.25d0, &
         1931.62d0, 1931.99d0, 1932.37d0, 1932.74d0, 1933.11d0, 1933.49d0, &
         1933.86d0, 1934.24d0, 1934.61d0, 1934.98d0, 1935.36d0, 1935.73d0, &
         1936.11d0, 1936.48d0, 1936.86d0, 1937.23d0, 1937.61d0, 1937.98d0, &
         1938.36d0, 1938.74d0, 1939.11d0, 1939.49d0, 1939.86d0, 1940.24d0, &
         1940.62d0, 1940.99d0, 1941.37d0, 1941.75d0, 1942.13d0, 1942.50d0, &
         1942.88d0, 1943.26d0, 1943.64d0, 1944.01d0, 1944.39d0, 1944.77d0, &
         1945.15d0, 1945.53d0, 1945.90d0, 1946.28d0, 1946.66d0, 1947.04d0, &
         1947.42d0, 1947.80d0, 1948.18d0, 1948.56d0, 1948.94d0, 1949.32d0, &
         1949.70d0, 1950.08d0, 1950.46d0, 1950.84d0, 1951.22d0, 1951.60d0, &
         1951.98d0, 1952.36d0, 1952.74d0, 1953.13d0, 1953.51d0, 1953.89d0, &
         1954.27d0, 1954.65d0, 1955.03d0, 1955.42d0, 1955.80d0, 1956.18d0, &
         1956.56d0, 1956.95d0, 1957.33d0, 1957.71d0, 1958.10d0, 1958.48d0, &
         1958.86d0, 1959.25d0, 1959.63d0, 1960.02d0, 1960.40d0, 1960.78d0, &
         1961.17d0, 1961.55d0, 1961.94d0, 1962.32d0, 1962.71d0, 1963.09d0, &
         1963.48d0, 1963.86d0, 1964.25d0, 1964.64d0, 1965.02d0, 1965.41d0, &
         1965.80d0, 1966.18d0, 1966.57d0, 1966.95d0, 1967.34d0, 1967.73d0, &
         1968.12d0, 1968.50d0, 1968.89d0, 1969.28d0, 1969.67d0, 1970.06d0, &
         1970.44d0, 1970.83d0, 1971.22d0, 1971.61d0, 1972.00d0, 1972.39d0, &
         1972.78d0, 1973.17d0, 1973.55d0, 1973.94d0, 1974.33d0, 1974.72d0, &
         1975.11d0, 1975.50d0, 1975.89d0, 1976.29d0, 1976.68d0, 1977.07d0, &
         1977.46d0, 1977.85d0, 1978.24d0, 1978.63d0, 1979.02d0, 1979.41d0, &
         1979.81d0, 1980.20d0, 1980.59d0, 1980.98d0, 1981.38d0, 1981.77d0, &
         1982.16d0, 1982.55d0, 1982.95d0, 1983.34d0, 1983.73d0, 1984.13d0, &
         1984.52d0, 1984.92d0, 1985.31d0, 1985.70d0, 1986.10d0, 1986.49d0, &
         1986.89d0, 1987.28d0, 1987.68d0, 1988.07d0, 1988.47d0, 1988.86d0, &
         1989.26d0, 1989.65d0, 1990.05d0, 1990.45d0, 1990.84d0, 1991.24d0, &
         1991.64d0, 1992.03d0, 1992.43d0, 1992.83d0, 1993.22d0, 1993.62d0, &
         1994.02d0, 1994.42d0, 1994.81d0, 1995.21d0, 1995.61d0, 1996.01d0, &
         1996.41d0, 1996.81d0, 1997.20d0, 1997.60d0, 1998.00d0, 1998.40d0, &
         1998.80d0, 1999.20d0, 1999.60d0, 2000.00d0, 2000.40d0, 2000.80d0, &
         2001.20d0, 2001.60d0, 2002.00d0, 2002.40d0, 2002.80d0, 2003.20d0, &
         2003.61d0, 2004.01d0, 2004.41d0, 2004.81d0, 2005.21d0, 2005.62d0, &
         2006.02d0, 2006.42d0, 2006.82d0, 2007.23d0, 2007.63d0, 2008.03d0, &
         2008.44d0, 2008.84d0, 2009.24d0, 2009.65d0, 2010.05d0, 2010.45d0, &
         2010.86d0, 2011.26d0, 2011.67d0, 2012.07d0, 2012.48d0, 2012.88d0, &
         2013.29d0, 2013.69d0, 2014.10d0, 2014.50d0, 2014.91d0, 2015.32d0, &
         2015.72d0, 2016.13d0, 2016.54d0, 2016.94d0, 2017.35d0, 2017.76d0, &
         2018.16d0, 2018.57d0, 2018.98d0, 2019.39d0, 2019.79d0, 2020.20d0, &
         2020.61d0, 2021.02d0, 2021.43d0, 2021.84d0, 2022.24d0, 2022.65d0/)
 
    wnc(7441:7680)=(/ &
         2023.06d0, 2023.47d0, 2023.88d0, 2024.29d0, 2024.70d0, 2025.11d0, &
         2025.52d0, 2025.93d0, 2026.34d0, 2026.75d0, 2027.16d0, 2027.57d0, &
         2027.99d0, 2028.40d0, 2028.81d0, 2029.22d0, 2029.63d0, 2030.05d0, &
         2030.46d0, 2030.87d0, 2031.28d0, 2031.69d0, 2032.11d0, 2032.52d0, &
         2032.93d0, 2033.35d0, 2033.76d0, 2034.17d0, 2034.59d0, 2035.00d0, &
         2035.42d0, 2035.83d0, 2036.24d0, 2036.66d0, 2037.07d0, 2037.49d0, &
         2037.91d0, 2038.32d0, 2038.74d0, 2039.15d0, 2039.57d0, 2039.98d0, &
         2040.40d0, 2040.82d0, 2041.23d0, 2041.65d0, 2042.07d0, 2042.48d0, &
         2042.90d0, 2043.32d0, 2043.74d0, 2044.15d0, 2044.57d0, 2044.99d0, &
         2045.41d0, 2045.83d0, 2046.24d0, 2046.66d0, 2047.08d0, 2047.50d0, &
         2047.92d0, 2048.34d0, 2048.76d0, 2049.18d0, 2049.60d0, 2050.02d0, &
         2050.44d0, 2050.86d0, 2051.28d0, 2051.70d0, 2052.12d0, 2052.54d0, &
         2052.97d0, 2053.39d0, 2053.81d0, 2054.23d0, 2054.65d0, 2055.08d0, &
         2055.50d0, 2055.92d0, 2056.34d0, 2056.77d0, 2057.19d0, 2057.61d0, &
         2058.04d0, 2058.46d0, 2058.88d0, 2059.31d0, 2059.73d0, 2060.16d0, &
         2060.58d0, 2061.01d0, 2061.43d0, 2061.85d0, 2062.28d0, 2062.71d0, &
         2063.13d0, 2063.56d0, 2063.98d0, 2064.41d0, 2064.84d0, 2065.26d0, &
         2065.69d0, 2066.12d0, 2066.54d0, 2066.97d0, 2067.40d0, 2067.82d0, &
         2068.25d0, 2068.68d0, 2069.11d0, 2069.54d0, 2069.97d0, 2070.39d0, &
         2070.82d0, 2071.25d0, 2071.68d0, 2072.11d0, 2072.54d0, 2072.97d0, &
         2073.40d0, 2073.83d0, 2074.26d0, 2074.69d0, 2075.12d0, 2075.55d0, &
         2075.98d0, 2076.41d0, 2076.84d0, 2077.27d0, 2077.71d0, 2078.14d0, &
         2078.57d0, 2079.00d0, 2079.43d0, 2079.87d0, 2080.30d0, 2080.73d0, &
         2081.17d0, 2081.60d0, 2082.03d0, 2082.47d0, 2082.90d0, 2083.33d0, &
         2083.77d0, 2084.20d0, 2084.64d0, 2085.07d0, 2085.51d0, 2085.94d0, &
         2086.38d0, 2086.81d0, 2087.25d0, 2087.68d0, 2088.12d0, 2088.55d0, &
         2088.99d0, 2089.43d0, 2089.86d0, 2090.30d0, 2090.74d0, 2091.18d0, &
         2091.61d0, 2092.05d0, 2092.49d0, 2092.93d0, 2093.36d0, 2093.80d0, &
         2094.24d0, 2094.68d0, 2095.12d0, 2095.56d0, 2096.00d0, 2096.44d0, &
         2096.88d0, 2097.31d0, 2097.75d0, 2098.20d0, 2098.64d0, 2099.08d0, &
         2099.52d0, 2099.96d0, 2100.40d0, 2100.84d0, 2101.28d0, 2101.72d0, &
         2102.17d0, 2102.61d0, 2103.05d0, 2103.49d0, 2103.93d0, 2104.38d0, &
         2104.82d0, 2105.26d0, 2105.71d0, 2106.15d0, 2106.59d0, 2107.04d0, &
         2107.48d0, 2107.93d0, 2108.37d0, 2108.81d0, 2109.26d0, 2109.71d0, &
         2110.15d0, 2110.59d0, 2111.04d0, 2111.49d0, 2111.93d0, 2112.38d0, &
         2112.82d0, 2113.27d0, 2113.72d0, 2114.17d0, 2114.61d0, 2115.06d0, &
         2115.51d0, 2115.95d0, 2116.40d0, 2116.85d0, 2117.30d0, 2117.75d0, &
         2118.20d0, 2118.64d0, 2119.09d0, 2119.54d0, 2119.99d0, 2120.44d0, &
         2120.89d0, 2121.34d0, 2121.79d0, 2122.24d0, 2122.69d0, 2123.14d0, &
         2123.59d0, 2124.04d0, 2124.50d0, 2124.95d0, 2125.40d0, 2125.85d0/)
 
    wnc(7681:7920)=(/ &
         2126.30d0, 2126.75d0, 2127.21d0, 2127.66d0, 2128.11d0, 2128.56d0, &
         2129.02d0, 2129.47d0, 2129.93d0, 2130.38d0, 2130.83d0, 2131.29d0, &
         2131.74d0, 2132.20d0, 2132.65d0, 2133.11d0, 2133.56d0, 2134.02d0, &
         2134.47d0, 2134.93d0, 2135.38d0, 2135.84d0, 2136.30d0, 2136.75d0, &
         2137.21d0, 2137.67d0, 2138.12d0, 2138.58d0, 2139.04d0, 2139.50d0, &
         2139.95d0, 2140.41d0, 2140.87d0, 2141.33d0, 2141.79d0, 2142.25d0, &
         2142.70d0, 2143.16d0, 2143.62d0, 2144.08d0, 2144.54d0, 2145.00d0, &
         2145.46d0, 2145.92d0, 2146.38d0, 2146.84d0, 2147.30d0, 2147.77d0, &
         2148.23d0, 2148.69d0, 2149.15d0, 2149.61d0, 2150.07d0, 2150.54d0, &
         2151.00d0, 2151.46d0, 2151.93d0, 2152.39d0, 2152.85d0, 2153.32d0, &
         2153.78d0, 2154.24d0, 2154.71d0, 2155.17d0, 2155.64d0, 2156.10d0, &
         2156.57d0, 2157.03d0, 2157.50d0, 2157.96d0, 2158.43d0, 2158.90d0, &
         2159.36d0, 2159.83d0, 2160.29d0, 2160.76d0, 2161.23d0, 2161.70d0, &
         2162.16d0, 2162.63d0, 2163.10d0, 2163.57d0, 2164.03d0, 2164.50d0, &
         2164.97d0, 2165.44d0, 2165.91d0, 2166.38d0, 2166.85d0, 2167.32d0, &
         2167.79d0, 2168.26d0, 2168.73d0, 2169.20d0, 2169.67d0, 2170.14d0, &
         2170.61d0, 2171.08d0, 2171.55d0, 2172.02d0, 2172.50d0, 2172.97d0, &
         2173.44d0, 2173.91d0, 2174.39d0, 2174.86d0, 2175.33d0, 2175.80d0, &
         2176.28d0, 2176.75d0, 2177.23d0, 2177.70d0, 2178.18d0, 2178.65d0, &
         2179.12d0, 2179.60d0, 2180.07d0, 2180.55d0, 2181.02d0, 2181.50d0, &
         2181.98d0, 2182.45d0, 2182.93d0, 2183.41d0, 2183.88d0, 2184.36d0, &
         2184.84d0, 2185.31d0, 2185.79d0, 2186.27d0, 2186.75d0, 2187.23d0, &
         2187.71d0, 2188.18d0, 2188.66d0, 2189.14d0, 2189.62d0, 2190.10d0, &
         2190.58d0, 2191.06d0, 2191.54d0, 2192.02d0, 2192.50d0, 2192.98d0, &
         2193.46d0, 2193.95d0, 2194.43d0, 2194.91d0, 2195.39d0, 2195.87d0, &
         2196.35d0, 2196.84d0, 2197.32d0, 2197.80d0, 2198.28d0, 2198.77d0, &
         2199.25d0, 2199.74d0, 2200.22d0, 2200.70d0, 2201.19d0, 2201.67d0, &
         2202.16d0, 2202.64d0, 2203.13d0, 2203.61d0, 2204.10d0, 2204.58d0, &
         2205.07d0, 2205.56d0, 2206.04d0, 2206.53d0, 2207.02d0, 2207.50d0, &
         2207.99d0, 2208.48d0, 2208.97d0, 2209.46d0, 2209.95d0, 2210.43d0, &
         2210.92d0, 2211.41d0, 2211.90d0, 2212.39d0, 2212.88d0, 2213.37d0, &
         2213.86d0, 2214.35d0, 2214.84d0, 2215.33d0, 2215.82d0, 2216.31d0, &
         2216.80d0, 2217.29d0, 2217.79d0, 2218.28d0, 2218.77d0, 2219.26d0, &
         2219.76d0, 2220.25d0, 2220.74d0, 2221.24d0, 2221.73d0, 2222.22d0, &
         2222.72d0, 2223.21d0, 2223.71d0, 2224.20d0, 2224.69d0, 2225.19d0, &
         2225.68d0, 2226.18d0, 2226.68d0, 2227.17d0, 2227.67d0, 2228.16d0, &
         2228.66d0, 2229.16d0, 2229.65d0, 2230.15d0, 2230.65d0, 2231.15d0, &
         2231.65d0, 2232.14d0, 2232.64d0, 2233.14d0, 2233.64d0, 2234.14d0, &
         2234.64d0, 2235.14d0, 2235.64d0, 2236.14d0, 2236.64d0, 2237.14d0, &
         2237.64d0, 2238.14d0, 2238.64d0, 2239.14d0, 2239.64d0, 2240.14d0/)
 
    wnc(7921:8160)=(/ &
         2240.65d0, 2241.15d0, 2241.65d0, 2242.15d0, 2242.66d0, 2243.16d0, &
         2243.66d0, 2244.17d0, 2244.67d0, 2245.17d0, 2245.68d0, 2246.18d0, &
         2246.69d0, 2247.19d0, 2247.70d0, 2248.20d0, 2248.71d0, 2249.21d0, &
         2249.72d0, 2250.23d0, 2250.73d0, 2251.24d0, 2251.75d0, 2252.25d0, &
         2252.76d0, 2253.27d0, 2253.77d0, 2254.28d0, 2254.79d0, 2255.30d0, &
         2255.81d0, 2256.32d0, 2256.83d0, 2257.34d0, 2257.85d0, 2258.36d0, &
         2258.87d0, 2259.38d0, 2259.89d0, 2260.40d0, 2260.91d0, 2261.42d0, &
         2261.93d0, 2262.44d0, 2262.96d0, 2263.47d0, 2263.98d0, 2264.49d0, &
         2265.01d0, 2265.52d0, 2266.03d0, 2266.55d0, 2267.06d0, 2267.57d0, &
         2268.09d0, 2268.60d0, 2269.12d0, 2269.63d0, 2270.15d0, 2270.66d0, &
         2271.18d0, 2271.70d0, 2272.21d0, 2272.73d0, 2273.24d0, 2273.76d0, &
         2274.28d0, 2274.79d0, 2275.31d0, 2275.83d0, 2276.35d0, 2276.87d0, &
         2277.39d0, 2277.90d0, 2278.42d0, 2278.94d0, 2279.46d0, 2279.98d0, &
         2280.50d0, 2281.02d0, 2281.54d0, 2282.06d0, 2282.58d0, 2283.10d0, &
         2283.63d0, 2284.15d0, 2284.67d0, 2285.19d0, 2285.71d0, 2286.24d0, &
         2286.76d0, 2287.28d0, 2287.81d0, 2288.33d0, 2288.85d0, 2289.38d0, &
         2289.90d0, 2290.43d0, 2290.95d0, 2291.48d0, 2292.00d0, 2292.53d0, &
         2293.05d0, 2293.58d0, 2294.10d0, 2294.63d0, 2295.16d0, 2295.68d0, &
         2296.21d0, 2296.74d0, 2297.27d0, 2297.79d0, 2298.32d0, 2298.85d0, &
         2299.38d0, 2299.91d0, 2300.44d0, 2300.97d0, 2301.50d0, 2302.03d0, &
         2302.56d0, 2303.09d0, 2303.62d0, 2304.15d0, 2304.68d0, 2305.21d0, &
         2305.74d0, 2306.27d0, 2306.80d0, 2307.34d0, 2307.87d0, 2308.40d0, &
         2308.94d0, 2309.47d0, 2310.00d0, 2310.54d0, 2311.07d0, 2311.60d0, &
         2312.14d0, 2312.67d0, 2313.21d0, 2313.74d0, 2314.28d0, 2314.81d0, &
         2315.35d0, 2315.89d0, 2316.42d0, 2316.96d0, 2317.50d0, 2318.03d0, &
         2318.57d0, 2319.11d0, 2319.65d0, 2320.19d0, 2320.72d0, 2321.26d0, &
         2321.80d0, 2322.34d0, 2322.88d0, 2323.42d0, 2323.96d0, 2324.50d0, &
         2325.04d0, 2325.58d0, 2326.12d0, 2326.66d0, 2327.21d0, 2327.75d0, &
         2328.29d0, 2328.83d0, 2329.37d0, 2329.92d0, 2330.46d0, 2331.00d0, &
         2331.55d0, 2332.09d0, 2332.63d0, 2333.18d0, 2333.72d0, 2334.27d0, &
         2334.81d0, 2335.36d0, 2335.90d0, 2336.45d0, 2337.00d0, 2337.54d0, &
         2338.09d0, 2338.63d0, 2339.18d0, 2339.73d0, 2340.28d0, 2340.82d0, &
         2341.37d0, 2341.92d0, 2342.47d0, 2343.02d0, 2343.57d0, 2344.12d0, &
         2344.67d0, 2345.22d0, 2345.77d0, 2346.32d0, 2346.87d0, 2347.42d0, &
         2347.97d0, 2348.52d0, 2349.07d0, 2349.62d0, 2350.18d0, 2350.73d0, &
         2351.28d0, 2351.83d0, 2352.39d0, 2352.94d0, 2353.50d0, 2354.05d0, &
         2354.60d0, 2355.16d0, 2355.71d0, 2356.27d0, 2356.82d0, 2357.38d0, &
         2357.94d0, 2358.49d0, 2359.05d0, 2359.60d0, 2360.16d0, 2360.72d0, &
         2361.27d0, 2361.83d0, 2362.39d0, 2362.95d0, 2363.51d0, 2364.07d0, &
         2364.63d0, 2365.19d0, 2365.74d0, 2366.30d0, 2366.86d0, 2367.42d0/)
 
    wnc(8161:8213)=(/ &
         2367.99d0, 2368.55d0, 2369.11d0, 2369.67d0, 2370.23d0, 2370.79d0, &
         2371.35d0, 2371.92d0, 2372.48d0, 2373.04d0, 2373.60d0, 2374.17d0, &
         2374.73d0, 2375.30d0, 2375.86d0, 2376.43d0, 2376.99d0, 2377.56d0, &
         2378.12d0, 2378.69d0, 2379.25d0, 2379.82d0, 2380.39d0, 2380.95d0, &
         2381.52d0, 2382.09d0, 2382.65d0, 2383.22d0, 2383.79d0, 2384.36d0, &
         2384.93d0, 2385.50d0, 2386.06d0, 2386.64d0, 2387.21d0, 2387.77d0, &
         2388.34d0, 2388.92d0, 2389.49d0, 2390.06d0, 2390.63d0, 2391.20d0, &
         2391.77d0, 2392.34d0, 2392.92d0, 2393.49d0, 2394.06d0, 2394.64d0, &
         2395.21d0, 2395.78d0, 2396.36d0, 2396.93d0, 2397.51d0/)
    solarc(   1: 240)=(/ &
            7.38d0,    7.50d0,    7.68d0,    7.79d0,    7.93d0,    8.08d0, &
            8.37d0,    8.63d0,    8.76d0,    8.80d0,    8.97d0,    9.36d0, &
            9.71d0,   10.15d0,   10.50d0,   10.90d0,   11.14d0,   11.17d0, &
           11.15d0,   11.18d0,   11.46d0,   11.99d0,   12.69d0,   13.29d0, &
           13.79d0,   14.43d0,   15.57d0,   17.53d0,   19.90d0,   22.64d0, &
           25.45d0,   27.74d0,   29.62d0,   31.44d0,   34.45d0,   36.27d0, &
           36.58d0,   34.32d0,   32.86d0,   32.61d0,   34.59d0,   37.44d0, &
           40.81d0,   42.55d0,   42.20d0,   40.24d0,   38.61d0,   36.89d0, &
           35.75d0,   34.64d0,   34.26d0,   36.05d0,   40.51d0,   45.26d0, &
           47.56d0,   47.92d0,   48.21d0,   49.68d0,   52.11d0,   52.65d0, &
           50.23d0,   45.25d0,   41.52d0,   41.82d0,   45.51d0,   49.55d0, &
           53.56d0,   58.91d0,   64.38d0,   66.66d0,   65.18d0,   62.12d0, &
           60.04d0,   57.82d0,   54.89d0,   50.80d0,   46.10d0,   41.00d0, &
           37.17d0,   37.07d0,   41.13d0,   47.42d0,   52.10d0,   53.38d0, &
           52.18d0,   49.82d0,   48.09d0,   49.16d0,   52.01d0,   53.75d0, &
           53.13d0,   50.98d0,   51.40d0,   53.09d0,   53.79d0,   51.53d0, &
           48.73d0,   45.42d0,   42.55d0,   39.37d0,   38.69d0,   42.02d0, &
           47.94d0,   51.84d0,   51.58d0,   49.08d0,   48.60d0,   49.78d0, &
           49.01d0,   45.26d0,   41.87d0,   42.93d0,   44.67d0,   45.49d0, &
           43.63d0,   41.73d0,   40.30d0,   39.63d0,   41.12d0,   46.90d0, &
           55.74d0,   63.86d0,   67.20d0,   68.52d0,   66.80d0,   65.58d0, &
           64.91d0,   62.75d0,   46.80d0,   48.14d0,   50.82d0,   53.37d0, &
           53.83d0,   51.71d0,   47.76d0,   43.79d0,   43.58d0,   48.19d0, &
           55.50d0,   60.47d0,   60.95d0,   57.92d0,   53.70d0,   49.34d0, &
           44.63d0,   41.53d0,   40.35d0,   41.74d0,   44.47d0,   48.35d0, &
           51.81d0,   54.48d0,   56.32d0,   59.96d0,   66.03d0,   74.75d0, &
           88.55d0,   95.31d0,  106.89d0,  117.08d0,  123.89d0,  126.76d0, &
          127.38d0,  127.37d0,  124.95d0,  120.35d0,  109.79d0,   99.49d0, &
           88.94d0,   86.59d0,   84.26d0,   82.91d0,   83.96d0,   92.79d0, &
          101.24d0,  104.71d0,  101.60d0,  107.88d0,  136.46d0,  186.14d0, &
          231.56d0,  250.94d0,  247.63d0,  241.77d0,  248.06d0,  259.96d0, &
          262.16d0,  253.74d0,  246.24d0,  248.79d0,  252.93d0,  254.67d0, &
          253.82d0,  250.91d0,  247.30d0,  243.14d0,  241.29d0,  248.23d0, &
          263.37d0,  274.23d0,  275.88d0,  265.44d0,  245.07d0,  219.15d0, &
          196.90d0,  193.17d0,  209.50d0,  225.33d0,  218.97d0,  192.49d0, &
          161.31d0,  139.53d0,  135.91d0,  143.21d0,  163.34d0,  189.24d0, &
          218.42d0,  239.44d0,  253.48d0,  257.46d0,  252.94d0,  235.20d0, &
          209.47d0,  182.51d0,  159.03d0,  136.13d0,  110.17d0,   88.36d0, &
           77.53d0,   80.46d0,   97.16d0,  126.36d0,  165.18d0,  206.84d0, &
          244.31d0,  272.58d0,  294.12d0,  309.07d0,  316.49d0,  318.71d0/)
 
    solarc( 241: 480)=(/ &
          313.24d0,  296.88d0,  262.76d0,  208.83d0,  158.29d0,  145.13d0, &
          181.24d0,  247.34d0,  305.25d0,  341.54d0,  358.77d0,  360.36d0, &
          336.73d0,  308.82d0,  301.22d0,  329.89d0,  376.94d0,  426.80d0, &
          476.14d0,  534.58d0,  583.91d0,  606.78d0,  607.57d0,  596.05d0, &
          584.08d0,  569.63d0,  545.86d0,  521.59d0,  520.71d0,  534.96d0, &
          543.95d0,  535.16d0,  518.71d0,  507.14d0,  511.42d0,  518.86d0, &
          532.02d0,  556.11d0,  569.54d0,  544.19d0,  496.71d0,  456.78d0, &
          472.21d0,  518.86d0,  532.31d0,  494.46d0,  455.21d0,  452.34d0, &
          490.11d0,  505.18d0,  474.57d0,  433.21d0,  411.46d0,  420.86d0, &
          456.76d0,  474.06d0,  454.19d0,  431.33d0,  442.44d0,  499.22d0, &
          583.30d0,  634.03d0,  635.87d0,  615.37d0,  597.49d0,  600.55d0, &
          630.03d0,  641.01d0,  617.33d0,  586.43d0,  558.24d0,  556.42d0, &
          582.34d0,  608.39d0,  626.39d0,  639.75d0,  641.86d0,  643.23d0, &
          633.91d0,  601.99d0,  555.44d0,  506.66d0,  493.15d0,  530.16d0, &
          612.81d0,  713.62d0,  785.79d0,  787.75d0,  747.83d0,  707.35d0, &
          686.58d0,  693.50d0,  709.22d0,  717.64d0,  733.57d0,  735.19d0, &
          712.38d0,  681.78d0,  667.11d0,  680.64d0,  677.99d0,  629.66d0, &
          583.21d0,  586.39d0,  653.73d0,  743.86d0,  806.32d0,  805.54d0, &
          746.60d0,  679.39d0,  663.94d0,  683.06d0,  704.93d0,  713.08d0, &
          730.76d0,  780.30d0,  833.88d0,  828.41d0,  770.81d0,  711.02d0, &
          690.61d0,  717.77d0,  741.96d0,  720.53d0,  677.22d0,  649.33d0, &
          655.76d0,  694.14d0,  739.64d0,  776.83d0,  800.58d0,  811.14d0, &
          841.42d0,  904.33d0,  978.64d0, 1026.50d0, 1011.03d0,  998.78d0, &
          981.25d0,  958.42d0,  936.33d0, 1089.73d0, 1147.85d0, 1141.34d0, &
         1093.85d0, 1039.46d0, 1000.79d0, 1000.51d0, 1017.14d0, 1010.50d0, &
         1007.56d0, 1004.94d0,  998.80d0,  997.34d0,  977.93d0,  954.02d0, &
          957.57d0,  984.62d0, 1008.67d0, 1019.31d0, 1037.82d0, 1030.18d0, &
          985.19d0,  931.77d0,  870.06d0,  846.17d0,  857.99d0,  870.98d0, &
          891.54d0,  937.10d0,  972.39d0,  980.03d0,  994.17d0, 1008.07d0, &
          999.49d0, 1018.77d0, 1067.98d0, 1104.44d0, 1087.04d0, 1033.34d0, &
          979.85d0,  958.59d0,  973.71d0,  998.18d0, 1029.69d0, 1056.07d0, &
         1068.78d0, 1082.46d0, 1068.72d0,  975.84d0,  866.82d0,  814.39d0, &
          916.96d0,  966.39d0,  985.24d0,  968.10d0, 1005.55d0, 1078.20d0, &
         1023.15d0, 1035.92d0, 1158.12d0, 1162.80d0, 1048.19d0,  908.62d0, &
          824.35d0, 1023.59d0, 1058.22d0,  984.43d0, 1074.90d0, 1096.63d0, &
         1120.41d0, 1262.89d0, 1296.79d0, 1227.01d0, 1247.50d0, 1280.71d0, &
         1230.00d0, 1160.33d0, 1029.41d0,  966.42d0, 1073.67d0, 1148.93d0, &
         1321.84d0, 1320.88d0, 1151.14d0, 1231.35d0, 1018.48d0,  773.43d0, &
          835.17d0, 1048.74d0, 1036.49d0, 1066.40d0, 1030.30d0, 1157.32d0, &
         1269.99d0, 1330.14d0, 1025.04d0,  689.96d0, 1089.54d0, 1248.71d0/)
 
    solarc( 481: 720)=(/ &
          835.17d0, 1196.46d0, 1628.07d0, 1734.38d0, 1797.92d0, 1881.96d0, &
         1836.73d0, 1788.64d0, 1737.35d0, 1663.39d0, 1721.78d0, 1583.17d0, &
         1771.99d0, 1762.13d0, 1763.90d0, 1788.78d0, 1713.22d0, 1749.67d0, &
         1715.66d0, 1825.44d0, 1763.19d0, 1683.15d0, 1750.75d0, 1724.90d0, &
         1731.03d0, 1645.09d0, 1656.42d0, 1497.55d0, 1236.01d0, 1542.01d0, &
         1699.47d0, 1652.05d0, 1613.33d0, 1774.12d0, 1851.48d0, 1730.22d0, &
         1678.10d0, 1823.29d0, 1846.74d0, 1955.54d0, 1953.96d0, 1958.66d0, &
         1943.52d0, 1859.16d0, 1999.92d0, 2026.49d0, 2027.19d0, 2128.20d0, &
         2143.80d0, 2032.87d0, 1974.03d0, 2065.35d0, 2071.23d0, 2130.29d0, &
         2117.36d0, 2049.37d0, 2045.22d0, 2085.35d0, 2110.88d0, 2123.16d0, &
         2070.17d0, 2018.51d0, 2053.85d0, 1979.44d0, 2030.75d0, 2040.35d0, &
         1977.21d0, 1994.41d0, 2104.23d0, 2043.71d0, 2096.99d0, 2101.69d0, &
         2052.39d0, 2111.71d0, 2107.20d0, 2102.24d0, 2087.70d0, 2100.21d0, &
         2075.89d0, 2044.26d0, 2015.88d0, 1803.03d0, 1713.13d0, 1911.44d0, &
         1928.42d0, 2026.38d0, 2024.79d0, 1915.00d0, 1959.68d0, 1966.72d0, &
         2037.81d0, 1980.62d0, 2008.50d0, 1945.63d0, 1936.22d0, 1933.76d0, &
         1856.89d0, 1866.73d0, 1949.82d0, 1895.54d0, 1972.79d0, 2025.31d0, &
         1925.83d0, 1886.25d0, 1932.24d0, 1912.35d0, 1860.80d0, 1827.88d0, &
         1865.84d0, 1731.09d0, 1620.62d0, 1680.97d0, 1799.12d0, 1828.57d0, &
         1860.44d0, 1815.37d0, 1852.34d0, 1909.16d0, 1874.55d0, 1689.50d0, &
         1771.10d0, 1889.98d0, 1882.45d0, 1916.35d0, 1908.22d0, 1849.88d0, &
         1866.26d0, 1935.56d0, 1838.03d0, 1881.07d0, 1874.68d0, 1808.46d0, &
         1785.13d0, 1859.82d0, 1843.83d0, 1878.12d0, 1878.18d0, 1882.46d0, &
         1876.00d0, 1836.80d0, 1884.52d0, 1879.56d0, 1861.38d0, 1888.95d0, &
         1849.92d0, 1876.58d0, 1882.89d0, 1850.62d0, 1800.09d0, 1808.16d0, &
         1739.88d0, 1769.94d0, 1826.23d0, 1782.71d0, 1796.74d0, 1793.25d0, &
         1753.66d0, 1814.06d0, 1794.37d0, 1784.08d0, 1783.80d0, 1730.81d0, &
         1827.49d0, 1841.29d0, 1836.36d0, 1795.26d0, 1790.05d0, 1816.01d0, &
         1772.67d0, 1778.30d0, 1801.76d0, 1799.40d0, 1823.45d0, 1825.76d0, &
         1821.53d0, 1786.45d0, 1754.09d0, 1799.62d0, 1779.81d0, 1615.59d0, &
         1706.30d0, 1760.01d0, 1773.61d0, 1756.12d0, 1774.96d0, 1754.40d0, &
         1763.55d0, 1776.38d0, 1746.95d0, 1747.82d0, 1742.24d0, 1719.00d0, &
         1698.63d0, 1740.39d0, 1753.07d0, 1747.04d0, 1728.57d0, 1733.10d0, &
         1708.42d0, 1698.70d0, 1686.59d0, 1697.75d0, 1688.43d0, 1678.83d0, &
         1644.19d0, 1670.89d0, 1619.90d0, 1604.64d0, 1658.74d0, 1657.86d0, &
         1673.65d0, 1685.56d0, 1656.77d0, 1655.62d0, 1623.72d0, 1621.38d0, &
         1667.17d0, 1673.71d0, 1670.34d0, 1643.84d0, 1641.17d0, 1609.82d0, &
         1643.07d0, 1621.60d0, 1631.82d0, 1627.56d0, 1621.95d0, 1647.11d0, &
         1641.40d0, 1605.07d0, 1593.58d0, 1586.33d0, 1602.68d0, 1595.96d0, &
         1597.42d0, 1582.34d0, 1582.56d0, 1593.35d0, 1595.03d0, 1531.99d0/)
 
    solarc( 721: 960)=(/ &
         1591.10d0, 1605.48d0, 1579.08d0, 1566.51d0, 1549.99d0, 1500.44d0, &
         1271.32d0, 1421.29d0, 1528.21d0, 1524.49d0, 1541.46d0, 1545.96d0, &
         1558.04d0, 1530.70d0, 1520.68d0, 1536.09d0, 1528.35d0, 1517.83d0, &
         1516.86d0, 1530.98d0, 1516.61d0, 1513.70d0, 1503.91d0, 1499.42d0, &
         1492.54d0, 1487.61d0, 1486.35d0, 1486.16d0, 1483.45d0, 1479.48d0, &
         1477.38d0, 1476.17d0, 1473.87d0, 1470.05d0, 1461.78d0, 1449.70d0, &
         1446.87d0, 1457.10d0, 1462.28d0, 1462.52d0, 1469.10d0, 1475.55d0, &
         1469.48d0, 1458.55d0, 1458.58d0, 1461.51d0, 1443.36d0, 1452.49d0, &
         1452.38d0, 1422.52d0, 1458.06d0, 1449.55d0, 1426.66d0, 1419.93d0, &
         1426.56d0, 1432.21d0, 1445.92d0, 1436.23d0, 1417.30d0, 1419.80d0, &
         1407.49d0, 1391.61d0, 1405.39d0, 1381.99d0, 1373.43d0, 1373.31d0, &
         1379.03d0, 1363.43d0, 1369.03d0, 1373.26d0, 1366.08d0, 1341.93d0, &
         1354.12d0, 1351.42d0, 1352.08d0, 1349.04d0, 1355.14d0, 1350.01d0, &
         1338.19d0, 1341.20d0, 1340.59d0, 1315.03d0, 1299.64d0, 1331.35d0, &
         1324.96d0, 1327.88d0, 1318.17d0, 1331.01d0, 1315.40d0, 1303.14d0, &
         1304.99d0, 1300.33d0, 1260.68d0, 1277.20d0, 1263.21d0, 1254.67d0, &
         1274.99d0, 1291.94d0, 1277.16d0, 1291.91d0, 1284.46d0, 1289.65d0, &
         1287.83d0, 1265.55d0, 1266.98d0, 1255.15d0, 1266.21d0, 1259.84d0, &
         1272.91d0, 1270.25d0, 1265.66d0, 1271.06d0, 1272.27d0, 1251.31d0, &
         1270.05d0, 1255.71d0, 1242.88d0, 1237.99d0, 1258.80d0, 1257.99d0, &
         1248.33d0, 1193.62d0, 1227.73d0, 1241.77d0, 1228.31d0, 1225.49d0, &
         1226.23d0, 1220.35d0, 1219.49d0, 1164.85d0, 1160.99d0, 1171.28d0, &
         1159.50d0, 1163.58d0, 1172.14d0, 1156.31d0, 1144.60d0, 1155.99d0, &
         1157.38d0, 1151.51d0, 1152.02d0, 1154.52d0, 1156.03d0, 1140.01d0, &
         1132.03d0, 1112.53d0, 1102.71d0, 1121.38d0, 1136.98d0, 1134.10d0, &
         1132.86d0, 1131.27d0, 1116.11d0, 1116.90d0, 1126.28d0, 1119.26d0, &
         1118.22d0, 1118.70d0, 1100.60d0, 1115.63d0, 1109.64d0, 1106.92d0, &
         1100.43d0, 1092.14d0, 1106.48d0, 1108.46d0, 1112.31d0, 1114.85d0, &
         1104.99d0, 1103.34d0, 1100.14d0, 1095.62d0, 1081.35d0, 1067.07d0, &
         1057.84d0, 1066.97d0, 1052.31d0, 1074.56d0, 1071.43d0, 1068.96d0, &
         1065.30d0, 1069.62d0, 1072.10d0, 1063.40d0, 1060.31d0, 1055.93d0, &
         1047.41d0, 1059.88d0, 1033.46d0, 1016.32d0, 1021.71d0, 1043.10d0, &
         1044.19d0, 1041.11d0, 1022.00d0, 1022.91d0, 1037.94d0, 1041.50d0, &
         1020.21d0, 1010.43d0,  990.93d0, 1011.90d0, 1029.24d0, 1025.13d0, &
         1000.04d0, 1003.19d0,  984.41d0,  903.33d0,  979.66d0,  962.37d0, &
          974.33d0,  885.25d0,  771.82d0,  937.93d0,  976.94d0,  964.59d0, &
          975.78d0,  970.50d0,  977.94d0,  975.09d0,  978.19d0, 1009.31d0, &
          994.47d0,  995.14d0,  950.54d0,  827.45d0,  914.64d0,  977.93d0, &
          948.86d0,  973.31d0,  965.23d0,  949.37d0,  972.91d0,  962.19d0, &
          935.36d0,  934.76d0,  935.12d0,  936.64d0,  935.68d0,  932.51d0/)
 
    solarc( 961:1200)=(/ &
          930.40d0,  929.09d0,  928.64d0,  929.85d0,  932.83d0,  936.44d0, &
          940.90d0,  945.36d0,  949.26d0,  953.01d0,  955.20d0,  955.47d0, &
          957.62d0,  961.34d0,  965.19d0,  968.91d0,  973.19d0,  975.03d0, &
          974.81d0,  973.07d0,  970.11d0,  966.43d0,  963.58d0,  961.32d0, &
          960.57d0,  960.86d0,  961.77d0,  961.73d0,  961.68d0,  961.24d0, &
          960.64d0,  959.95d0,  960.26d0,  960.73d0,  962.29d0,  964.55d0, &
          967.03d0,  968.91d0,  970.58d0,  971.12d0,  971.06d0,  970.13d0, &
          967.40d0,  965.32d0,  963.22d0,  959.60d0,  954.75d0,  952.39d0, &
          949.87d0,  947.47d0,  946.10d0,  946.93d0,  946.82d0,  946.09d0, &
          944.77d0,  945.55d0,  947.35d0,  949.16d0,  950.54d0,  953.83d0, &
          955.47d0,  955.41d0,  952.15d0,  944.56d0,  935.78d0,  926.87d0, &
          918.72d0,  913.53d0,  913.45d0,  913.16d0,  912.77d0,  911.94d0, &
          910.55d0,  908.94d0,  907.54d0,  905.34d0,  907.75d0,  914.90d0, &
          923.82d0,  932.96d0,  943.46d0,  949.90d0,  952.46d0,  953.19d0, &
          952.75d0,  949.25d0,  942.84d0,  938.35d0,  934.49d0,  931.84d0, &
          931.87d0,  934.45d0,  935.06d0,  935.09d0,  934.76d0,  934.41d0, &
          934.01d0,  933.06d0,  931.56d0,  933.84d0,  938.02d0,  942.37d0, &
          947.19d0,  951.24d0,  949.10d0,  945.76d0,  942.65d0,  939.87d0, &
          938.31d0,  938.70d0,  938.28d0,  937.96d0,  937.58d0,  936.99d0, &
          936.14d0,  934.94d0,  932.90d0,  933.14d0,  934.92d0,  937.60d0, &
          940.80d0,  944.42d0,  945.87d0,  946.34d0,  946.47d0,  946.36d0, &
          945.96d0,  945.57d0,  945.62d0,  945.66d0,  945.47d0,  944.32d0, &
          940.46d0,  935.78d0,  929.81d0,  922.59d0,  916.30d0,  912.32d0, &
          908.22d0,  904.16d0,  899.22d0,  894.95d0,  890.36d0,  886.29d0, &
          883.14d0,  884.73d0,  887.21d0,  890.83d0,  895.80d0,  902.36d0, &
          907.31d0,  911.02d0,  912.79d0,  915.62d0,  918.23d0,  920.63d0, &
          923.84d0,  928.55d0,  930.67d0,  931.73d0,  932.15d0,  931.58d0, &
          930.79d0,  930.21d0,  929.46d0,  929.74d0,  930.72d0,  931.72d0, &
          933.20d0,  935.04d0,  935.62d0,  935.64d0,  935.38d0,  933.41d0, &
          931.84d0,  931.23d0,  930.88d0,  930.93d0,  931.90d0,  932.38d0, &
          932.28d0,  931.51d0,  930.64d0,  930.29d0,  930.26d0,  930.01d0, &
          931.26d0,  932.94d0,  934.29d0,  935.34d0,  936.71d0,  937.04d0, &
          936.98d0,  936.50d0,  936.10d0,  936.03d0,  935.52d0,  933.46d0, &
          931.95d0,  930.52d0,  928.88d0,  927.72d0,  928.06d0,  928.08d0, &
          927.89d0,  927.51d0,  926.39d0,  924.22d0,  922.50d0,  920.44d0, &
          919.61d0,  919.52d0,  919.49d0,  918.64d0,  917.91d0,  915.94d0, &
          913.04d0,  910.08d0,  907.07d0,  902.86d0,  900.50d0,  899.44d0, &
          899.22d0,  899.44d0,  900.91d0,  901.30d0,  902.21d0,  904.07d0, &
          905.94d0,  908.15d0,  910.73d0,  912.79d0,  915.40d0,  918.26d0, &
          921.05d0,  922.56d0,  921.79d0,  920.28d0,  918.23d0,  914.03d0/)
 
    solarc(1201:1440)=(/ &
          909.64d0,  907.09d0,  904.00d0,  901.08d0,  899.36d0,  897.76d0, &
          896.60d0,  895.43d0,  893.70d0,  894.87d0,  896.85d0,  897.87d0, &
          900.40d0,  905.02d0,  908.45d0,  911.75d0,  915.58d0,  918.36d0, &
          920.52d0,  921.99d0,  923.17d0,  924.49d0,  925.25d0,  925.20d0, &
          924.74d0,  923.29d0,  920.54d0,  917.23d0,  914.06d0,  911.10d0, &
          909.10d0,  908.43d0,  908.51d0,  908.58d0,  908.66d0,  908.40d0, &
          906.97d0,  904.62d0,  902.22d0,  900.79d0,  900.62d0,  902.03d0, &
          904.64d0,  907.38d0,  909.16d0,  910.01d0,  910.41d0,  909.94d0, &
          908.08d0,  906.96d0,  906.74d0,  907.01d0,  907.95d0,  910.24d0, &
          912.01d0,  912.86d0,  912.71d0,  912.25d0,  911.69d0,  910.68d0, &
          909.12d0,  908.83d0,  908.91d0,  908.57d0,  908.49d0,  907.95d0, &
          902.78d0,  897.75d0,  893.55d0,  889.61d0,  887.11d0,  888.47d0, &
          889.28d0,  889.69d0,  889.84d0,  889.01d0,  888.09d0,  885.61d0, &
          881.28d0,  878.44d0,  877.42d0,  876.33d0,  874.54d0,  874.27d0, &
          870.83d0,  865.17d0,  858.95d0,  854.39d0,  848.98d0,  844.94d0, &
          842.89d0,  840.95d0,  841.14d0,  843.05d0,  843.63d0,  845.97d0, &
          849.40d0,  851.80d0,  855.27d0,  861.57d0,  865.47d0,  870.34d0, &
          875.81d0,  879.66d0,  882.93d0,  885.32d0,  886.51d0,  888.51d0, &
          890.80d0,  892.25d0,  895.33d0,  898.13d0,  899.25d0,  900.07d0, &
          901.35d0,  901.64d0,  901.81d0,  901.93d0,  902.78d0,  903.63d0, &
          904.41d0,  905.34d0,  906.35d0,  906.40d0,  906.41d0,  906.67d0, &
          906.85d0,  907.01d0,  907.35d0,  907.40d0,  906.54d0,  905.89d0, &
          905.25d0,  904.65d0,  904.12d0,  904.20d0,  904.17d0,  904.22d0, &
          903.99d0,  903.45d0,  903.05d0,  901.98d0,  897.90d0,  893.06d0, &
          888.28d0,  884.17d0,  880.83d0,  880.38d0,  880.92d0,  881.57d0, &
          881.34d0,  880.96d0,  880.82d0,  879.97d0,  878.57d0,  878.78d0, &
          881.00d0,  883.98d0,  888.19d0,  892.92d0,  896.21d0,  897.48d0, &
          897.14d0,  893.92d0,  889.66d0,  884.90d0,  881.22d0,  878.39d0, &
          877.90d0,  878.11d0,  879.35d0,  879.85d0,  880.22d0,  880.07d0, &
          878.94d0,  871.21d0,  863.93d0,  859.56d0,  857.00d0,  856.11d0, &
          861.18d0,  865.38d0,  865.40d0,  861.21d0,  857.76d0,  854.42d0, &
          851.15d0,  846.54d0,  848.16d0,  852.46d0,  856.55d0,  861.36d0, &
          868.68d0,  872.12d0,  871.69d0,  870.57d0,  871.30d0,  872.62d0, &
          874.67d0,  876.02d0,  878.38d0,  879.46d0,  879.46d0,  877.44d0, &
          875.67d0,  874.18d0,  872.29d0,  870.91d0,  870.84d0,  871.15d0, &
          869.42d0,  867.09d0,  862.70d0,  860.25d0,  858.15d0,  856.60d0, &
          856.64d0,  860.55d0,  863.51d0,  866.39d0,  870.19d0,  871.85d0, &
          871.38d0,  872.63d0,  873.27d0,  876.41d0,  879.98d0,  884.73d0, &
          887.25d0,  890.27d0,  890.73d0,  890.59d0,  890.37d0,  889.95d0, &
          889.60d0,  889.20d0,  888.75d0,  888.10d0,  887.56d0,  886.79d0/)
 
    solarc(1441:1680)=(/ &
          885.81d0,  884.79d0,  883.97d0,  883.10d0,  881.65d0,  879.77d0, &
          877.48d0,  874.52d0,  871.52d0,  869.31d0,  867.96d0,  867.27d0, &
          867.52d0,  868.17d0,  868.53d0,  868.56d0,  868.42d0,  868.64d0, &
          869.25d0,  870.87d0,  873.25d0,  875.69d0,  877.52d0,  878.88d0, &
          879.41d0,  879.06d0,  877.71d0,  876.41d0,  875.21d0,  874.24d0, &
          873.50d0,  873.36d0,  872.96d0,  872.20d0,  871.17d0,  869.81d0, &
          868.30d0,  865.91d0,  863.41d0,  861.97d0,  860.89d0,  860.04d0, &
          860.35d0,  860.81d0,  860.29d0,  859.95d0,  860.01d0,  860.02d0, &
          860.28d0,  860.93d0,  862.63d0,  864.46d0,  866.41d0,  868.39d0, &
          870.07d0,  870.29d0,  870.34d0,  870.54d0,  870.67d0,  870.72d0, &
          870.90d0,  870.83d0,  870.70d0,  870.58d0,  870.49d0,  870.28d0, &
          870.13d0,  869.55d0,  868.45d0,  867.22d0,  866.25d0,  865.01d0, &
          863.52d0,  862.64d0,  861.76d0,  860.65d0,  859.74d0,  859.14d0, &
          858.00d0,  856.64d0,  854.75d0,  852.77d0,  850.74d0,  848.32d0, &
          845.09d0,  842.49d0,  839.82d0,  837.70d0,  836.35d0,  835.17d0, &
          833.26d0,  831.62d0,  830.06d0,  829.67d0,  830.80d0,  833.14d0, &
          836.21d0,  839.45d0,  841.05d0,  841.85d0,  841.52d0,  839.16d0, &
          835.33d0,  831.11d0,  826.12d0,  821.22d0,  816.88d0,  812.86d0, &
          809.39d0,  807.11d0,  806.24d0,  806.51d0,  807.12d0,  807.54d0, &
          808.98d0,  811.65d0,  815.50d0,  820.62d0,  826.68d0,  832.16d0, &
          836.07d0,  838.41d0,  839.54d0,  839.37d0,  838.34d0,  837.87d0, &
          838.21d0,  838.92d0,  840.77d0,  842.99d0,  844.39d0,  844.78d0, &
          844.81d0,  844.23d0,  841.35d0,  837.92d0,  835.87d0,  833.12d0, &
          829.39d0,  827.75d0,  826.45d0,  823.78d0,  821.55d0,  820.39d0, &
          819.35d0,  818.33d0,  818.64d0,  821.40d0,  824.64d0,  828.33d0, &
          833.48d0,  838.35d0,  841.47d0,  844.58d0,  847.18d0,  848.86d0, &
          850.31d0,  851.87d0,  853.32d0,  855.05d0,  856.29d0,  856.43d0, &
          856.08d0,  855.98d0,  855.72d0,  855.34d0,  855.49d0,  856.05d0, &
          856.27d0,  856.11d0,  855.77d0,  855.13d0,  854.05d0,  852.68d0, &
          850.94d0,  849.11d0,  847.55d0,  846.45d0,  845.69d0,  844.92d0, &
          844.06d0,  842.85d0,  841.25d0,  839.79d0,  839.02d0,  838.73d0, &
          839.40d0,  840.90d0,  842.40d0,  843.96d0,  845.38d0,  846.14d0, &
          846.58d0,  847.01d0,  847.48d0,  848.17d0,  848.84d0,  849.32d0, &
          849.66d0,  849.58d0,  849.40d0,  849.21d0,  848.60d0,  848.02d0, &
          848.02d0,  847.83d0,  846.75d0,  845.52d0,  844.47d0,  843.23d0, &
          842.25d0,  842.14d0,  842.68d0,  842.82d0,  842.60d0,  842.38d0, &
          841.92d0,  840.81d0,  840.50d0,  841.48d0,  842.63d0,  843.99d0, &
          845.73d0,  847.03d0,  846.95d0,  846.13d0,  845.52d0,  845.13d0, &
          844.56d0,  844.52d0,  845.11d0,  845.50d0,  845.75d0,  845.98d0, &
          846.00d0,  845.43d0,  844.77d0,  844.44d0,  843.99d0,  843.55d0/)
 
    solarc(1681:1920)=(/ &
          843.71d0,  843.95d0,  843.68d0,  842.42d0,  840.43d0,  838.59d0, &
          836.57d0,  834.74d0,  834.01d0,  833.98d0,  833.86d0,  833.85d0, &
          833.63d0,  832.70d0,  830.85d0,  829.42d0,  829.07d0,  828.28d0, &
          827.71d0,  828.34d0,  828.51d0,  827.81d0,  828.06d0,  829.07d0, &
          829.59d0,  830.17d0,  831.43d0,  832.81d0,  833.85d0,  835.02d0, &
          835.94d0,  836.05d0,  835.68d0,  835.58d0,  835.52d0,  835.39d0, &
          835.56d0,  835.64d0,  835.22d0,  834.76d0,  834.17d0,  833.74d0, &
          833.89d0,  834.61d0,  835.59d0,  836.55d0,  836.52d0,  835.66d0, &
          834.43d0,  832.87d0,  831.75d0,  831.22d0,  830.54d0,  829.82d0, &
          829.36d0,  828.70d0,  827.88d0,  827.37d0,  827.45d0,  827.86d0, &
          828.19d0,  828.11d0,  827.59d0,  827.01d0,  826.41d0,  825.59d0, &
          823.73d0,  821.24d0,  818.57d0,  815.53d0,  812.78d0,  810.89d0, &
          809.39d0,  808.36d0,  807.75d0,  804.69d0,  798.52d0,  791.61d0, &
          785.22d0,  780.25d0,  778.08d0,  779.63d0,  782.86d0,  785.15d0, &
          785.57d0,  785.29d0,  784.68d0,  785.89d0,  789.76d0,  796.18d0, &
          804.26d0,  812.84d0,  819.88d0,  823.95d0,  824.96d0,  824.51d0, &
          823.92d0,  822.60d0,  821.00d0,  820.07d0,  819.37d0,  818.53d0, &
          817.10d0,  814.45d0,  810.52d0,  807.03d0,  804.02d0,  802.01d0, &
          802.11d0,  803.70d0,  804.35d0,  804.81d0,  804.97d0,  803.74d0, &
          802.29d0,  802.93d0,  804.45d0,  806.60d0,  809.50d0,  811.88d0, &
          812.18d0,  811.69d0,  811.01d0,  810.51d0,  810.54d0,  811.86d0, &
          813.28d0,  814.71d0,  816.34d0,  817.77d0,  817.98d0,  817.08d0, &
          815.46d0,  814.24d0,  813.71d0,  813.60d0,  814.41d0,  815.81d0, &
          816.40d0,  816.17d0,  815.80d0,  815.02d0,  814.49d0,  814.72d0, &
          815.46d0,  816.44d0,  817.75d0,  818.79d0,  818.99d0,  818.67d0, &
          818.45d0,  818.32d0,  818.07d0,  818.00d0,  818.12d0,  818.19d0, &
          818.10d0,  817.88d0,  817.69d0,  817.45d0,  817.05d0,  816.92d0, &
          817.08d0,  817.45d0,  818.07d0,  818.38d0,  817.97d0,  817.24d0, &
          816.66d0,  816.10d0,  815.78d0,  816.26d0,  817.17d0,  817.47d0, &
          817.17d0,  816.41d0,  815.25d0,  813.45d0,  811.60d0,  810.52d0, &
          809.88d0,  809.28d0,  809.17d0,  808.99d0,  807.96d0,  806.91d0, &
          806.12d0,  805.15d0,  804.54d0,  805.13d0,  806.20d0,  807.10d0, &
          808.08d0,  808.89d0,  808.65d0,  807.72d0,  807.32d0,  807.16d0, &
          807.48d0,  808.44d0,  809.56d0,  809.74d0,  809.38d0,  808.57d0, &
          807.39d0,  805.43d0,  804.45d0,  804.35d0,  804.35d0,  804.34d0, &
          804.69d0,  803.50d0,  801.50d0,  799.45d0,  797.86d0,  796.48d0, &
          796.32d0,  796.75d0,  797.09d0,  796.59d0,  795.36d0,  792.00d0, &
          786.84d0,  779.83d0,  772.71d0,  766.30d0,  761.16d0,  757.41d0, &
          755.35d0,  753.60d0,  751.96d0,  750.71d0,  750.27d0,  750.95d0, &
          753.74d0,  758.57d0,  765.06d0,  772.21d0,  779.15d0,  784.49d0/)
 
    solarc(1921:2160)=(/ &
          788.18d0,  790.76d0,  792.50d0,  793.85d0,  795.09d0,  796.16d0, &
          797.28d0,  798.27d0,  798.37d0,  797.23d0,  795.55d0,  793.71d0, &
          791.70d0,  790.18d0,  789.20d0,  788.89d0,  788.35d0,  787.78d0, &
          787.18d0,  786.82d0,  786.97d0,  788.09d0,  789.56d0,  791.61d0, &
          793.82d0,  795.85d0,  797.38d0,  798.46d0,  799.30d0,  799.92d0, &
          800.10d0,  799.95d0,  799.75d0,  799.59d0,  799.73d0,  799.59d0, &
          799.46d0,  799.15d0,  798.68d0,  798.06d0,  797.76d0,  797.11d0, &
          796.15d0,  795.45d0,  794.66d0,  792.99d0,  791.27d0,  789.84d0, &
          787.87d0,  785.81d0,  784.28d0,  783.09d0,  782.05d0,  782.10d0, &
          782.86d0,  783.81d0,  785.03d0,  786.94d0,  788.44d0,  789.71d0, &
          791.24d0,  792.79d0,  794.12d0,  795.30d0,  795.69d0,  794.45d0, &
          793.12d0,  791.31d0,  788.89d0,  786.85d0,  785.56d0,  782.61d0, &
          780.45d0,  778.92d0,  777.69d0,  776.79d0,  778.58d0,  780.17d0, &
          780.85d0,  780.65d0,  781.22d0,  780.18d0,  779.70d0,  779.54d0, &
          779.78d0,  779.84d0,  780.06d0,  779.19d0,  778.45d0,  777.86d0, &
          778.29d0,  779.03d0,  779.37d0,  779.27d0,  780.09d0,  780.71d0, &
          781.16d0,  782.27d0,  783.76d0,  783.76d0,  782.37d0,  781.10d0, &
          779.49d0,  777.71d0,  776.03d0,  773.47d0,  770.71d0,  768.69d0, &
          767.04d0,  765.74d0,  766.16d0,  767.33d0,  767.95d0,  768.53d0, &
          769.44d0,  770.05d0,  771.68d0,  774.22d0,  776.46d0,  779.00d0, &
          781.58d0,  782.16d0,  781.32d0,  779.73d0,  777.89d0,  776.03d0, &
          774.53d0,  773.35d0,  772.95d0,  773.06d0,  773.20d0,  773.28d0, &
          773.51d0,  773.72d0,  774.28d0,  775.57d0,  777.10d0,  778.14d0, &
          778.45d0,  778.32d0,  777.39d0,  776.32d0,  775.58d0,  775.60d0, &
          775.52d0,  775.32d0,  774.97d0,  774.68d0,  774.44d0,  775.10d0, &
          776.16d0,  777.00d0,  777.48d0,  778.19d0,  778.14d0,  777.10d0, &
          775.28d0,  774.14d0,  773.09d0,  771.56d0,  770.73d0,  770.65d0, &
          770.14d0,  770.22d0,  770.69d0,  770.56d0,  770.39d0,  771.34d0, &
          772.25d0,  772.91d0,  774.01d0,  775.48d0,  775.92d0,  775.85d0, &
          775.58d0,  775.27d0,  775.03d0,  774.90d0,  774.70d0,  774.13d0, &
          773.05d0,  772.20d0,  771.23d0,  770.33d0,  769.95d0,  770.29d0, &
          769.66d0,  769.18d0,  768.30d0,  766.49d0,  762.86d0,  760.88d0, &
          759.13d0,  758.09d0,  758.02d0,  759.31d0,  758.23d0,  757.79d0, &
          756.94d0,  755.10d0,  752.78d0,  753.85d0,  754.96d0,  756.52d0, &
          759.19d0,  762.62d0,  763.45d0,  764.23d0,  764.88d0,  764.98d0, &
          765.50d0,  767.22d0,  768.20d0,  768.90d0,  770.13d0,  770.71d0, &
          769.20d0,  766.32d0,  763.88d0,  761.29d0,  759.24d0,  758.33d0, &
          758.18d0,  757.60d0,  756.72d0,  755.59d0,  754.23d0,  753.63d0, &
          754.61d0,  756.56d0,  758.92d0,  761.54d0,  763.65d0,  764.61d0, &
          764.76d0,  764.79d0,  765.16d0,  765.05d0,  764.12d0,  763.31d0/)
 
    solarc(2161:2400)=(/ &
          762.14d0,  759.53d0,  756.48d0,  753.89d0,  751.43d0,  749.16d0, &
          748.32d0,  748.32d0,  748.77d0,  749.73d0,  751.02d0,  751.60d0, &
          752.47d0,  754.10d0,  755.63d0,  755.62d0,  756.42d0,  757.21d0, &
          756.91d0,  756.06d0,  756.44d0,  756.28d0,  756.21d0,  756.09d0, &
          756.10d0,  755.42d0,  756.19d0,  757.07d0,  758.20d0,  759.22d0, &
          760.96d0,  761.14d0,  761.25d0,  760.97d0,  760.83d0,  760.64d0, &
          760.57d0,  759.75d0,  759.51d0,  759.20d0,  758.75d0,  758.13d0, &
          758.18d0,  757.60d0,  756.93d0,  756.49d0,  756.10d0,  755.51d0, &
          755.36d0,  755.01d0,  753.53d0,  752.41d0,  751.75d0,  751.04d0, &
          750.62d0,  751.29d0,  751.74d0,  752.08d0,  751.69d0,  750.34d0, &
          749.17d0,  749.15d0,  749.40d0,  750.33d0,  751.87d0,  753.07d0, &
          753.11d0,  752.68d0,  751.89d0,  751.01d0,  751.20d0,  751.48d0, &
          751.77d0,  752.19d0,  752.82d0,  752.59d0,  752.21d0,  751.85d0, &
          751.06d0,  749.15d0,  747.71d0,  746.52d0,  745.47d0,  745.06d0, &
          745.93d0,  745.94d0,  746.05d0,  746.10d0,  745.65d0,  744.34d0, &
          743.45d0,  743.33d0,  743.11d0,  743.45d0,  744.63d0,  745.55d0, &
          745.97d0,  746.31d0,  746.01d0,  745.03d0,  744.09d0,  744.32d0, &
          745.00d0,  746.19d0,  747.90d0,  749.35d0,  748.39d0,  745.41d0, &
          741.61d0,  737.93d0,  735.50d0,  734.14d0,  734.39d0,  735.29d0, &
          736.18d0,  736.00d0,  735.02d0,  732.11d0,  730.92d0,  731.04d0, &
          732.08d0,  733.76d0,  737.31d0,  738.92d0,  739.02d0,  738.45d0, &
          737.72d0,  736.49d0,  737.14d0,  738.57d0,  739.65d0,  739.27d0, &
          740.01d0,  739.04d0,  737.62d0,  736.88d0,  737.77d0,  738.18d0, &
          738.57d0,  739.01d0,  738.74d0,  737.63d0,  737.98d0,  738.59d0, &
          739.38d0,  740.51d0,  742.37d0,  742.76d0,  742.85d0,  742.24d0, &
          740.90d0,  739.82d0,  738.83d0,  737.92d0,  737.87d0,  738.38d0, &
          738.71d0,  738.98d0,  739.26d0,  738.88d0,  738.38d0,  738.56d0, &
          738.57d0,  738.45d0,  738.90d0,  739.44d0,  739.38d0,  739.10d0, &
          738.86d0,  738.19d0,  737.16d0,  736.42d0,  735.81d0,  735.45d0, &
          735.36d0,  735.57d0,  735.45d0,  735.31d0,  735.05d0,  734.83d0, &
          734.24d0,  734.22d0,  734.41d0,  734.60d0,  734.63d0,  735.14d0, &
          735.05d0,  735.06d0,  734.82d0,  734.72d0,  734.48d0,  734.72d0, &
          734.78d0,  734.92d0,  735.02d0,  735.07d0,  734.65d0,  734.29d0, &
          734.07d0,  733.80d0,  733.85d0,  733.80d0,  733.38d0,  733.13d0, &
          732.91d0,  731.92d0,  731.43d0,  731.23d0,  731.03d0,  730.73d0, &
          731.17d0,  731.06d0,  730.16d0,  729.67d0,  729.21d0,  728.31d0, &
          727.67d0,  728.06d0,  727.96d0,  727.73d0,  727.59d0,  727.34d0, &
          726.47d0,  726.41d0,  726.53d0,  726.91d0,  727.66d0,  728.41d0, &
          728.63d0,  728.70d0,  728.78d0,  729.00d0,  729.11d0,  729.31d0, &
          729.52d0,  729.63d0,  729.52d0,  729.33d0,  729.15d0,  729.01d0/)
 
    solarc(2401:2640)=(/ &
          728.82d0,  728.69d0,  728.57d0,  728.34d0,  727.70d0,  726.94d0, &
          726.10d0,  725.18d0,  724.23d0,  723.59d0,  722.75d0,  721.86d0, &
          720.98d0,  720.06d0,  719.00d0,  718.00d0,  717.06d0,  716.12d0, &
          715.22d0,  714.35d0,  713.68d0,  713.30d0,  712.88d0,  712.20d0, &
          711.21d0,  709.91d0,  707.95d0,  704.38d0,  698.71d0,  692.02d0, &
          685.08d0,  678.21d0,  672.83d0,  669.78d0,  668.26d0,  667.64d0, &
          667.35d0,  667.73d0,  669.97d0,  674.67d0,  680.64d0,  687.40d0, &
          694.12d0,  699.28d0,  702.32d0,  704.24d0,  705.63d0,  707.08d0, &
          708.82d0,  710.38d0,  711.69d0,  712.88d0,  713.79d0,  714.43d0, &
          715.11d0,  715.66d0,  716.08d0,  716.42d0,  716.74d0,  716.84d0, &
          716.94d0,  716.96d0,  716.69d0,  715.96d0,  715.13d0,  714.30d0, &
          713.66d0,  713.25d0,  713.13d0,  713.21d0,  713.33d0,  713.41d0, &
          713.48d0,  713.72d0,  714.15d0,  714.62d0,  714.94d0,  715.17d0, &
          715.25d0,  715.15d0,  715.04d0,  715.06d0,  714.96d0,  714.44d0, &
          713.73d0,  713.00d0,  712.34d0,  712.01d0,  712.05d0,  712.12d0, &
          712.04d0,  711.60d0,  710.93d0,  710.53d0,  710.65d0,  710.92d0, &
          711.42d0,  711.99d0,  712.15d0,  711.85d0,  711.44d0,  710.51d0, &
          709.54d0,  708.82d0,  708.15d0,  707.47d0,  707.32d0,  707.25d0, &
          706.99d0,  706.77d0,  706.61d0,  706.76d0,  707.52d0,  708.43d0, &
          709.18d0,  709.89d0,  710.38d0,  710.26d0,  710.02d0,  709.80d0, &
          709.40d0,  708.68d0,  706.88d0,  704.61d0,  702.60d0,  700.98d0, &
          699.55d0,  699.11d0,  699.12d0,  698.93d0,  698.55d0,  698.05d0, &
          697.89d0,  698.52d0,  699.26d0,  700.10d0,  701.15d0,  702.00d0, &
          702.05d0,  701.77d0,  700.49d0,  698.82d0,  697.28d0,  695.86d0, &
          694.86d0,  694.88d0,  695.25d0,  695.36d0,  695.32d0,  694.95d0, &
          695.01d0,  696.19d0,  697.62d0,  699.31d0,  701.49d0,  703.09d0, &
          703.52d0,  703.70d0,  703.52d0,  702.05d0,  699.79d0,  697.46d0, &
          694.93d0,  692.45d0,  690.95d0,  690.34d0,  689.88d0,  688.85d0, &
          686.81d0,  684.97d0,  684.20d0,  683.80d0,  684.34d0,  686.28d0, &
          687.90d0,  688.31d0,  688.25d0,  688.03d0,  688.21d0,  689.15d0, &
          690.43d0,  692.05d0,  693.70d0,  694.48d0,  694.61d0,  694.67d0, &
          694.35d0,  693.96d0,  694.11d0,  694.40d0,  693.65d0,  692.14d0, &
          690.10d0,  687.58d0,  685.23d0,  683.81d0,  683.42d0,  683.72d0, &
          684.15d0,  684.15d0,  684.42d0,  685.50d0,  687.21d0,  689.51d0, &
          692.15d0,  694.45d0,  695.82d0,  696.32d0,  696.16d0,  695.83d0, &
          695.59d0,  695.36d0,  695.03d0,  694.75d0,  694.51d0,  694.14d0, &
          693.77d0,  693.62d0,  693.36d0,  692.95d0,  692.58d0,  692.24d0, &
          692.02d0,  692.05d0,  692.19d0,  692.27d0,  692.29d0,  692.10d0, &
          691.96d0,  692.09d0,  692.25d0,  692.40d0,  692.67d0,  692.79d0, &
          692.61d0,  692.42d0,  692.20d0,  691.80d0,  691.28d0,  690.78d0/)
 
    solarc(2641:2880)=(/ &
          690.35d0,  689.98d0,  689.70d0,  689.51d0,  689.33d0,  689.07d0, &
          688.82d0,  688.79d0,  688.99d0,  689.26d0,  689.53d0,  689.81d0, &
          689.97d0,  689.98d0,  689.91d0,  689.92d0,  690.04d0,  690.13d0, &
          690.08d0,  689.31d0,  687.58d0,  685.54d0,  683.57d0,  681.71d0, &
          680.60d0,  680.45d0,  680.51d0,  680.39d0,  679.99d0,  679.87d0, &
          680.53d0,  681.56d0,  682.52d0,  683.62d0,  684.46d0,  684.40d0, &
          683.83d0,  683.30d0,  682.80d0,  682.42d0,  682.23d0,  682.13d0, &
          682.05d0,  681.96d0,  681.78d0,  681.55d0,  681.31d0,  681.23d0, &
          681.39d0,  681.48d0,  681.39d0,  681.14d0,  681.12d0,  681.29d0, &
          681.46d0,  681.42d0,  680.62d0,  678.87d0,  676.50d0,  673.60d0, &
          671.03d0,  669.29d0,  668.23d0,  667.51d0,  667.23d0,  666.92d0, &
          667.48d0,  668.60d0,  669.76d0,  671.06d0,  672.63d0,  672.76d0, &
          671.58d0,  670.52d0,  669.37d0,  667.65d0,  666.27d0,  665.57d0, &
          665.16d0,  665.25d0,  665.34d0,  666.33d0,  668.24d0,  669.79d0, &
          670.87d0,  672.62d0,  674.10d0,  674.78d0,  675.29d0,  675.74d0, &
          675.89d0,  675.74d0,  675.57d0,  675.45d0,  675.44d0,  675.39d0, &
          674.86d0,  673.03d0,  670.22d0,  667.64d0,  665.29d0,  663.52d0, &
          663.02d0,  663.16d0,  662.45d0,  661.17d0,  659.82d0,  659.71d0, &
          660.99d0,  663.09d0,  665.53d0,  667.88d0,  668.86d0,  668.87d0, &
          669.20d0,  669.75d0,  670.22d0,  670.82d0,  671.25d0,  670.57d0, &
          668.80d0,  666.98d0,  665.19d0,  663.58d0,  662.67d0,  662.76d0, &
          663.08d0,  663.28d0,  663.03d0,  663.01d0,  663.47d0,  664.05d0, &
          664.89d0,  666.08d0,  666.94d0,  667.20d0,  667.37d0,  667.36d0, &
          667.30d0,  667.21d0,  667.36d0,  667.68d0,  668.04d0,  668.39d0, &
          668.64d0,  668.08d0,  666.82d0,  665.41d0,  663.59d0,  661.70d0, &
          660.58d0,  659.97d0,  659.44d0,  659.21d0,  659.11d0,  659.26d0, &
          659.54d0,  659.76d0,  660.71d0,  662.11d0,  663.04d0,  663.76d0, &
          664.50d0,  664.65d0,  664.50d0,  664.32d0,  664.37d0,  664.53d0, &
          664.31d0,  663.66d0,  663.15d0,  662.55d0,  661.89d0,  661.45d0, &
          660.69d0,  658.69d0,  656.36d0,  653.95d0,  651.51d0,  649.20d0, &
          647.98d0,  647.12d0,  646.39d0,  645.59d0,  646.05d0,  647.57d0, &
          649.29d0,  650.18d0,  650.95d0,  652.06d0,  652.63d0,  652.93d0, &
          654.01d0,  655.40d0,  655.70d0,  655.42d0,  654.73d0,  654.89d0, &
          655.91d0,  657.10d0,  658.34d0,  659.92d0,  660.44d0,  659.87d0, &
          659.32d0,  658.90d0,  658.51d0,  658.29d0,  658.31d0,  658.28d0, &
          658.16d0,  657.66d0,  657.11d0,  656.89d0,  656.61d0,  656.33d0, &
          656.28d0,  656.03d0,  655.43d0,  654.86d0,  654.18d0,  653.92d0, &
          654.20d0,  654.59d0,  654.86d0,  654.98d0,  654.91d0,  654.85d0, &
          654.83d0,  654.90d0,  655.22d0,  655.09d0,  654.27d0,  653.48d0, &
          652.77d0,  652.18d0,  652.04d0,  652.36d0,  652.52d0,  652.50d0/)
 
    solarc(2881:3120)=(/ &
          652.29d0,  652.45d0,  652.69d0,  652.66d0,  652.35d0,  651.49d0, &
          650.34d0,  649.02d0,  647.86d0,  647.10d0,  646.99d0,  646.64d0, &
          646.49d0,  646.30d0,  646.81d0,  647.78d0,  648.77d0,  649.75d0, &
          651.00d0,  651.56d0,  651.61d0,  651.56d0,  651.54d0,  651.54d0, &
          651.51d0,  651.56d0,  651.64d0,  651.67d0,  651.54d0,  651.34d0, &
          651.20d0,  651.06d0,  650.88d0,  650.72d0,  650.48d0,  650.20d0, &
          649.99d0,  649.84d0,  649.78d0,  649.79d0,  649.85d0,  649.88d0, &
          649.85d0,  649.72d0,  649.51d0,  649.12d0,  648.78d0,  648.42d0, &
          647.94d0,  647.11d0,  646.01d0,  643.69d0,  639.00d0,  634.39d0, &
          630.77d0,  627.72d0,  625.89d0,  626.40d0,  627.02d0,  627.30d0, &
          626.96d0,  628.44d0,  631.85d0,  635.77d0,  639.63d0,  644.03d0, &
          646.46d0,  646.64d0,  644.93d0,  641.34d0,  637.84d0,  634.64d0, &
          631.84d0,  630.40d0,  630.62d0,  630.48d0,  629.52d0,  628.36d0, &
          628.91d0,  630.85d0,  633.13d0,  636.08d0,  639.28d0,  640.70d0, &
          640.72d0,  640.98d0,  641.41d0,  641.79d0,  641.96d0,  641.57d0, &
          639.60d0,  637.88d0,  636.29d0,  634.84d0,  633.88d0,  633.96d0, &
          633.61d0,  632.98d0,  631.94d0,  632.51d0,  634.15d0,  635.81d0, &
          637.59d0,  639.88d0,  640.94d0,  641.26d0,  641.48d0,  641.66d0, &
          641.74d0,  641.57d0,  641.27d0,  641.04d0,  640.83d0,  640.69d0, &
          640.53d0,  640.32d0,  639.99d0,  639.60d0,  638.63d0,  636.20d0, &
          632.48d0,  629.43d0,  626.60d0,  624.31d0,  623.36d0,  623.62d0, &
          623.34d0,  622.72d0,  622.31d0,  623.86d0,  626.53d0,  629.29d0, &
          632.22d0,  634.96d0,  636.04d0,  636.28d0,  636.28d0,  636.00d0, &
          634.98d0,  632.17d0,  629.09d0,  624.92d0,  621.39d0,  618.61d0, &
          616.62d0,  612.48d0,  607.83d0,  602.92d0,  599.08d0,  595.22d0, &
          595.55d0,  598.31d0,  601.03d0,  602.19d0,  604.95d0,  608.34d0, &
          612.02d0,  615.47d0,  620.80d0,  625.53d0,  626.66d0,  627.17d0, &
          628.02d0,  627.49d0,  626.81d0,  627.25d0,  627.34d0,  627.16d0, &
          626.25d0,  625.94d0,  626.43d0,  626.94d0,  627.59d0,  628.97d0, &
          629.84d0,  629.72d0,  628.85d0,  626.73d0,  623.65d0,  620.33d0, &
          617.07d0,  614.61d0,  613.27d0,  612.89d0,  612.52d0,  612.32d0, &
          612.08d0,  613.32d0,  615.72d0,  619.03d0,  622.30d0,  625.70d0, &
          627.62d0,  627.76d0,  627.10d0,  626.27d0,  624.03d0,  619.97d0, &
          617.13d0,  614.44d0,  611.21d0,  608.89d0,  609.22d0,  609.39d0, &
          609.30d0,  609.63d0,  612.40d0,  615.29d0,  617.56d0,  620.54d0, &
          624.39d0,  625.79d0,  626.20d0,  626.49d0,  626.21d0,  625.40d0, &
          624.87d0,  624.52d0,  624.39d0,  624.04d0,  623.95d0,  624.09d0, &
          624.57d0,  625.27d0,  625.94d0,  625.80d0,  624.46d0,  622.19d0, &
          619.18d0,  614.39d0,  610.77d0,  608.33d0,  606.36d0,  605.06d0, &
          605.78d0,  606.40d0,  607.51d0,  608.07d0,  610.84d0,  614.39d0/)
 
    solarc(3121:3360)=(/ &
          617.42d0,  619.72d0,  622.51d0,  622.82d0,  622.40d0,  621.83d0, &
          621.58d0,  621.31d0,  620.70d0,  618.81d0,  614.39d0,  610.49d0, &
          607.22d0,  604.63d0,  603.20d0,  603.87d0,  602.99d0,  601.38d0, &
          597.87d0,  597.35d0,  598.66d0,  600.88d0,  602.34d0,  602.67d0, &
          599.14d0,  595.24d0,  590.81d0,  588.61d0,  590.14d0,  592.66d0, &
          593.50d0,  594.18d0,  595.30d0,  597.85d0,  601.07d0,  605.53d0, &
          610.71d0,  613.58d0,  612.76d0,  612.36d0,  611.71d0,  610.91d0, &
          610.70d0,  612.08d0,  612.41d0,  612.28d0,  611.78d0,  612.64d0, &
          613.84d0,  615.11d0,  616.50d0,  618.24d0,  618.54d0,  617.91d0, &
          616.16d0,  614.62d0,  613.23d0,  611.71d0,  609.28d0,  604.22d0, &
          598.10d0,  592.43d0,  586.71d0,  583.41d0,  584.30d0,  586.10d0, &
          587.06d0,  587.16d0,  588.63d0,  592.34d0,  596.25d0,  599.89d0, &
          603.83d0,  604.10d0,  602.14d0,  600.02d0,  598.49d0,  597.61d0, &
          597.31d0,  596.67d0,  596.23d0,  595.73d0,  596.42d0,  598.52d0, &
          600.66d0,  602.50d0,  604.31d0,  605.53d0,  606.04d0,  606.21d0, &
          606.04d0,  606.93d0,  607.69d0,  608.33d0,  609.17d0,  610.27d0, &
          610.18d0,  608.84d0,  606.22d0,  604.42d0,  602.81d0,  601.18d0, &
          600.46d0,  600.97d0,  600.54d0,  599.62d0,  598.69d0,  598.56d0, &
          598.68d0,  598.50d0,  598.47d0,  598.44d0,  597.15d0,  595.14d0, &
          592.63d0,  589.00d0,  583.88d0,  576.57d0,  569.04d0,  562.21d0, &
          556.58d0,  552.76d0,  551.50d0,  551.25d0,  551.28d0,  551.80d0, &
          554.77d0,  560.01d0,  566.32d0,  572.67d0,  578.26d0,  582.16d0, &
          583.87d0,  582.90d0,  582.64d0,  583.29d0,  583.29d0,  582.82d0, &
          583.68d0,  583.92d0,  581.95d0,  579.54d0,  579.23d0,  579.54d0, &
          579.10d0,  580.35d0,  581.82d0,  581.26d0,  580.18d0,  581.54d0, &
          583.24d0,  583.53d0,  583.24d0,  583.45d0,  580.56d0,  577.54d0, &
          575.52d0,  574.73d0,  572.93d0,  571.96d0,  571.90d0,  573.42d0, &
          575.08d0,  578.58d0,  582.34d0,  585.83d0,  588.08d0,  590.30d0, &
          591.39d0,  592.25d0,  592.50d0,  592.45d0,  592.11d0,  591.23d0, &
          590.77d0,  590.29d0,  590.47d0,  590.42d0,  590.65d0,  590.17d0, &
          589.08d0,  587.49d0,  585.97d0,  582.71d0,  579.96d0,  577.59d0, &
          575.35d0,  572.95d0,  572.27d0,  572.70d0,  573.67d0,  574.07d0, &
          575.75d0,  578.23d0,  580.38d0,  582.42d0,  585.24d0,  587.05d0, &
          588.36d0,  588.67d0,  587.78d0,  586.92d0,  586.69d0,  586.15d0, &
          586.09d0,  586.49d0,  586.50d0,  585.73d0,  584.28d0,  583.39d0, &
          583.43d0,  583.68d0,  584.36d0,  585.35d0,  585.28d0,  584.91d0, &
          584.28d0,  583.82d0,  584.08d0,  584.57d0,  584.87d0,  584.89d0, &
          584.38d0,  583.56d0,  582.87d0,  581.85d0,  581.81d0,  582.00d0, &
          581.97d0,  581.58d0,  581.37d0,  581.14d0,  581.04d0,  580.71d0, &
          580.85d0,  581.27d0,  581.05d0,  580.80d0,  581.13d0,  581.62d0/)
 
    solarc(3361:3600)=(/ &
          581.88d0,  581.84d0,  581.61d0,  580.94d0,  580.32d0,  579.99d0, &
          580.50d0,  580.86d0,  581.11d0,  581.15d0,  581.31d0,  580.50d0, &
          580.21d0,  580.78d0,  581.33d0,  581.20d0,  581.44d0,  581.44d0, &
          581.10d0,  579.97d0,  578.99d0,  578.67d0,  577.85d0,  577.16d0, &
          577.40d0,  577.25d0,  576.02d0,  574.43d0,  573.40d0,  572.22d0, &
          571.91d0,  572.53d0,  573.56d0,  573.73d0,  573.47d0,  572.03d0, &
          571.22d0,  570.59d0,  570.23d0,  570.21d0,  571.17d0,  571.71d0, &
          572.30d0,  571.85d0,  572.48d0,  573.79d0,  574.70d0,  575.65d0, &
          577.09d0,  577.62d0,  576.84d0,  575.95d0,  575.37d0,  574.94d0, &
          573.85d0,  573.08d0,  572.27d0,  571.10d0,  569.92d0,  569.47d0, &
          569.58d0,  569.72d0,  570.12d0,  571.08d0,  571.90d0,  571.95d0, &
          572.77d0,  573.55d0,  574.18d0,  574.89d0,  575.74d0,  575.79d0, &
          575.60d0,  574.98d0,  574.18d0,  573.74d0,  572.94d0,  572.85d0, &
          572.93d0,  572.74d0,  572.31d0,  570.45d0,  567.97d0,  565.47d0, &
          563.10d0,  561.45d0,  561.25d0,  561.35d0,  560.83d0,  560.56d0, &
          561.01d0,  561.53d0,  561.75d0,  562.46d0,  562.73d0,  561.73d0, &
          560.59d0,  560.55d0,  560.61d0,  561.28d0,  562.30d0,  563.59d0, &
          563.93d0,  564.44d0,  564.85d0,  565.33d0,  565.66d0,  566.40d0, &
          566.87d0,  567.17d0,  567.46d0,  567.88d0,  568.15d0,  568.21d0, &
          567.72d0,  567.22d0,  566.58d0,  566.12d0,  566.02d0,  566.41d0, &
          566.80d0,  566.93d0,  566.89d0,  567.02d0,  567.01d0,  566.77d0, &
          565.92d0,  564.74d0,  563.45d0,  562.30d0,  561.31d0,  560.42d0, &
          559.20d0,  556.68d0,  552.97d0,  549.31d0,  546.49d0,  544.32d0, &
          543.07d0,  542.58d0,  542.43d0,  542.81d0,  544.56d0,  547.87d0, &
          552.04d0,  555.59d0,  558.18d0,  559.50d0,  559.81d0,  559.75d0, &
          559.54d0,  559.25d0,  558.32d0,  556.64d0,  554.94d0,  553.71d0, &
          552.92d0,  553.00d0,  553.91d0,  554.86d0,  555.66d0,  556.61d0, &
          556.62d0,  555.99d0,  555.17d0,  553.99d0,  552.05d0,  550.27d0, &
          548.70d0,  546.62d0,  545.06d0,  545.08d0,  545.65d0,  546.38d0, &
          548.06d0,  549.85d0,  550.49d0,  551.24d0,  552.45d0,  553.15d0, &
          553.50d0,  553.76d0,  553.58d0,  552.74d0,  552.27d0,  552.28d0, &
          552.56d0,  553.12d0,  553.56d0,  553.83d0,  554.02d0,  554.28d0, &
          554.19d0,  553.55d0,  552.22d0,  550.22d0,  547.79d0,  545.73d0, &
          544.33d0,  543.48d0,  542.57d0,  542.09d0,  542.29d0,  543.09d0, &
          544.42d0,  546.66d0,  548.93d0,  550.53d0,  551.60d0,  552.55d0, &
          553.01d0,  552.92d0,  552.43d0,  551.68d0,  550.48d0,  549.18d0, &
          548.11d0,  547.51d0,  547.27d0,  547.39d0,  548.01d0,  549.05d0, &
          550.12d0,  551.16d0,  552.12d0,  552.60d0,  552.43d0,  551.28d0, &
          549.35d0,  547.21d0,  545.14d0,  543.39d0,  542.00d0,  540.18d0, &
          538.19d0,  536.73d0,  536.17d0,  536.51d0,  537.84d0,  539.09d0/)
 
    solarc(3601:3840)=(/ &
          539.08d0,  538.53d0,  538.53d0,  538.72d0,  539.31d0,  540.38d0, &
          540.71d0,  540.00d0,  539.70d0,  539.98d0,  539.41d0,  538.54d0, &
          537.59d0,  536.04d0,  534.18d0,  533.14d0,  532.62d0,  532.05d0, &
          531.87d0,  532.54d0,  533.90d0,  535.69d0,  537.70d0,  539.74d0, &
          541.01d0,  540.96d0,  540.28d0,  539.71d0,  538.88d0,  537.61d0, &
          537.23d0,  537.22d0,  537.01d0,  537.33d0,  538.53d0,  539.80d0, &
          541.04d0,  541.63d0,  540.95d0,  539.41d0,  537.83d0,  536.18d0, &
          535.05d0,  534.40d0,  533.76d0,  533.37d0,  533.78d0,  534.85d0, &
          536.23d0,  537.70d0,  538.86d0,  539.47d0,  539.69d0,  539.79d0, &
          540.31d0,  541.21d0,  541.83d0,  542.30d0,  542.84d0,  543.12d0, &
          543.28d0,  543.70d0,  543.97d0,  543.72d0,  543.27d0,  542.74d0, &
          542.09d0,  541.61d0,  541.32d0,  540.97d0,  540.37d0,  539.89d0, &
          539.39d0,  538.81d0,  538.33d0,  537.87d0,  537.35d0,  537.06d0, &
          537.18d0,  537.30d0,  537.15d0,  537.05d0,  537.05d0,  537.04d0, &
          537.12d0,  537.39d0,  537.11d0,  536.25d0,  535.59d0,  535.32d0, &
          535.25d0,  535.55d0,  536.02d0,  536.11d0,  535.93d0,  535.94d0, &
          535.94d0,  535.89d0,  535.66d0,  535.12d0,  534.24d0,  533.08d0, &
          532.02d0,  531.22d0,  530.65d0,  530.26d0,  530.29d0,  530.68d0, &
          531.15d0,  531.88d0,  532.72d0,  533.48d0,  534.13d0,  534.82d0, &
          535.32d0,  535.43d0,  535.43d0,  535.43d0,  535.38d0,  535.26d0, &
          535.29d0,  535.30d0,  535.13d0,  535.07d0,  534.95d0,  534.30d0, &
          533.42d0,  532.67d0,  531.62d0,  530.40d0,  529.78d0,  529.54d0, &
          529.27d0,  529.39d0,  529.96d0,  530.56d0,  531.17d0,  531.73d0, &
          531.87d0,  531.70d0,  531.34d0,  530.91d0,  530.58d0,  530.36d0, &
          530.12d0,  530.10d0,  530.35d0,  530.54d0,  530.45d0,  530.20d0, &
          529.93d0,  529.27d0,  528.10d0,  526.49d0,  523.91d0,  520.38d0, &
          517.40d0,  515.35d0,  514.16d0,  514.01d0,  514.80d0,  515.48d0, &
          516.76d0,  518.92d0,  520.30d0,  520.53d0,  519.99d0,  517.36d0, &
          513.25d0,  510.24d0,  508.25d0,  506.35d0,  506.34d0,  507.60d0, &
          508.78d0,  511.18d0,  515.02d0,  518.31d0,  521.03d0,  523.66d0, &
          524.79d0,  524.67d0,  524.50d0,  524.27d0,  524.00d0,  524.08d0, &
          524.21d0,  522.90d0,  520.72d0,  518.96d0,  517.13d0,  515.41d0, &
          514.83d0,  514.85d0,  514.00d0,  514.01d0,  515.02d0,  516.30d0, &
          517.76d0,  519.40d0,  520.17d0,  519.75d0,  518.59d0,  516.75d0, &
          514.96d0,  513.42d0,  512.43d0,  512.29d0,  513.00d0,  513.76d0, &
          514.18d0,  514.63d0,  515.31d0,  515.82d0,  516.37d0,  517.14d0, &
          517.53d0,  517.33d0,  517.61d0,  518.37d0,  519.08d0,  519.79d0, &
          520.47d0,  520.55d0,  519.90d0,  517.78d0,  514.36d0,  511.50d0, &
          508.86d0,  506.56d0,  505.77d0,  506.36d0,  506.02d0,  506.70d0, &
          508.76d0,  511.00d0,  513.22d0,  516.06d0,  517.72d0,  517.89d0/)
 
    solarc(3841:4080)=(/ &
          517.95d0,  518.06d0,  517.95d0,  517.93d0,  518.07d0,  518.01d0, &
          517.95d0,  517.98d0,  517.88d0,  517.87d0,  517.84d0,  517.46d0, &
          516.99d0,  516.61d0,  516.11d0,  515.76d0,  515.67d0,  515.52d0, &
          515.50d0,  515.76d0,  516.05d0,  516.38d0,  516.68d0,  516.64d0, &
          516.35d0,  516.02d0,  515.50d0,  514.68d0,  513.44d0,  512.07d0, &
          510.65d0,  508.50d0,  505.35d0,  502.15d0,  499.07d0,  496.62d0, &
          495.70d0,  496.35d0,  497.61d0,  499.67d0,  502.55d0,  505.63d0, &
          508.84d0,  511.85d0,  513.66d0,  513.59d0,  512.01d0,  510.30d0, &
          508.76d0,  507.37d0,  506.16d0,  505.82d0,  505.02d0,  503.83d0, &
          502.42d0,  501.71d0,  500.89d0,  500.69d0,  501.12d0,  502.08d0, &
          502.58d0,  504.25d0,  506.56d0,  508.70d0,  510.79d0,  512.77d0, &
          513.07d0,  512.30d0,  511.57d0,  510.85d0,  510.37d0,  510.29d0, &
          510.15d0,  509.55d0,  508.61d0,  507.90d0,  507.27d0,  506.79d0, &
          506.65d0,  506.71d0,  506.16d0,  505.88d0,  506.24d0,  506.56d0, &
          506.17d0,  503.79d0,  498.83d0,  493.58d0,  488.72d0,  484.91d0, &
          483.38d0,  483.92d0,  483.91d0,  485.45d0,  488.13d0,  491.54d0, &
          495.27d0,  499.23d0,  501.31d0,  501.99d0,  501.61d0,  501.71d0, &
          502.42d0,  503.12d0,  504.01d0,  505.34d0,  505.97d0,  505.89d0, &
          505.89d0,  505.57d0,  505.03d0,  504.50d0,  504.22d0,  503.88d0, &
          503.82d0,  503.78d0,  503.82d0,  503.77d0,  503.94d0,  504.24d0, &
          504.62d0,  504.85d0,  504.64d0,  503.84d0,  501.53d0,  496.86d0, &
          491.57d0,  487.22d0,  483.16d0,  480.03d0,  478.89d0,  477.91d0, &
          477.07d0,  478.52d0,  481.07d0,  484.36d0,  488.19d0,  491.79d0, &
          493.33d0,  494.62d0,  495.76d0,  497.60d0,  499.28d0,  500.70d0, &
          501.70d0,  502.57d0,  502.64d0,  502.37d0,  502.28d0,  502.15d0, &
          501.99d0,  501.78d0,  501.39d0,  500.90d0,  500.47d0,  499.94d0, &
          499.40d0,  499.03d0,  498.66d0,  498.53d0,  498.68d0,  498.93d0, &
          499.05d0,  499.28d0,  499.44d0,  499.41d0,  499.34d0,  499.40d0, &
          499.27d0,  498.94d0,  498.76d0,  498.26d0,  496.94d0,  496.01d0, &
          495.14d0,  493.78d0,  492.42d0,  491.95d0,  490.83d0,  490.25d0, &
          490.59d0,  491.36d0,  491.84d0,  493.01d0,  493.73d0,  493.80d0, &
          493.55d0,  492.29d0,  488.54d0,  484.93d0,  481.67d0,  478.99d0, &
          477.52d0,  478.12d0,  477.62d0,  477.18d0,  475.78d0,  475.35d0, &
          475.12d0,  475.35d0,  473.93d0,  471.06d0,  466.99d0,  465.25d0, &
          465.52d0,  467.49d0,  471.67d0,  475.71d0,  479.03d0,  482.08d0, &
          485.04d0,  488.14d0,  491.64d0,  493.20d0,  493.14d0,  492.83d0, &
          492.30d0,  491.94d0,  491.80d0,  491.87d0,  491.86d0,  492.10d0, &
          492.11d0,  491.85d0,  491.65d0,  491.41d0,  490.75d0,  489.48d0, &
          486.25d0,  480.57d0,  475.77d0,  471.55d0,  467.92d0,  466.36d0, &
          466.60d0,  465.74d0,  467.39d0,  470.72d0,  474.36d0,  478.78d0/)
 
    solarc(4081:4320)=(/ &
          483.47d0,  485.38d0,  485.90d0,  486.19d0,  486.05d0,  486.13d0, &
          485.98d0,  485.61d0,  485.18d0,  485.16d0,  484.96d0,  485.15d0, &
          485.48d0,  486.02d0,  486.61d0,  487.23d0,  487.61d0,  487.71d0, &
          487.59d0,  487.28d0,  486.68d0,  485.63d0,  484.42d0,  481.59d0, &
          475.81d0,  469.17d0,  463.59d0,  458.29d0,  454.93d0,  454.47d0, &
          454.75d0,  455.96d0,  460.09d0,  465.23d0,  470.63d0,  476.40d0, &
          480.43d0,  480.55d0,  477.83d0,  475.47d0,  473.35d0,  471.43d0, &
          470.23d0,  470.08d0,  469.00d0,  469.50d0,  471.05d0,  473.00d0, &
          475.25d0,  477.48d0,  478.40d0,  478.78d0,  479.07d0,  479.54d0, &
          480.40d0,  480.65d0,  480.67d0,  480.57d0,  480.36d0,  480.08d0, &
          479.92d0,  479.45d0,  479.08d0,  478.84d0,  478.76d0,  478.87d0, &
          479.16d0,  479.35d0,  479.65d0,  479.95d0,  480.11d0,  480.13d0, &
          480.08d0,  479.87d0,  479.62d0,  479.35d0,  479.19d0,  479.13d0, &
          479.08d0,  479.03d0,  478.98d0,  478.85d0,  478.71d0,  478.65d0, &
          478.58d0,  478.38d0,  478.10d0,  477.87d0,  477.57d0,  477.24d0, &
          477.08d0,  476.96d0,  476.64d0,  476.37d0,  476.21d0,  475.92d0, &
          475.53d0,  475.05d0,  474.59d0,  474.08d0,  473.77d0,  473.58d0, &
          473.64d0,  473.65d0,  473.98d0,  474.30d0,  474.71d0,  475.05d0, &
          475.47d0,  475.47d0,  475.35d0,  475.05d0,  474.63d0,  474.14d0, &
          473.65d0,  473.16d0,  472.76d0,  472.65d0,  472.45d0,  472.32d0, &
          472.23d0,  472.05d0,  471.36d0,  471.00d0,  470.58d0,  469.97d0, &
          469.56d0,  469.68d0,  469.49d0,  469.69d0,  470.25d0,  470.72d0, &
          471.19d0,  471.75d0,  471.79d0,  471.56d0,  471.17d0,  470.73d0, &
          470.25d0,  469.90d0,  469.57d0,  469.54d0,  469.49d0,  469.68d0, &
          469.75d0,  469.66d0,  469.46d0,  469.17d0,  468.75d0,  468.26d0, &
          467.00d0,  463.97d0,  461.76d0,  459.76d0,  458.10d0,  457.38d0, &
          458.24d0,  457.98d0,  459.17d0,  460.98d0,  462.81d0,  464.84d0, &
          467.27d0,  467.99d0,  467.83d0,  467.67d0,  467.45d0,  467.26d0, &
          467.04d0,  466.90d0,  466.55d0,  466.06d0,  465.65d0,  465.19d0, &
          464.74d0,  464.52d0,  464.50d0,  464.30d0,  464.28d0,  464.03d0, &
          463.79d0,  463.60d0,  463.32d0,  462.59d0,  462.02d0,  461.36d0, &
          460.76d0,  460.45d0,  460.57d0,  460.66d0,  460.97d0,  461.24d0, &
          461.46d0,  461.69d0,  461.99d0,  462.10d0,  462.07d0,  461.72d0, &
          461.07d0,  460.60d0,  460.02d0,  459.45d0,  459.04d0,  458.92d0, &
          458.39d0,  458.31d0,  458.37d0,  458.55d0,  458.76d0,  459.41d0, &
          459.61d0,  459.80d0,  460.02d0,  460.27d0,  460.28d0,  460.28d0, &
          460.28d0,  460.23d0,  460.08d0,  459.94d0,  459.80d0,  459.71d0, &
          459.71d0,  459.73d0,  459.70d0,  459.59d0,  459.47d0,  459.22d0, &
          458.80d0,  457.90d0,  457.14d0,  456.30d0,  455.33d0,  453.73d0, &
          452.93d0,  451.95d0,  451.51d0,  451.48d0,  452.30d0,  452.54d0/)
 
    solarc(4321:4560)=(/ &
          453.57d0,  454.37d0,  455.06d0,  455.71d0,  456.66d0,  456.87d0, &
          456.58d0,  456.00d0,  455.62d0,  455.26d0,  454.63d0,  453.55d0, &
          452.74d0,  451.58d0,  450.79d0,  450.44d0,  450.23d0,  448.52d0, &
          447.89d0,  447.24d0,  446.73d0,  446.77d0,  448.02d0,  447.98d0, &
          448.74d0,  449.79d0,  450.95d0,  452.24d0,  453.87d0,  454.25d0, &
          454.11d0,  453.86d0,  453.64d0,  453.20d0,  452.58d0,  451.94d0, &
          451.40d0,  450.91d0,  450.69d0,  450.68d0,  450.45d0,  449.95d0, &
          449.71d0,  449.50d0,  449.47d0,  449.64d0,  449.97d0,  449.88d0, &
          450.23d0,  450.58d0,  450.92d0,  451.27d0,  451.82d0,  451.85d0, &
          451.78d0,  451.69d0,  451.59d0,  451.38d0,  451.22d0,  451.04d0, &
          450.82d0,  450.63d0,  450.39d0,  450.06d0,  449.90d0,  449.79d0, &
          449.49d0,  448.95d0,  448.53d0,  447.97d0,  447.31d0,  446.72d0, &
          446.20d0,  445.38d0,  444.22d0,  443.56d0,  443.12d0,  442.95d0, &
          443.00d0,  443.59d0,  443.51d0,  443.93d0,  444.54d0,  445.13d0, &
          445.50d0,  446.13d0,  446.06d0,  445.81d0,  445.67d0,  445.69d0, &
          445.73d0,  445.73d0,  445.48d0,  445.38d0,  445.27d0,  445.14d0, &
          444.87d0,  444.72d0,  444.34d0,  444.11d0,  443.68d0,  443.54d0, &
          443.31d0,  443.14d0,  442.59d0,  442.37d0,  441.99d0,  442.10d0, &
          442.17d0,  442.51d0,  442.70d0,  443.26d0,  443.24d0,  443.21d0, &
          442.90d0,  442.58d0,  442.19d0,  442.01d0,  441.67d0,  441.76d0, &
          442.04d0,  442.35d0,  443.04d0,  443.86d0,  444.24d0,  444.23d0, &
          444.10d0,  443.79d0,  443.51d0,  443.36d0,  443.47d0,  443.35d0, &
          443.04d0,  442.39d0,  441.46d0,  440.76d0,  440.10d0,  439.44d0, &
          438.97d0,  438.85d0,  438.90d0,  439.56d0,  440.34d0,  441.26d0, &
          442.16d0,  442.78d0,  442.89d0,  442.62d0,  441.39d0,  440.37d0, &
          439.50d0,  438.67d0,  438.16d0,  438.30d0,  437.03d0,  436.77d0, &
          436.84d0,  436.89d0,  437.21d0,  438.56d0,  438.46d0,  438.71d0, &
          439.18d0,  439.63d0,  440.01d0,  440.36d0,  439.43d0,  438.48d0, &
          437.49d0,  436.67d0,  436.14d0,  436.03d0,  435.41d0,  434.44d0, &
          433.64d0,  433.04d0,  432.39d0,  432.00d0,  432.02d0,  431.45d0, &
          431.63d0,  432.42d0,  433.33d0,  434.53d0,  436.22d0,  436.83d0, &
          437.13d0,  437.43d0,  437.53d0,  437.62d0,  437.82d0,  437.85d0, &
          437.95d0,  437.97d0,  437.75d0,  437.56d0,  437.39d0,  437.01d0, &
          436.67d0,  436.47d0,  436.18d0,  436.07d0,  436.06d0,  435.94d0, &
          435.84d0,  435.71d0,  435.45d0,  435.05d0,  434.63d0,  434.12d0, &
          433.56d0,  432.91d0,  432.50d0,  432.12d0,  431.88d0,  431.90d0, &
          432.05d0,  432.11d0,  432.50d0,  432.89d0,  433.22d0,  433.57d0, &
          433.85d0,  433.89d0,  433.93d0,  433.92d0,  433.83d0,  433.77d0, &
          433.66d0,  433.54d0,  433.42d0,  433.29d0,  433.12d0,  432.93d0, &
          432.69d0,  432.43d0,  432.17d0,  431.90d0,  431.64d0,  431.31d0/)
 
    solarc(4561:4800)=(/ &
          430.99d0,  430.38d0,  429.85d0,  429.30d0,  428.74d0,  428.06d0, &
          427.63d0,  426.91d0,  426.39d0,  425.92d0,  425.44d0,  424.68d0, &
          423.38d0,  421.57d0,  419.58d0,  417.09d0,  414.10d0,  410.22d0, &
          403.94d0,  396.04d0,  388.94d0,  382.37d0,  377.37d0,  375.09d0, &
          374.79d0,  375.72d0,  379.80d0,  385.28d0,  391.92d0,  399.34d0, &
          405.85d0,  409.94d0,  412.74d0,  414.78d0,  416.44d0,  417.88d0, &
          418.73d0,  419.66d0,  420.22d0,  420.40d0,  420.56d0,  420.91d0, &
          420.80d0,  420.93d0,  421.14d0,  421.18d0,  421.43d0,  422.07d0, &
          422.44d0,  422.88d0,  423.35d0,  423.67d0,  423.96d0,  424.34d0, &
          424.54d0,  424.57d0,  423.79d0,  423.37d0,  423.02d0,  422.52d0, &
          422.08d0,  422.37d0,  422.07d0,  422.24d0,  422.64d0,  422.96d0, &
          422.92d0,  423.06d0,  421.48d0,  420.03d0,  418.92d0,  418.10d0, &
          417.02d0,  417.30d0,  416.56d0,  416.88d0,  417.38d0,  418.47d0, &
          419.19d0,  420.50d0,  420.63d0,  420.86d0,  421.21d0,  421.61d0, &
          422.03d0,  422.42d0,  422.54d0,  422.57d0,  422.36d0,  421.65d0, &
          420.75d0,  419.81d0,  418.81d0,  417.92d0,  417.51d0,  417.52d0, &
          417.95d0,  418.58d0,  419.19d0,  419.83d0,  420.34d0,  420.48d0, &
          420.52d0,  420.70d0,  420.83d0,  420.87d0,  420.90d0,  420.92d0, &
          420.91d0,  420.82d0,  420.41d0,  419.96d0,  419.51d0,  418.81d0, &
          417.71d0,  416.78d0,  415.90d0,  415.23d0,  414.84d0,  414.98d0, &
          415.49d0,  416.41d0,  417.17d0,  417.91d0,  418.59d0,  418.99d0, &
          418.95d0,  418.80d0,  418.55d0,  418.26d0,  417.94d0,  417.62d0, &
          417.30d0,  417.05d0,  416.86d0,  416.65d0,  416.18d0,  415.64d0, &
          415.10d0,  414.43d0,  413.71d0,  413.28d0,  413.04d0,  412.85d0, &
          412.78d0,  412.59d0,  412.24d0,  411.74d0,  410.91d0,  409.98d0, &
          409.48d0,  409.07d0,  408.75d0,  408.96d0,  409.47d0,  410.08d0, &
          410.75d0,  411.41d0,  412.03d0,  412.58d0,  412.81d0,  412.98d0, &
          413.07d0,  413.12d0,  413.02d0,  412.95d0,  413.01d0,  413.11d0, &
          413.06d0,  412.88d0,  412.55d0,  412.12d0,  411.62d0,  411.03d0, &
          410.49d0,  410.15d0,  410.04d0,  410.07d0,  410.16d0,  410.33d0, &
          410.50d0,  410.47d0,  410.40d0,  410.44d0,  410.43d0,  410.37d0, &
          410.10d0,  409.75d0,  409.27d0,  408.58d0,  407.79d0,  407.19d0, &
          406.74d0,  406.64d0,  406.80d0,  407.17d0,  407.60d0,  407.80d0, &
          407.70d0,  407.16d0,  404.69d0,  401.38d0,  398.30d0,  395.45d0, &
          393.07d0,  392.36d0,  393.07d0,  395.20d0,  397.52d0,  399.82d0, &
          402.29d0,  404.18d0,  404.62d0,  404.74d0,  404.70d0,  404.24d0, &
          402.20d0,  399.12d0,  395.88d0,  392.54d0,  389.68d0,  388.64d0, &
          389.25d0,  391.57d0,  394.60d0,  397.70d0,  400.68d0,  403.02d0, &
          403.79d0,  404.03d0,  404.09d0,  403.36d0,  402.38d0,  401.47d0, &
          400.58d0,  399.71d0,  399.37d0,  399.57d0,  400.42d0,  401.36d0/)
 
    solarc(4801:5040)=(/ &
          402.33d0,  403.34d0,  404.01d0,  403.94d0,  403.72d0,  403.37d0, &
          402.96d0,  402.53d0,  402.09d0,  401.54d0,  401.01d0,  400.47d0, &
          400.01d0,  399.58d0,  399.26d0,  399.06d0,  399.12d0,  399.20d0, &
          399.35d0,  399.59d0,  399.86d0,  400.00d0,  400.05d0,  399.92d0, &
          399.77d0,  399.62d0,  399.47d0,  399.43d0,  399.55d0,  399.73d0, &
          399.96d0,  400.19d0,  400.29d0,  400.14d0,  399.85d0,  399.40d0, &
          398.90d0,  398.49d0,  398.24d0,  397.94d0,  397.66d0,  397.29d0, &
          396.73d0,  396.05d0,  395.38d0,  394.81d0,  394.57d0,  394.64d0, &
          395.05d0,  395.70d0,  396.24d0,  396.34d0,  396.19d0,  395.67d0, &
          393.98d0,  391.72d0,  389.83d0,  388.23d0,  386.59d0,  385.70d0, &
          385.93d0,  387.01d0,  388.09d0,  389.33d0,  391.11d0,  392.73d0, &
          393.26d0,  393.61d0,  394.12d0,  394.43d0,  394.25d0,  393.59d0, &
          392.20d0,  390.55d0,  388.98d0,  387.50d0,  386.46d0,  386.39d0, &
          387.27d0,  388.76d0,  390.38d0,  392.14d0,  393.73d0,  394.51d0, &
          394.61d0,  394.58d0,  394.53d0,  394.46d0,  394.41d0,  394.40d0, &
          394.31d0,  393.79d0,  393.06d0,  392.39d0,  391.68d0,  391.01d0, &
          390.74d0,  390.94d0,  391.46d0,  391.99d0,  392.43d0,  392.75d0, &
          392.70d0,  392.17d0,  391.59d0,  391.01d0,  390.52d0,  390.22d0, &
          390.01d0,  389.76d0,  389.56d0,  389.23d0,  388.52d0,  387.22d0, &
          385.61d0,  384.09d0,  382.74d0,  381.75d0,  381.60d0,  382.34d0, &
          383.65d0,  385.23d0,  386.76d0,  387.96d0,  388.64d0,  388.68d0, &
          388.34d0,  387.84d0,  387.47d0,  387.25d0,  387.09d0,  387.10d0, &
          387.26d0,  387.44d0,  387.50d0,  387.38d0,  387.23d0,  387.07d0, &
          386.87d0,  386.76d0,  386.78d0,  386.96d0,  387.31d0,  387.64d0, &
          387.87d0,  388.02d0,  387.95d0,  387.64d0,  387.20d0,  386.68d0, &
          386.01d0,  385.26d0,  384.65d0,  384.20d0,  383.89d0,  383.84d0, &
          384.07d0,  384.46d0,  384.79d0,  385.01d0,  385.24d0,  385.32d0, &
          385.20d0,  385.09d0,  385.08d0,  385.06d0,  384.92d0,  384.73d0, &
          384.57d0,  384.27d0,  383.59d0,  382.76d0,  382.09d0,  381.35d0, &
          380.29d0,  379.34d0,  378.98d0,  378.83d0,  378.62d0,  378.75d0, &
          379.55d0,  380.38d0,  380.92d0,  381.51d0,  382.28d0,  382.82d0, &
          383.00d0,  383.10d0,  383.21d0,  383.12d0,  382.85d0,  382.54d0, &
          382.18d0,  381.78d0,  381.46d0,  381.23d0,  381.07d0,  380.92d0, &
          380.52d0,  379.87d0,  379.23d0,  378.24d0,  376.96d0,  375.99d0, &
          375.51d0,  375.20d0,  375.09d0,  375.41d0,  375.48d0,  374.83d0, &
          374.04d0,  373.47d0,  372.83d0,  372.42d0,  372.82d0,  373.67d0, &
          374.58d0,  375.50d0,  376.54d0,  377.21d0,  377.52d0,  377.65d0, &
          377.54d0,  377.05d0,  376.25d0,  375.27d0,  374.12d0,  373.07d0, &
          372.28d0,  372.15d0,  372.40d0,  372.98d0,  373.79d0,  374.92d0, &
          375.81d0,  376.33d0,  376.79d0,  377.17d0,  377.22d0,  376.93d0/)
 
    solarc(5041:5280)=(/ &
          376.39d0,  375.35d0,  373.92d0,  372.52d0,  371.29d0,  370.30d0, &
          369.87d0,  370.12d0,  370.81d0,  371.66d0,  372.35d0,  372.69d0, &
          372.80d0,  372.71d0,  372.53d0,  372.42d0,  372.75d0,  373.28d0, &
          373.60d0,  373.64d0,  373.67d0,  373.51d0,  373.03d0,  372.39d0, &
          371.53d0,  370.80d0,  370.28d0,  369.86d0,  369.51d0,  369.57d0, &
          370.11d0,  370.58d0,  370.58d0,  370.24d0,  369.83d0,  368.85d0, &
          367.72d0,  366.74d0,  366.39d0,  366.30d0,  366.26d0,  366.18d0, &
          366.35d0,  366.42d0,  366.24d0,  366.05d0,  366.03d0,  365.95d0, &
          365.85d0,  365.92d0,  366.28d0,  366.55d0,  367.08d0,  367.93d0, &
          368.84d0,  369.56d0,  370.08d0,  370.30d0,  370.21d0,  370.01d0, &
          369.80d0,  369.68d0,  369.76d0,  369.67d0,  369.10d0,  368.22d0, &
          367.45d0,  366.57d0,  365.60d0,  364.98d0,  364.74d0,  364.28d0, &
          363.71d0,  363.09d0,  362.60d0,  361.70d0,  361.15d0,  361.14d0, &
          361.77d0,  362.55d0,  363.64d0,  364.64d0,  365.10d0,  365.10d0, &
          364.94d0,  364.85d0,  364.63d0,  364.63d0,  365.08d0,  365.73d0, &
          366.30d0,  366.74d0,  366.91d0,  366.58d0,  366.04d0,  365.47d0, &
          365.00d0,  364.64d0,  364.65d0,  364.77d0,  364.93d0,  365.06d0, &
          365.01d0,  364.43d0,  363.62d0,  362.74d0,  361.77d0,  360.77d0, &
          360.34d0,  360.32d0,  360.39d0,  360.48d0,  361.07d0,  361.67d0, &
          362.04d0,  362.33d0,  362.86d0,  363.32d0,  363.42d0,  363.14d0, &
          362.78d0,  362.09d0,  361.29d0,  360.62d0,  360.40d0,  360.52d0, &
          360.99d0,  361.32d0,  361.38d0,  361.40d0,  361.23d0,  360.72d0, &
          360.03d0,  359.93d0,  359.99d0,  359.99d0,  360.14d0,  360.65d0, &
          361.00d0,  361.10d0,  361.29d0,  361.59d0,  361.82d0,  361.79d0, &
          361.19d0,  360.06d0,  359.00d0,  357.94d0,  356.91d0,  356.27d0, &
          356.63d0,  357.31d0,  358.04d0,  358.89d0,  359.87d0,  360.31d0, &
          360.26d0,  360.10d0,  359.81d0,  359.37d0,  358.90d0,  358.54d0, &
          358.18d0,  357.87d0,  357.80d0,  357.79d0,  357.42d0,  356.88d0, &
          356.52d0,  356.17d0,  355.77d0,  355.52d0,  355.31d0,  355.11d0, &
          354.93d0,  354.80d0,  354.67d0,  354.83d0,  355.20d0,  355.58d0, &
          355.95d0,  356.42d0,  356.66d0,  356.69d0,  356.63d0,  356.63d0, &
          356.70d0,  356.82d0,  356.83d0,  356.75d0,  356.66d0,  356.48d0, &
          356.29d0,  356.16d0,  356.03d0,  355.37d0,  353.93d0,  352.37d0, &
          350.81d0,  349.08d0,  347.66d0,  347.12d0,  346.91d0,  347.09d0, &
          347.71d0,  348.64d0,  349.24d0,  350.04d0,  350.86d0,  351.58d0, &
          352.10d0,  352.49d0,  352.24d0,  351.63d0,  350.70d0,  349.88d0, &
          349.36d0,  349.28d0,  349.03d0,  349.28d0,  349.69d0,  349.95d0, &
          349.52d0,  349.55d0,  349.60d0,  349.55d0,  349.56d0,  350.28d0, &
          350.62d0,  350.58d0,  350.38d0,  350.21d0,  349.70d0,  349.35d0, &
          349.20d0,  349.07d0,  349.20d0,  349.48d0,  349.53d0,  349.27d0/)
 
    solarc(5281:5520)=(/ &
          349.29d0,  349.26d0,  349.20d0,  349.22d0,  349.57d0,  349.78d0, &
          349.94d0,  350.10d0,  350.12d0,  349.92d0,  349.62d0,  349.27d0, &
          348.91d0,  348.55d0,  347.60d0,  345.64d0,  343.95d0,  342.07d0, &
          340.14d0,  338.61d0,  339.04d0,  339.60d0,  340.05d0,  340.84d0, &
          342.04d0,  342.34d0,  342.13d0,  342.53d0,  343.13d0,  343.65d0, &
          343.90d0,  344.40d0,  344.60d0,  344.61d0,  344.56d0,  345.09d0, &
          345.68d0,  345.98d0,  345.71d0,  345.46d0,  344.93d0,  344.10d0, &
          343.40d0,  343.49d0,  343.89d0,  344.32d0,  344.92d0,  345.70d0, &
          346.13d0,  345.99d0,  345.57d0,  345.18d0,  344.65d0,  343.75d0, &
          343.04d0,  342.83d0,  342.40d0,  341.52d0,  341.33d0,  341.33d0, &
          341.13d0,  340.88d0,  341.71d0,  342.31d0,  342.18d0,  341.09d0, &
          340.50d0,  339.53d0,  338.04d0,  336.45d0,  336.37d0,  335.89d0, &
          335.51d0,  335.42d0,  336.36d0,  336.46d0,  336.76d0,  336.57d0, &
          336.79d0,  336.63d0,  336.49d0,  336.17d0,  336.88d0,  337.46d0, &
          337.38d0,  337.26d0,  337.25d0,  336.13d0,  333.79d0,  332.49d0, &
          332.26d0,  332.31d0,  332.15d0,  332.79d0,  333.68d0,  333.71d0, &
          333.57d0,  333.79d0,  334.81d0,  335.42d0,  335.83d0,  335.71d0, &
          336.02d0,  335.21d0,  332.96d0,  330.64d0,  329.84d0,  329.09d0, &
          328.50d0,  329.80d0,  332.23d0,  333.22d0,  333.32d0,  334.10d0, &
          334.32d0,  333.56d0,  333.06d0,  333.99d0,  335.19d0,  336.43d0, &
          337.76d0,  339.17d0,  339.79d0,  339.40d0,  338.28d0,  337.21d0, &
          336.20d0,  335.08d0,  334.12d0,  334.02d0,  334.33d0,  334.69d0, &
          335.08d0,  335.58d0,  335.94d0,  335.99d0,  335.90d0,  335.60d0, &
          335.42d0,  335.38d0,  335.28d0,  335.10d0,  335.23d0,  335.69d0, &
          335.97d0,  335.98d0,  335.70d0,  335.60d0,  335.41d0,  335.13d0, &
          334.83d0,  335.34d0,  335.75d0,  335.89d0,  335.63d0,  334.66d0, &
          332.03d0,  327.98d0,  324.09d0,  320.44d0,  317.98d0,  317.30d0, &
          319.44d0,  322.52d0,  325.81d0,  327.92d0,  328.71d0,  328.05d0, &
          326.24d0,  323.87d0,  322.36d0,  322.80d0,  323.71d0,  324.86d0, &
          326.38d0,  327.81d0,  328.00d0,  326.85d0,  326.00d0,  325.36d0, &
          325.22d0,  325.18d0,  326.79d0,  328.37d0,  329.61d0,  330.34d0, &
          330.78d0,  329.98d0,  328.39d0,  327.42d0,  326.71d0,  326.23d0, &
          326.09d0,  326.92d0,  327.61d0,  328.17d0,  328.79d0,  329.31d0, &
          329.33d0,  329.17d0,  329.17d0,  329.13d0,  329.07d0,  328.63d0, &
          328.27d0,  327.42d0,  326.25d0,  325.10d0,  324.58d0,  323.40d0, &
          321.58d0,  321.05d0,  320.85d0,  320.31d0,  319.87d0,  321.37d0, &
          322.26d0,  323.05d0,  323.79d0,  324.67d0,  324.48d0,  324.09d0, &
          323.56d0,  322.96d0,  322.05d0,  321.02d0,  320.27d0,  319.75d0, &
          319.30d0,  319.40d0,  319.41d0,  319.29d0,  319.25d0,  319.34d0, &
          319.08d0,  319.48d0,  319.87d0,  320.26d0,  320.72d0,  321.40d0/)
 
    solarc(5521:5760)=(/ &
          321.57d0,  321.93d0,  322.44d0,  322.99d0,  323.74d0,  324.61d0, &
          325.31d0,  325.43d0,  325.11d0,  324.80d0,  324.47d0,  323.77d0, &
          322.87d0,  322.31d0,  321.98d0,  321.71d0,  321.52d0,  321.57d0, &
          321.77d0,  321.34d0,  320.82d0,  320.49d0,  320.02d0,  318.83d0, &
          318.37d0,  317.99d0,  317.41d0,  316.92d0,  317.14d0,  316.57d0, &
          316.42d0,  316.81d0,  317.42d0,  317.86d0,  319.06d0,  319.48d0, &
          318.73d0,  318.06d0,  317.26d0,  315.95d0,  315.04d0,  315.79d0, &
          316.62d0,  317.79d0,  319.21d0,  320.36d0,  320.20d0,  319.36d0, &
          318.52d0,  317.45d0,  316.51d0,  316.04d0,  316.43d0,  316.93d0, &
          317.57d0,  318.49d0,  319.31d0,  319.56d0,  319.03d0,  318.08d0, &
          316.49d0,  314.92d0,  313.29d0,  312.28d0,  311.91d0,  312.54d0, &
          313.10d0,  313.34d0,  313.76d0,  313.67d0,  312.97d0,  311.96d0, &
          312.10d0,  311.65d0,  310.57d0,  309.28d0,  308.55d0,  307.36d0, &
          306.24d0,  306.73d0,  307.72d0,  308.11d0,  308.69d0,  309.50d0, &
          309.42d0,  308.64d0,  308.70d0,  309.02d0,  309.57d0,  309.96d0, &
          310.18d0,  310.01d0,  309.68d0,  309.07d0,  308.61d0,  308.22d0, &
          308.20d0,  308.15d0,  308.30d0,  308.49d0,  309.41d0,  310.71d0, &
          311.84d0,  312.60d0,  313.45d0,  313.82d0,  313.13d0,  311.71d0, &
          310.98d0,  310.13d0,  309.42d0,  308.97d0,  309.64d0,  310.00d0, &
          310.40d0,  310.55d0,  310.11d0,  309.41d0,  308.44d0,  307.05d0, &
          305.60d0,  306.01d0,  306.29d0,  306.64d0,  307.76d0,  309.85d0, &
          310.89d0,  311.58d0,  312.08d0,  312.47d0,  312.25d0,  311.54d0, &
          310.22d0,  309.50d0,  308.67d0,  307.87d0,  307.02d0,  306.61d0, &
          304.64d0,  299.70d0,  293.70d0,  288.35d0,  283.64d0,  279.90d0, &
          281.25d0,  286.36d0,  292.56d0,  298.54d0,  304.52d0,  308.11d0, &
          309.25d0,  308.94d0,  308.39d0,  308.12d0,  308.22d0,  307.87d0, &
          307.79d0,  307.55d0,  306.82d0,  306.17d0,  306.23d0,  306.07d0, &
          306.05d0,  306.96d0,  307.65d0,  307.78d0,  308.03d0,  308.46d0, &
          308.43d0,  308.54d0,  308.82d0,  308.86d0,  308.41d0,  308.00d0, &
          307.01d0,  304.80d0,  302.82d0,  301.25d0,  299.76d0,  298.40d0, &
          298.98d0,  299.37d0,  300.31d0,  301.23d0,  302.55d0,  303.00d0, &
          303.87d0,  303.96d0,  303.39d0,  303.05d0,  302.85d0,  302.30d0, &
          301.85d0,  302.58d0,  303.25d0,  303.92d0,  304.46d0,  305.02d0, &
          304.99d0,  304.72d0,  304.44d0,  304.28d0,  304.00d0,  303.41d0, &
          301.69d0,  296.93d0,  291.84d0,  287.57d0,  283.41d0,  279.65d0, &
          280.99d0,  283.57d0,  283.59d0,  284.37d0,  285.50d0,  282.58d0, &
          278.10d0,  277.09d0,  276.22d0,  275.49d0,  277.74d0,  281.32d0, &
          284.38d0,  287.33d0,  290.59d0,  293.47d0,  295.89d0,  297.18d0, &
          297.48d0,  297.76d0,  296.87d0,  295.07d0,  293.43d0,  292.65d0, &
          291.93d0,  291.84d0,  293.39d0,  295.28d0,  296.66d0,  297.89d0/)
 
    solarc(5761:6000)=(/ &
          299.09d0,  299.40d0,  299.45d0,  299.51d0,  299.72d0,  299.62d0, &
          299.07d0,  298.03d0,  296.46d0,  294.94d0,  293.51d0,  292.61d0, &
          291.84d0,  291.96d0,  291.96d0,  292.08d0,  291.84d0,  291.99d0, &
          291.82d0,  292.03d0,  292.47d0,  293.10d0,  293.62d0,  294.12d0, &
          293.97d0,  293.56d0,  292.95d0,  292.33d0,  291.34d0,  291.07d0, &
          290.87d0,  291.45d0,  291.97d0,  293.03d0,  293.74d0,  294.14d0, &
          293.57d0,  293.22d0,  292.74d0,  291.93d0,  291.47d0,  292.04d0, &
          292.29d0,  292.45d0,  292.63d0,  291.70d0,  290.46d0,  289.68d0, &
          288.75d0,  287.11d0,  286.68d0,  286.63d0,  286.33d0,  286.04d0, &
          286.36d0,  287.28d0,  287.80d0,  288.30d0,  288.96d0,  289.89d0, &
          289.76d0,  288.62d0,  287.93d0,  287.36d0,  286.52d0,  285.69d0, &
          286.90d0,  287.97d0,  288.74d0,  289.49d0,  290.58d0,  290.45d0, &
          289.94d0,  289.47d0,  289.57d0,  289.75d0,  289.95d0,  290.10d0, &
          290.30d0,  290.12d0,  289.66d0,  289.11d0,  287.51d0,  284.94d0, &
          282.29d0,  279.85d0,  277.35d0,  276.22d0,  277.17d0,  279.08d0, &
          281.46d0,  284.11d0,  286.29d0,  287.37d0,  287.52d0,  286.99d0, &
          286.39d0,  285.86d0,  285.30d0,  284.88d0,  283.98d0,  283.30d0, &
          282.69d0,  281.66d0,  280.35d0,  280.54d0,  280.69d0,  280.66d0, &
          281.57d0,  283.02d0,  283.60d0,  283.94d0,  284.52d0,  284.75d0, &
          284.72d0,  284.81d0,  284.77d0,  283.93d0,  282.82d0,  281.94d0, &
          280.88d0,  279.49d0,  279.32d0,  279.94d0,  280.09d0,  279.05d0, &
          278.77d0,  278.03d0,  276.30d0,  274.31d0,  274.74d0,  275.08d0, &
          275.10d0,  275.94d0,  277.61d0,  278.19d0,  278.23d0,  278.62d0, &
          278.86d0,  278.85d0,  278.79d0,  279.04d0,  279.69d0,  280.19d0, &
          280.64d0,  280.97d0,  281.38d0,  281.38d0,  281.36d0,  281.33d0, &
          281.57d0,  281.67d0,  281.70d0,  281.58d0,  281.40d0,  281.04d0, &
          280.51d0,  279.19d0,  278.03d0,  276.47d0,  274.71d0,  272.93d0, &
          272.85d0,  272.63d0,  272.97d0,  273.83d0,  275.23d0,  275.48d0, &
          275.29d0,  275.12d0,  274.50d0,  273.75d0,  273.16d0,  273.39d0, &
          273.52d0,  274.38d0,  275.16d0,  276.18d0,  276.78d0,  277.32d0, &
          277.47d0,  277.35d0,  276.25d0,  275.01d0,  274.05d0,  272.59d0, &
          270.97d0,  269.99d0,  269.81d0,  269.66d0,  270.13d0,  270.25d0, &
          270.78d0,  270.51d0,  270.15d0,  269.38d0,  269.54d0,  269.58d0, &
          270.44d0,  271.37d0,  272.51d0,  273.09d0,  273.56d0,  273.14d0, &
          272.70d0,  272.25d0,  272.13d0,  271.37d0,  270.99d0,  270.70d0, &
          270.37d0,  269.82d0,  270.26d0,  271.16d0,  271.99d0,  272.83d0, &
          273.77d0,  274.50d0,  274.63d0,  273.98d0,  273.46d0,  273.18d0, &
          272.77d0,  271.81d0,  270.91d0,  270.42d0,  269.76d0,  269.05d0, &
          268.70d0,  269.68d0,  269.91d0,  270.56d0,  271.18d0,  271.80d0, &
          270.63d0,  270.12d0,  269.19d0,  268.11d0,  267.09d0,  267.26d0/)
 
    solarc(6001:6240)=(/ &
          267.39d0,  267.54d0,  267.67d0,  267.37d0,  266.75d0,  266.09d0, &
          265.35d0,  264.90d0,  264.73d0,  264.89d0,  265.15d0,  265.36d0, &
          265.26d0,  265.90d0,  266.87d0,  267.54d0,  268.46d0,  269.63d0, &
          270.28d0,  270.41d0,  270.43d0,  269.68d0,  269.03d0,  268.68d0, &
          268.14d0,  267.41d0,  267.92d0,  268.05d0,  266.05d0,  264.76d0, &
          263.40d0,  259.14d0,  255.10d0,  255.12d0,  254.58d0,  253.21d0, &
          256.18d0,  258.75d0,  256.72d0,  253.75d0,  252.37d0,  248.58d0, &
          244.99d0,  245.60d0,  248.24d0,  251.42d0,  255.41d0,  259.41d0, &
          261.72d0,  263.51d0,  264.04d0,  264.14d0,  264.80d0,  265.61d0, &
          265.62d0,  266.00d0,  265.93d0,  265.96d0,  265.46d0,  263.50d0, &
          261.14d0,  258.86d0,  256.55d0,  254.97d0,  255.47d0,  256.26d0, &
          257.17d0,  258.10d0,  258.48d0,  257.88d0,  258.02d0,  258.92d0, &
          259.95d0,  260.91d0,  261.78d0,  261.97d0,  261.39d0,  260.57d0, &
          260.38d0,  259.70d0,  258.86d0,  257.90d0,  257.06d0,  255.24d0, &
          254.22d0,  252.70d0,  250.55d0,  246.60d0,  243.25d0,  239.53d0, &
          236.92d0,  235.73d0,  237.64d0,  239.67d0,  241.60d0,  243.20d0, &
          244.41d0,  244.92d0,  246.02d0,  248.05d0,  250.59d0,  253.45d0, &
          256.06d0,  258.05d0,  259.38d0,  260.20d0,  260.46d0,  260.42d0, &
          260.42d0,  260.61d0,  260.92d0,  261.30d0,  261.47d0,  260.99d0, &
          259.87d0,  257.37d0,  254.47d0,  251.60d0,  249.71d0,  248.70d0, &
          250.19d0,  252.46d0,  255.36d0,  257.93d0,  259.93d0,  260.53d0, &
          260.04d0,  258.83d0,  257.54d0,  256.38d0,  255.48d0,  255.81d0, &
          255.85d0,  255.48d0,  254.73d0,  253.60d0,  251.73d0,  250.85d0, &
          250.63d0,  250.87d0,  251.44d0,  252.41d0,  252.66d0,  252.84d0, &
          253.19d0,  253.49d0,  253.46d0,  253.61d0,  253.32d0,  252.61d0, &
          251.79d0,  251.30d0,  251.20d0,  251.52d0,  251.52d0,  251.24d0, &
          250.51d0,  249.36d0,  248.19d0,  248.17d0,  248.81d0,  249.97d0, &
          251.23d0,  252.25d0,  252.65d0,  252.69d0,  252.32d0,  251.09d0, &
          248.96d0,  246.33d0,  243.17d0,  239.97d0,  238.36d0,  238.45d0, &
          239.29d0,  240.98d0,  242.75d0,  243.79d0,  244.26d0,  244.56d0, &
          244.81d0,  245.62d0,  246.54d0,  247.27d0,  247.66d0,  247.76d0, &
          247.53d0,  247.26d0,  247.17d0,  247.09d0,  246.48d0,  244.99d0, &
          242.81d0,  240.46d0,  238.31d0,  236.83d0,  236.69d0,  237.49d0, &
          238.61d0,  240.53d0,  242.58d0,  244.19d0,  245.54d0,  246.38d0, &
          246.40d0,  246.39d0,  246.17d0,  245.00d0,  243.54d0,  241.48d0, &
          238.92d0,  236.47d0,  235.78d0,  236.09d0,  237.22d0,  238.71d0, &
          240.48d0,  241.35d0,  242.07d0,  243.11d0,  244.29d0,  245.21d0, &
          246.33d0,  247.16d0,  247.08d0,  246.53d0,  245.77d0,  244.69d0, &
          243.69d0,  243.46d0,  243.59d0,  243.74d0,  244.11d0,  244.45d0, &
          244.48d0,  244.61d0,  245.07d0,  245.51d0,  245.88d0,  246.24d0/)
 
    solarc(6241:6480)=(/ &
          246.46d0,  246.48d0,  246.39d0,  245.94d0,  245.23d0,  244.36d0, &
          243.27d0,  242.35d0,  242.16d0,  242.28d0,  242.44d0,  242.79d0, &
          243.02d0,  242.86d0,  242.69d0,  242.47d0,  242.15d0,  241.77d0, &
          240.68d0,  239.25d0,  238.23d0,  237.24d0,  236.52d0,  237.08d0, &
          238.12d0,  238.97d0,  239.85d0,  240.50d0,  240.61d0,  240.19d0, &
          238.81d0,  237.09d0,  235.32d0,  233.43d0,  232.06d0,  231.96d0, &
          231.16d0,  229.67d0,  228.17d0,  226.31d0,  224.31d0,  224.32d0, &
          225.18d0,  226.08d0,  227.07d0,  227.77d0,  227.41d0,  226.93d0, &
          226.40d0,  225.88d0,  225.51d0,  225.51d0,  225.83d0,  226.60d0, &
          227.66d0,  228.84d0,  229.61d0,  229.76d0,  229.70d0,  229.32d0, &
          228.26d0,  227.63d0,  227.68d0,  227.57d0,  227.78d0,  228.87d0, &
          229.81d0,  230.41d0,  231.12d0,  231.60d0,  231.77d0,  231.84d0, &
          231.90d0,  232.01d0,  232.04d0,  231.35d0,  230.49d0,  229.76d0, &
          228.84d0,  228.23d0,  228.93d0,  229.85d0,  230.05d0,  230.19d0, &
          230.11d0,  229.13d0,  228.37d0,  228.83d0,  229.51d0,  229.86d0, &
          230.43d0,  230.79d0,  230.41d0,  230.13d0,  230.44d0,  230.65d0, &
          230.57d0,  230.51d0,  230.25d0,  229.68d0,  229.49d0,  229.68d0, &
          229.99d0,  230.49d0,  230.97d0,  231.16d0,  231.20d0,  231.19d0, &
          231.11d0,  231.02d0,  230.97d0,  230.91d0,  230.59d0,  230.05d0, &
          229.50d0,  228.96d0,  228.63d0,  228.82d0,  229.34d0,  229.98d0, &
          230.66d0,  231.16d0,  231.38d0,  231.32d0,  231.06d0,  230.65d0, &
          230.14d0,  229.61d0,  229.04d0,  228.58d0,  228.32d0,  228.08d0, &
          227.89d0,  227.79d0,  227.60d0,  227.28d0,  226.84d0,  226.25d0, &
          225.70d0,  225.24d0,  224.89d0,  224.90d0,  225.09d0,  225.08d0, &
          225.00d0,  224.62d0,  223.47d0,  222.21d0,  221.34d0,  220.70d0, &
          220.86d0,  222.15d0,  223.54d0,  224.68d0,  225.63d0,  225.92d0, &
          225.66d0,  225.27d0,  224.53d0,  223.09d0,  221.29d0,  219.24d0, &
          217.11d0,  215.91d0,  216.11d0,  217.09d0,  218.54d0,  220.13d0, &
          221.13d0,  221.42d0,  221.25d0,  220.28d0,  218.96d0,  217.72d0, &
          216.36d0,  215.31d0,  215.34d0,  215.82d0,  216.22d0,  217.02d0, &
          217.87d0,  218.11d0,  218.04d0,  217.83d0,  217.26d0,  216.38d0, &
          215.51d0,  214.63d0,  213.36d0,  211.68d0,  209.73d0,  207.26d0, &
          204.79d0,  203.15d0,  202.09d0,  201.79d0,  202.80d0,  204.38d0, &
          205.94d0,  207.80d0,  209.58d0,  210.87d0,  212.00d0,  213.10d0, &
          213.97d0,  214.65d0,  215.27d0,  215.75d0,  215.78d0,  215.55d0, &
          215.29d0,  214.94d0,  214.66d0,  214.72d0,  214.80d0,  214.71d0, &
          214.77d0,  214.89d0,  215.05d0,  215.34d0,  215.18d0,  214.48d0, &
          213.66d0,  212.68d0,  212.12d0,  212.61d0,  213.63d0,  214.61d0, &
          215.56d0,  216.12d0,  216.23d0,  216.29d0,  216.36d0,  216.46d0, &
          216.45d0,  216.33d0,  216.15d0,  215.90d0,  215.70d0,  215.59d0/)
 
    solarc(6481:6720)=(/ &
          215.50d0,  215.45d0,  215.46d0,  215.41d0,  215.29d0,  215.15d0, &
          214.91d0,  214.59d0,  214.29d0,  214.03d0,  213.85d0,  213.77d0, &
          213.79d0,  213.84d0,  213.88d0,  213.79d0,  213.60d0,  213.15d0, &
          212.52d0,  211.88d0,  211.19d0,  210.66d0,  210.22d0,  209.88d0, &
          209.79d0,  209.79d0,  209.61d0,  209.49d0,  209.29d0,  208.67d0, &
          208.15d0,  207.98d0,  208.11d0,  208.56d0,  209.34d0,  210.13d0, &
          210.62d0,  210.72d0,  210.53d0,  210.20d0,  209.70d0,  209.16d0, &
          208.81d0,  208.51d0,  207.71d0,  206.65d0,  205.75d0,  204.84d0, &
          204.33d0,  204.56d0,  205.18d0,  205.69d0,  206.23d0,  206.79d0, &
          207.18d0,  206.97d0,  205.53d0,  203.23d0,  200.76d0,  198.45d0, &
          197.77d0,  199.33d0,  201.89d0,  204.40d0,  206.72d0,  207.97d0, &
          208.23d0,  208.25d0,  208.27d0,  208.29d0,  208.28d0,  208.22d0, &
          208.11d0,  207.78d0,  207.25d0,  206.73d0,  206.26d0,  205.94d0, &
          205.78d0,  205.68d0,  205.57d0,  205.38d0,  205.28d0,  205.37d0, &
          205.39d0,  205.23d0,  205.13d0,  204.77d0,  204.15d0,  203.54d0, &
          203.07d0,  202.53d0,  202.19d0,  202.38d0,  202.82d0,  202.82d0, &
          202.33d0,  201.34d0,  199.32d0,  197.48d0,  196.72d0,  196.89d0, &
          197.90d0,  199.63d0,  200.88d0,  201.49d0,  201.67d0,  201.46d0, &
          201.27d0,  201.43d0,  201.65d0,  201.93d0,  201.92d0,  201.48d0, &
          200.75d0,  199.95d0,  199.32d0,  199.17d0,  199.58d0,  200.15d0, &
          200.79d0,  201.27d0,  201.39d0,  201.16d0,  200.90d0,  200.56d0, &
          200.07d0,  199.53d0,  198.79d0,  197.14d0,  194.85d0,  192.59d0, &
          190.36d0,  188.72d0,  188.34d0,  188.88d0,  189.33d0,  189.93d0, &
          190.14d0,  189.61d0,  188.40d0,  186.81d0,  184.89d0,  183.12d0, &
          181.99d0,  181.81d0,  182.76d0,  184.47d0,  186.46d0,  188.48d0, &
          190.17d0,  191.36d0,  192.13d0,  192.72d0,  193.23d0,  193.63d0, &
          193.66d0,  193.30d0,  192.94d0,  192.37d0,  192.13d0,  192.54d0, &
          193.24d0,  193.73d0,  194.31d0,  194.61d0,  194.65d0,  194.88d0, &
          195.23d0,  195.34d0,  194.93d0,  194.23d0,  193.21d0,  192.07d0, &
          191.56d0,  191.25d0,  190.79d0,  190.54d0,  190.31d0,  189.90d0, &
          190.30d0,  191.36d0,  192.41d0,  193.38d0,  193.91d0,  193.75d0, &
          193.09d0,  192.30d0,  191.54d0,  190.76d0,  190.22d0,  190.06d0, &
          190.11d0,  190.24d0,  190.62d0,  190.72d0,  190.81d0,  191.09d0, &
          191.46d0,  191.78d0,  192.21d0,  192.36d0,  191.96d0,  191.52d0, &
          191.08d0,  190.66d0,  190.65d0,  190.94d0,  191.26d0,  191.66d0, &
          191.98d0,  191.86d0,  191.56d0,  191.25d0,  190.83d0,  190.57d0, &
          190.50d0,  190.49d0,  190.39d0,  190.34d0,  190.10d0,  189.60d0, &
          189.14d0,  188.61d0,  187.75d0,  186.70d0,  185.76d0,  184.57d0, &
          184.00d0,  184.16d0,  184.83d0,  185.52d0,  186.18d0,  186.35d0, &
          186.11d0,  185.93d0,  186.08d0,  186.55d0,  186.96d0,  187.32d0/)
 
    solarc(6721:6960)=(/ &
          187.37d0,  187.12d0,  186.67d0,  186.16d0,  185.76d0,  185.32d0, &
          185.09d0,  185.13d0,  185.30d0,  185.34d0,  185.30d0,  184.98d0, &
          184.46d0,  183.85d0,  183.44d0,  183.27d0,  183.29d0,  183.50d0, &
          183.85d0,  184.13d0,  184.37d0,  184.56d0,  184.62d0,  184.59d0, &
          184.50d0,  184.28d0,  183.96d0,  183.60d0,  183.09d0,  182.55d0, &
          182.11d0,  181.63d0,  181.19d0,  180.69d0,  179.80d0,  179.02d0, &
          178.41d0,  178.17d0,  178.53d0,  179.30d0,  179.73d0,  180.05d0, &
          179.97d0,  179.74d0,  179.73d0,  180.04d0,  180.44d0,  180.74d0, &
          180.65d0,  180.33d0,  179.78d0,  179.18d0,  178.81d0,  178.64d0, &
          178.51d0,  178.51d0,  178.58d0,  178.36d0,  177.95d0,  177.66d0, &
          177.31d0,  177.18d0,  177.43d0,  178.00d0,  178.53d0,  179.17d0, &
          179.58d0,  179.78d0,  179.82d0,  179.75d0,  179.60d0,  179.37d0, &
          179.08d0,  178.75d0,  178.44d0,  178.22d0,  178.14d0,  178.12d0, &
          178.11d0,  178.01d0,  177.83d0,  177.59d0,  177.30d0,  177.09d0, &
          176.91d0,  176.83d0,  176.64d0,  176.46d0,  176.28d0,  176.11d0, &
          176.07d0,  176.25d0,  176.48d0,  176.60d0,  176.63d0,  176.47d0, &
          176.12d0,  175.83d0,  175.69d0,  175.66d0,  175.75d0,  176.00d0, &
          176.24d0,  176.45d0,  176.62d0,  176.61d0,  176.40d0,  175.85d0, &
          175.27d0,  174.70d0,  174.16d0,  173.59d0,  173.17d0,  172.50d0, &
          171.91d0,  171.64d0,  171.70d0,  172.08d0,  172.85d0,  173.64d0, &
          174.11d0,  174.41d0,  174.47d0,  174.33d0,  174.04d0,  173.63d0, &
          173.29d0,  172.92d0,  172.65d0,  172.55d0,  172.50d0,  172.48d0, &
          172.58d0,  172.68d0,  172.65d0,  172.69d0,  172.60d0,  172.50d0, &
          172.42d0,  172.31d0,  172.14d0,  171.87d0,  171.48d0,  171.10d0, &
          170.76d0,  170.56d0,  170.49d0,  170.46d0,  170.25d0,  169.83d0, &
          169.27d0,  168.53d0,  167.82d0,  167.17d0,  166.51d0,  165.68d0, &
          164.67d0,  163.20d0,  161.13d0,  158.62d0,  156.08d0,  154.02d0, &
          153.05d0,  153.44d0,  155.02d0,  157.27d0,  159.62d0,  161.59d0, &
          162.98d0,  163.97d0,  164.45d0,  164.55d0,  164.44d0,  163.80d0, &
          163.17d0,  162.85d0,  162.86d0,  163.34d0,  164.50d0,  165.64d0, &
          166.57d0,  167.28d0,  167.42d0,  167.34d0,  167.22d0,  167.15d0, &
          167.19d0,  167.31d0,  167.38d0,  167.41d0,  167.38d0,  166.98d0, &
          166.24d0,  165.59d0,  164.89d0,  164.57d0,  164.75d0,  165.27d0, &
          165.69d0,  166.21d0,  166.44d0,  166.49d0,  166.39d0,  166.00d0, &
          165.39d0,  164.40d0,  163.63d0,  163.20d0,  163.34d0,  163.79d0, &
          164.52d0,  164.86d0,  164.96d0,  164.77d0,  164.46d0,  164.23d0, &
          164.21d0,  164.27d0,  164.17d0,  163.66d0,  163.15d0,  162.44d0, &
          162.07d0,  162.09d0,  162.43d0,  162.57d0,  162.73d0,  162.61d0, &
          162.42d0,  162.47d0,  162.68d0,  162.82d0,  162.38d0,  161.38d0, &
          160.15d0,  158.84d0,  158.22d0,  158.30d0,  158.91d0,  159.55d0/)
 
    solarc(6961:7200)=(/ &
          160.30d0,  160.61d0,  160.81d0,  160.98d0,  161.14d0,  160.74d0, &
          159.50d0,  158.01d0,  155.98d0,  154.71d0,  154.50d0,  155.43d0, &
          156.65d0,  158.40d0,  159.51d0,  160.23d0,  160.68d0,  160.96d0, &
          161.18d0,  161.34d0,  161.40d0,  161.26d0,  160.91d0,  160.30d0, &
          159.61d0,  158.91d0,  158.48d0,  158.41d0,  158.78d0,  159.26d0, &
          159.66d0,  159.48d0,  158.65d0,  157.72d0,  156.83d0,  156.57d0, &
          156.97d0,  157.85d0,  158.64d0,  159.33d0,  159.35d0,  158.94d0, &
          158.35d0,  157.52d0,  156.74d0,  156.16d0,  155.78d0,  155.69d0, &
          155.66d0,  155.70d0,  155.66d0,  155.64d0,  155.45d0,  155.55d0, &
          155.54d0,  155.66d0,  155.69d0,  155.73d0,  155.51d0,  155.56d0, &
          155.49d0,  155.30d0,  154.89d0,  154.19d0,  153.39d0,  152.58d0, &
          152.13d0,  151.86d0,  152.20d0,  152.43d0,  153.05d0,  153.58d0, &
          154.16d0,  154.51d0,  154.75d0,  154.59d0,  154.25d0,  153.83d0, &
          153.33d0,  152.68d0,  151.57d0,  150.51d0,  149.37d0,  148.43d0, &
          147.67d0,  147.07d0,  145.83d0,  143.65d0,  139.85d0,  135.35d0, &
          131.23d0,  128.80d0,  129.05d0,  131.87d0,  136.03d0,  140.52d0, &
          144.12d0,  146.38d0,  147.75d0,  148.62d0,  149.03d0,  149.22d0, &
          149.13d0,  149.15d0,  149.31d0,  149.82d0,  150.42d0,  151.03d0, &
          151.31d0,  151.35d0,  151.22d0,  151.10d0,  151.05d0,  151.06d0, &
          150.97d0,  150.71d0,  150.43d0,  149.81d0,  148.85d0,  148.19d0, &
          147.63d0,  147.59d0,  148.21d0,  149.09d0,  149.73d0,  150.35d0, &
          150.39d0,  150.15d0,  149.78d0,  149.22d0,  148.28d0,  147.57d0, &
          146.90d0,  146.79d0,  146.81d0,  147.16d0,  146.90d0,  146.43d0, &
          145.42d0,  144.48d0,  143.91d0,  143.96d0,  144.34d0,  144.81d0, &
          145.22d0,  145.10d0,  144.59d0,  143.65d0,  142.56d0,  141.92d0, &
          141.67d0,  142.05d0,  142.86d0,  143.98d0,  144.63d0,  144.89d0, &
          144.71d0,  144.21d0,  144.06d0,  144.21d0,  144.79d0,  145.41d0, &
          146.20d0,  146.50d0,  146.61d0,  146.45d0,  145.85d0,  144.98d0, &
          144.15d0,  143.42d0,  143.13d0,  143.17d0,  143.46d0,  143.67d0, &
          143.95d0,  143.95d0,  144.00d0,  143.97d0,  143.90d0,  143.62d0, &
          143.16d0,  142.72d0,  142.46d0,  142.47d0,  142.68d0,  143.03d0, &
          143.25d0,  143.25d0,  142.98d0,  142.27d0,  141.38d0,  140.65d0, &
          140.11d0,  140.02d0,  140.45d0,  141.07d0,  141.67d0,  142.15d0, &
          142.29d0,  142.20d0,  142.05d0,  141.76d0,  141.47d0,  141.18d0, &
          141.05d0,  141.04d0,  141.11d0,  141.10d0,  140.97d0,  140.77d0, &
          140.42d0,  139.87d0,  139.21d0,  138.67d0,  138.26d0,  138.35d0, &
          138.84d0,  139.53d0,  140.18d0,  140.70d0,  140.63d0,  140.23d0, &
          139.87d0,  139.47d0,  139.17d0,  139.17d0,  139.30d0,  139.50d0, &
          139.76d0,  139.83d0,  139.74d0,  139.64d0,  139.38d0,  138.94d0, &
          138.59d0,  137.97d0,  137.21d0,  136.33d0,  135.77d0,  135.38d0/)
 
    solarc(7201:7440)=(/ &
          135.48d0,  135.77d0,  135.94d0,  135.88d0,  135.83d0,  135.42d0, &
          135.02d0,  134.83d0,  134.69d0,  134.59d0,  134.91d0,  135.37d0, &
          135.85d0,  136.22d0,  136.39d0,  136.27d0,  136.21d0,  136.25d0, &
          136.48d0,  136.68d0,  136.90d0,  136.89d0,  136.61d0,  135.75d0, &
          134.68d0,  133.43d0,  132.55d0,  132.26d0,  132.69d0,  133.36d0, &
          134.07d0,  134.39d0,  134.17d0,  133.56d0,  132.60d0,  131.19d0, &
          129.46d0,  127.48d0,  125.24d0,  122.90d0,  120.90d0,  119.17d0, &
          118.72d0,  119.40d0,  121.28d0,  123.66d0,  126.37d0,  128.27d0, &
          129.83d0,  130.76d0,  131.30d0,  131.35d0,  131.32d0,  131.04d0, &
          130.62d0,  129.70d0,  129.02d0,  128.08d0,  127.87d0,  128.17d0, &
          129.29d0,  130.53d0,  132.03d0,  132.85d0,  133.19d0,  133.32d0, &
          133.29d0,  133.11d0,  132.90d0,  132.63d0,  132.44d0,  132.28d0, &
          132.27d0,  132.20d0,  132.23d0,  132.14d0,  132.05d0,  131.81d0, &
          131.69d0,  131.47d0,  131.33d0,  131.27d0,  131.21d0,  130.86d0, &
          130.62d0,  130.10d0,  129.42d0,  128.83d0,  128.21d0,  127.51d0, &
          127.32d0,  127.25d0,  127.50d0,  127.92d0,  128.37d0,  128.34d0, &
          128.45d0,  128.35d0,  128.49d0,  128.73d0,  129.15d0,  129.28d0, &
          129.34d0,  129.15d0,  128.97d0,  128.88d0,  128.91d0,  128.89d0, &
          128.84d0,  128.63d0,  128.02d0,  126.80d0,  125.73d0,  124.49d0, &
          123.74d0,  123.62d0,  124.08d0,  124.71d0,  125.65d0,  126.21d0, &
          126.45d0,  126.64d0,  126.61d0,  126.43d0,  126.00d0,  124.93d0, &
          124.09d0,  123.10d0,  122.73d0,  122.54d0,  123.07d0,  123.18d0, &
          123.61d0,  123.52d0,  123.55d0,  123.61d0,  124.04d0,  124.25d0, &
          124.48d0,  124.59d0,  124.48d0,  124.23d0,  123.91d0,  123.50d0, &
          122.93d0,  122.56d0,  121.98d0,  121.57d0,  121.36d0,  121.41d0, &
          121.76d0,  122.45d0,  123.09d0,  123.55d0,  123.93d0,  123.97d0, &
          123.88d0,  123.79d0,  123.71d0,  123.60d0,  123.39d0,  123.04d0, &
          122.53d0,  121.86d0,  121.09d0,  120.29d0,  119.83d0,  119.64d0, &
          119.96d0,  120.46d0,  121.14d0,  121.54d0,  121.66d0,  121.46d0, &
          120.89d0,  120.31d0,  119.86d0,  119.65d0,  119.69d0,  120.09d0, &
          120.50d0,  120.86d0,  121.14d0,  121.12d0,  121.06d0,  120.97d0, &
          120.84d0,  120.52d0,  120.17d0,  119.69d0,  119.22d0,  118.91d0, &
          118.83d0,  118.89d0,  118.94d0,  118.94d0,  118.78d0,  118.70d0, &
          118.72d0,  118.93d0,  119.20d0,  119.50d0,  119.63d0,  119.55d0, &
          119.42d0,  119.27d0,  119.17d0,  119.06d0,  118.99d0,  118.89d0, &
          118.80d0,  118.68d0,  118.60d0,  118.51d0,  118.44d0,  118.26d0, &
          118.09d0,  117.88d0,  117.77d0,  117.71d0,  117.77d0,  117.77d0, &
          117.79d0,  117.69d0,  117.57d0,  117.46d0,  117.40d0,  117.36d0, &
          117.33d0,  117.27d0,  117.05d0,  116.59d0,  115.83d0,  114.93d0, &
          114.21d0,  113.74d0,  113.75d0,  114.12d0,  114.70d0,  115.22d0/)
 
    solarc(7441:7680)=(/ &
          115.57d0,  115.53d0,  115.41d0,  115.21d0,  115.05d0,  115.01d0, &
          115.08d0,  115.14d0,  115.22d0,  115.18d0,  115.05d0,  114.78d0, &
          114.52d0,  114.07d0,  113.53d0,  112.99d0,  112.38d0,  112.08d0, &
          111.99d0,  112.27d0,  112.66d0,  113.34d0,  113.72d0,  114.07d0, &
          114.12d0,  113.95d0,  113.34d0,  112.70d0,  111.98d0,  111.65d0, &
          111.67d0,  112.15d0,  112.54d0,  112.78d0,  112.14d0,  111.30d0, &
          110.42d0,  110.03d0,  110.15d0,  110.83d0,  111.58d0,  112.27d0, &
          112.45d0,  112.31d0,  112.13d0,  112.01d0,  111.97d0,  112.07d0, &
          112.17d0,  112.27d0,  112.24d0,  112.18d0,  112.11d0,  112.05d0, &
          111.99d0,  111.91d0,  111.76d0,  111.55d0,  111.33d0,  111.14d0, &
          111.06d0,  111.04d0,  111.09d0,  111.04d0,  110.96d0,  110.78d0, &
          110.59d0,  110.38d0,  110.08d0,  109.76d0,  109.45d0,  109.26d0, &
          109.15d0,  109.26d0,  109.40d0,  109.61d0,  109.72d0,  109.76d0, &
          109.72d0,  109.68d0,  109.60d0,  109.50d0,  109.31d0,  109.18d0, &
          108.99d0,  108.89d0,  108.78d0,  108.57d0,  108.06d0,  107.64d0, &
          107.15d0,  107.03d0,  107.21d0,  107.51d0,  107.21d0,  106.75d0, &
          105.88d0,  105.31d0,  105.26d0,  105.84d0,  106.55d0,  107.36d0, &
          107.77d0,  107.78d0,  107.66d0,  107.49d0,  107.32d0,  107.18d0, &
          107.12d0,  107.00d0,  106.53d0,  106.14d0,  105.59d0,  105.33d0, &
          105.19d0,  105.47d0,  105.67d0,  106.10d0,  106.26d0,  106.38d0, &
          106.50d0,  106.59d0,  106.57d0,  106.51d0,  106.43d0,  106.33d0, &
          106.23d0,  106.12d0,  106.02d0,  105.93d0,  105.80d0,  105.50d0, &
          105.21d0,  104.79d0,  104.47d0,  104.20d0,  104.16d0,  104.15d0, &
          104.29d0,  104.30d0,  104.12d0,  103.84d0,  103.47d0,  103.15d0, &
          103.03d0,  103.15d0,  103.38d0,  103.69d0,  103.93d0,  103.99d0, &
          104.02d0,  103.98d0,  103.91d0,  103.84d0,  103.76d0,  103.67d0, &
          103.62d0,  103.54d0,  103.38d0,  103.20d0,  102.70d0,  102.00d0, &
          101.34d0,  100.74d0,  100.58d0,  100.71d0,  100.96d0,  101.22d0, &
          101.25d0,  101.11d0,  100.94d0,  100.94d0,  101.00d0,  101.23d0, &
          101.34d0,  101.47d0,  101.47d0,  101.41d0,  101.42d0,  101.37d0, &
          101.33d0,  101.30d0,  101.24d0,  101.26d0,  101.22d0,  101.10d0, &
          100.96d0,  100.84d0,  100.74d0,  100.71d0,  100.80d0,  100.92d0, &
          101.05d0,  101.07d0,  101.02d0,  100.94d0,  100.85d0,  100.73d0, &
          100.60d0,  100.38d0,   99.96d0,   99.55d0,   99.14d0,   98.94d0, &
           98.94d0,   99.16d0,   99.38d0,   99.55d0,   99.56d0,   99.44d0, &
           99.36d0,   99.30d0,   99.28d0,   99.26d0,   99.21d0,   99.05d0, &
           98.56d0,   98.15d0,   97.69d0,   97.52d0,   97.54d0,   97.83d0, &
           97.90d0,   97.94d0,   97.72d0,   97.48d0,   97.36d0,   97.29d0, &
           97.33d0,   97.34d0,   97.33d0,   97.17d0,   96.92d0,   96.58d0, &
           96.32d0,   96.11d0,   96.10d0,   96.20d0,   96.22d0,   96.27d0/)
 
    solarc(7681:7920)=(/ &
           96.21d0,   96.17d0,   96.21d0,   96.37d0,   96.50d0,   96.57d0, &
           96.51d0,   96.38d0,   96.35d0,   96.34d0,   96.39d0,   96.41d0, &
           96.41d0,   96.34d0,   96.24d0,   96.14d0,   96.02d0,   95.84d0, &
           95.32d0,   94.90d0,   94.38d0,   94.19d0,   94.19d0,   94.55d0, &
           94.89d0,   95.29d0,   95.34d0,   95.27d0,   95.18d0,   95.13d0, &
           95.10d0,   95.12d0,   95.13d0,   95.13d0,   95.08d0,   94.99d0, &
           94.90d0,   94.80d0,   94.67d0,   94.55d0,   94.33d0,   94.11d0, &
           93.93d0,   93.87d0,   93.90d0,   94.07d0,   94.20d0,   94.31d0, &
           94.35d0,   94.27d0,   94.18d0,   94.09d0,   94.00d0,   93.91d0, &
           93.81d0,   93.63d0,   93.47d0,   93.29d0,   93.15d0,   93.04d0, &
           93.00d0,   92.97d0,   92.99d0,   92.97d0,   92.93d0,   92.90d0, &
           92.83d0,   92.76d0,   92.67d0,   92.55d0,   92.42d0,   92.27d0, &
           92.13d0,   91.98d0,   91.79d0,   91.57d0,   91.33d0,   91.05d0, &
           90.77d0,   90.45d0,   90.04d0,   89.46d0,   88.49d0,   86.86d0, &
           84.92d0,   83.14d0,   82.05d0,   81.98d0,   82.92d0,   84.49d0, &
           86.20d0,   87.57d0,   88.43d0,   88.96d0,   89.35d0,   89.58d0, &
           89.68d0,   89.75d0,   89.79d0,   89.83d0,   89.82d0,   89.85d0, &
           89.82d0,   89.85d0,   89.79d0,   89.70d0,   89.48d0,   89.30d0, &
           89.11d0,   88.98d0,   88.52d0,   88.27d0,   87.90d0,   87.92d0, &
           88.03d0,   88.50d0,   88.89d0,   89.27d0,   88.95d0,   88.60d0, &
           88.16d0,   88.00d0,   87.99d0,   88.26d0,   88.50d0,   88.82d0, &
           88.88d0,   88.88d0,   88.86d0,   88.74d0,   88.38d0,   87.70d0, &
           87.08d0,   86.48d0,   86.17d0,   86.18d0,   86.49d0,   86.85d0, &
           87.23d0,   87.35d0,   87.36d0,   87.40d0,   87.30d0,   87.15d0, &
           87.03d0,   86.92d0,   86.81d0,   86.71d0,   86.59d0,   86.49d0, &
           86.40d0,   86.32d0,   86.27d0,   86.23d0,   86.16d0,   86.10d0, &
           86.00d0,   85.88d0,   85.76d0,   85.64d0,   85.54d0,   85.46d0, &
           85.41d0,   85.38d0,   85.37d0,   85.35d0,   85.23d0,   84.79d0, &
           84.24d0,   83.25d0,   82.61d0,   82.01d0,   82.08d0,   82.07d0, &
           82.63d0,   82.82d0,   83.28d0,   83.44d0,   83.77d0,   83.94d0, &
           84.16d0,   84.12d0,   84.05d0,   83.95d0,   83.87d0,   83.78d0, &
           83.71d0,   83.61d0,   83.46d0,   83.21d0,   82.92d0,   82.67d0, &
           82.46d0,   82.44d0,   82.52d0,   82.70d0,   82.85d0,   82.96d0, &
           82.94d0,   82.89d0,   82.79d0,   82.69d0,   82.61d0,   82.52d0, &
           82.45d0,   82.36d0,   82.29d0,   82.18d0,   81.91d0,   81.56d0, &
           81.23d0,   80.99d0,   80.87d0,   80.94d0,   81.08d0,   81.28d0, &
           81.40d0,   81.39d0,   81.37d0,   81.33d0,   81.28d0,   81.17d0, &
           81.14d0,   81.11d0,   81.11d0,   81.05d0,   80.98d0,   80.87d0, &
           80.76d0,   80.67d0,   80.59d0,   80.47d0,   80.31d0,   79.99d0, &
           79.64d0,   79.32d0,   79.11d0,   79.02d0,   79.14d0,   79.37d0/)
 
    solarc(7921:8160)=(/ &
           79.56d0,   79.54d0,   79.44d0,   79.29d0,   79.15d0,   79.05d0, &
           79.09d0,   79.16d0,   79.23d0,   79.21d0,   79.16d0,   78.99d0, &
           78.70d0,   78.42d0,   78.24d0,   78.15d0,   78.16d0,   78.27d0, &
           78.39d0,   78.41d0,   78.34d0,   78.27d0,   78.18d0,   78.06d0, &
           77.73d0,   77.38d0,   77.06d0,   76.92d0,   76.83d0,   76.92d0, &
           77.09d0,   77.25d0,   77.29d0,   77.33d0,   77.38d0,   77.40d0, &
           77.39d0,   77.36d0,   77.26d0,   77.12d0,   76.77d0,   76.36d0, &
           75.98d0,   75.84d0,   75.86d0,   76.05d0,   76.22d0,   76.32d0, &
           76.26d0,   76.14d0,   76.08d0,   76.10d0,   76.17d0,   76.19d0, &
           76.15d0,   76.11d0,   76.05d0,   75.93d0,   75.78d0,   75.67d0, &
           75.63d0,   75.63d0,   75.67d0,   75.71d0,   75.62d0,   75.43d0, &
           75.24d0,   75.14d0,   75.08d0,   75.13d0,   75.21d0,   75.28d0, &
           75.24d0,   75.16d0,   75.07d0,   74.97d0,   74.78d0,   74.24d0, &
           73.59d0,   72.99d0,   72.75d0,   72.65d0,   72.96d0,   73.39d0, &
           73.76d0,   73.78d0,   73.74d0,   73.70d0,   73.66d0,   73.66d0, &
           73.67d0,   73.68d0,   73.64d0,   73.60d0,   73.54d0,   73.48d0, &
           73.39d0,   73.29d0,   73.21d0,   73.15d0,   72.92d0,   72.55d0, &
           72.10d0,   71.73d0,   71.41d0,   71.27d0,   71.29d0,   71.28d0, &
           71.18d0,   71.09d0,   71.16d0,   71.28d0,   71.50d0,   71.67d0, &
           71.80d0,   71.80d0,   71.80d0,   71.80d0,   71.83d0,   71.82d0, &
           71.76d0,   71.68d0,   71.59d0,   71.51d0,   71.46d0,   71.43d0, &
           71.42d0,   71.39d0,   71.37d0,   71.29d0,   71.18d0,   71.03d0, &
           70.93d0,   70.86d0,   70.83d0,   70.82d0,   70.84d0,   70.82d0, &
           70.77d0,   70.71d0,   70.58d0,   70.38d0,   70.18d0,   70.04d0, &
           69.88d0,   69.74d0,   69.67d0,   69.61d0,   69.49d0,   69.40d0, &
           69.41d0,   69.46d0,   69.56d0,   69.67d0,   69.71d0,   69.37d0, &
           68.76d0,   68.09d0,   67.58d0,   67.18d0,   67.06d0,   67.13d0, &
           67.28d0,   67.34d0,   67.47d0,   67.64d0,   67.86d0,   68.03d0, &
           68.15d0,   68.14d0,   68.09d0,   68.00d0,   67.92d0,   67.82d0, &
           67.76d0,   67.72d0,   67.75d0,   67.77d0,   67.69d0,   67.48d0, &
           67.34d0,   67.30d0,   67.33d0,   67.39d0,   67.36d0,   67.16d0, &
           66.93d0,   66.82d0,   66.81d0,   66.95d0,   67.20d0,   67.36d0, &
           67.37d0,   67.30d0,   67.24d0,   67.16d0,   67.06d0,   66.95d0, &
           66.86d0,   66.79d0,   66.74d0,   66.69d0,   66.65d0,   66.61d0, &
           66.58d0,   66.55d0,   66.51d0,   66.46d0,   66.32d0,   65.98d0, &
           65.42d0,   64.79d0,   64.26d0,   63.93d0,   63.83d0,   63.99d0, &
           64.27d0,   64.46d0,   64.46d0,   64.37d0,   64.28d0,   64.27d0, &
           64.31d0,   64.43d0,   64.59d0,   64.72d0,   64.78d0,   64.79d0, &
           64.75d0,   64.70d0,   64.67d0,   64.62d0,   64.54d0,   64.46d0, &
           64.42d0,   64.40d0,   64.39d0,   64.40d0,   64.40d0,   64.36d0/)
 
    solarc(8161:8213)=(/ &
           64.28d0,   64.12d0,   63.93d0,   63.79d0,   63.74d0,   63.70d0, &
           63.70d0,   63.66d0,   63.38d0,   62.89d0,   62.48d0,   62.31d0, &
           62.32d0,   62.60d0,   63.03d0,   63.37d0,   63.45d0,   63.40d0, &
           63.31d0,   63.20d0,   63.10d0,   63.02d0,   63.00d0,   62.92d0, &
           62.57d0,   62.00d0,   61.34d0,   60.69d0,   60.09d0,   59.83d0, &
           59.79d0,   59.85d0,   59.96d0,   60.21d0,   60.44d0,   60.68d0, &
           60.90d0,   61.06d0,   61.08d0,   61.07d0,   61.03d0,   60.94d0, &
           60.81d0,   60.70d0,   60.65d0,   60.60d0,   60.56d0,   60.58d0, &
           60.57d0,   60.53d0,   60.48d0,   60.48d0,   60.45d0/)

  end subroutine solar2
end module sundat2

function   sunir2(v)
!--- history
! 92. 4.24  registered from lowtran-7
! 07. 4. 4  modified for new dataset (thuillier et al., solar physics, 2003)
!--- input
! v        r        wavenumber (cm-1) 4171 to 50220 cm-1
!--- output
! sunir    rf       the extra-terrestrial solar irradiance (watt/m2/micron)
!                   if 0 then v is out of range
!--
  use sundat2, only: wnc, solarc, solar2
  implicit none
  real(8),intent(in):: v
  real(8):: p,wm,w0,w1,w2, wn
  real(8):: sunir2
  integer:: iw, nw
!--exec
!       wm, w0, w1, w2  are statement functions used by
!            the 4 point lagrange interpolation

  wm(p) = p*(p - 1)*(p - 2)
  w0(p) = 3*(p**2 - 1)*(p - 2)
  w1(p) = 3*p*(p + 1)*(p - 2)
  w2(p) = p*(p**2 - 1)

  call solar2(wnc,solarc)

  wn=1.d7/v
  
!  if  v  is too small or too large, write warning + return sunir2 = 0
  
  if(wn .lt. 199.12d0 .or. wn .gt. 2397.51d0) then
     sunir2 = 0.d0
     write(6, 900) v
     return

  else
!  use  4 point interpolation
     do iw = 1, 8213
        if ( wn .lt. wnc( iw ) ) exit
     enddo
     nw = iw - 1
       
     p = ( wn - wnc ( nw ) ) / ( wnc ( nw+1 ) - wnc( nw ) )
     if ( nw .eq. 1 .or. nw .ge. 8212 ) then

! linear interpolation
        sunir2 = solarc( nw ) + ( solarc( nw+1 ) - solarc( nw )) * p
        return
        
     else

! 4 point lagrange
        sunir2 = ( w2(p)*solarc(nw+2) - w1(p)*solarc(nw+1) &
             +w0(p)*solarc(nw) - wm(p)*solarc(nw-1) ) / 6.d0
        return
     endif
  endif

  return
900 format('0 *****  warning - input frequency = ', 1pg12.5, 'cm-1', &
         /, '   outside valid range of 4171 to 50220 cm-1    *******', /)
end function sunir2
subroutine wvcal(ind,p,t,rh,ppmv,gm3,e,gm3s,es)
! conversion of units for water vapor
! ppmv =n/na =e/(p-e)*1.0e6, rh =e/es =gm3/gm3s
! ev = nrt, (p-e)v = na rt
!--- history
! 95. 9.30  created
! 08. 9.20  modified Fortran 90 free-style form
!--- input
! ind   i    1: give rh  (relative humidity, 0-1)
!            2: give ppmv (volume mixing ratio in ppmv)
!            3: give gm3 (mass mixing ratio in g/m3)
!            4: give e    (water vapor pressure in hpa)
! p     r    atmospheric pressure (hPa)
! t     r    temperature (k)
! one of rh, ppmv, gm3, or e
!--- output
! other than input variable among rh, ppmv and gm3.
! gm3s  r    saturation water vapor content (g/m3)
! es    r    saturation water vapor pressure (hPa)
!--- gas constant (cgs) and molecular weights of water vapor
!           and air (g/mol)
!--
  implicit none
! for input & output
  integer,intent(in)::ind        !! indicator
  real(8),intent(in)::p,t        !! pressure and temperature
  real(8),intent(inout)::rh,ppmv,gm3,e,gm3s,es !! quantities of watere vaour

! work
  real(8):: gcm3,gcm3s
  real(8):: wvsat                !! function for saturated
  real(8),parameter::r=8.314d7, w=18.02d0, air=28.964d0
!--exec
! satuaration water vapor (g/cm3)
  gcm3s=wvsat(t)*1.0d-6
  es=gcm3s/w*r*t/1.0d3
  if(ind==1) then
     gcm3=rh*gcm3s
     e=rh*es
     ppmv=e/(p-e)*1.0d6
  elseif(ind==2) then
     e=p*ppmv/(1.0d6+ppmv)
     rh=e/es
     gcm3=rh*gcm3s
  elseif(ind==3) then
     gcm3=gm3*1.0d-6
     rh=gcm3/gcm3s
     e=rh*es
     ppmv=e/(p-e)*1.0d6
  elseif(ind==4) then
     rh=e/es
     gcm3=rh*gcm3s
     ppmv=e/(p-e)*1.0d6
  endif
  gm3=gcm3*1.0d6
  gm3s=gcm3s*1.0d6
  if(rh>1.d0) rh=1.d0
  return
end subroutine wvcal

function wvsat(t)
! saturation water vapor amount (LOWTRAN)
!  ws=a*exp(18.9766-14.9595a-2.4388a**2) g/m3
!  a=t0/t, t0=273.15, t in k (t0-50,t0+50)
!--- history
! 93. 3. 3 created
! 08. 9.20  modified Fortran 90 free-style form
!--- input
! t       r      absolute temperature (K)
!                t0-50 to t0+50
!--- output
! wvsat  rf      water vapor amount (g/m3)
!---
  implicit none
  real(8),intent(in)::t
  real(8)::a,wvsat
!--exec
  a=273.15d0/t
  wvsat=a*dexp(18.9766d0-14.9595d0*a-2.4388d0*a**2)
  return
end function wvsat

function tbb(wl,bb)
  implicit none
! CALCULAION Brightness temperature
!--- History
! 1994.1.11 CCS
! 2008.5.15 updated to f90
!--- Input
! WL     R     Wavelength in micron
! BB     R     Radiance (Watt/m2/str/micron)
!--- Output
! TBB    R     Brightness temperature (K)
!
  real(8):: tbb,wl,bb
!
  tbb=1.438786d4/wl/LOG(1.1911d8/wl**5/bb+1)
  RETURN
END function tbb
